# frozen_string_literal: true

module Discorb
  #
  # A table of emoji names and their unicode values.
  #
  module EmojiTable
    # A hash of Discord's emoji names to their unicode characters.
    DISCORD_TO_UNICODE = {
      "flag_ni" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAE",
      "flag_ne" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAA",
      "flag_ng" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAC",
      "flag_nu" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xBA",
      "flag_nf" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAB",
      "flag_kp" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB5",
      "flag_mp" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB5",
      "flag_no" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xB4",
      "flag_om" => "\xF0\x9F\x87\xB4\xF0\x9F\x87\xB2",
      "flag_pk" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB0",
      "flag_pw" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xBC",
      "flag_ps" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB8",
      "flag_pa" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xA6",
      "flag_pg" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAC",
      "flag_py" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xBE",
      "flag_pe" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAA",
      "flag_ph" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAD",
      "flag_pn" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB3",
      "flag_pl" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB1",
      "flag_pt" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB9",
      "flag_pr" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB7",
      "flag_qa" => "\xF0\x9F\x87\xB6\xF0\x9F\x87\xA6",
      "flag_re" => "\xF0\x9F\x87\xB7\xF0\x9F\x87\xAA",
      "flag_ro" => "\xF0\x9F\x87\xB7\xF0\x9F\x87\xB4",
      "flag_ru" => "\xF0\x9F\x87\xB7\xF0\x9F\x87\xBA",
      "flag_rw" => "\xF0\x9F\x87\xB7\xF0\x9F\x87\xBC",
      "flag_ws" => "\xF0\x9F\x87\xBC\xF0\x9F\x87\xB8",
      "flag_sm" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB2",
      "flag_st" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB9",
      "flag_sa" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA6",
      "flag_sn" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB3",
      "flag_rs" => "\xF0\x9F\x87\xB7\xF0\x9F\x87\xB8",
      "flag_sc" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA8",
      "flag_sl" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB1",
      "flag_sg" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAC",
      "flag_sx" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBD",
      "flag_sk" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB0",
      "flag_si" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAE",
      "flag_gs" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB8",
      "flag_sb" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA7",
      "flag_so" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB4",
      "flag_za" => "\xF0\x9F\x87\xBF\xF0\x9F\x87\xA6",
      "flag_kr" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB7",
      "flag_ss" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB8",
      "flag_es" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xB8",
      "flag_lk" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB0",
      "flag_bl" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB1",
      "flag_sh" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAD",
      "flag_kn" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB3",
      "flag_lc" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xA8",
      "flag_pm" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB2",
      "flag_vc" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xA8",
      "flag_sd" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA9",
      "flag_sr" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB7",
      "flag_sz" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBF",
      "flag_se" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAA",
      "flag_ch" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAD",
      "flag_sy" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBE",
      "flag_tw" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xBC",
      "flag_tj" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAF",
      "flag_tz" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xBF",
      "flag_th" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAD",
      "flag_tl" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB1",
      "flag_tg" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAC",
      "flag_tk" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB0",
      "flag_to" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB4",
      "flag_tt" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB9",
      "flag_tn" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB3",
      "flag_tr" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB7",
      "flag_tm" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB2",
      "flag_tc" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xA8",
      "flag_vi" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xAE",
      "flag_tv" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xBB",
      "flag_ug" => "\xF0\x9F\x87\xBA\xF0\x9F\x87\xAC",
      "flag_ua" => "\xF0\x9F\x87\xBA\xF0\x9F\x87\xA6",
      "flag_ae" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAA",
      "flag_gb" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xA7",
      "england" => "\xF0\x9F\x8F\xB4\xF3\xA0\x81\xA7\xF3\xA0\x81\xA2\xF3\xA0\x81\xA5\xF3\xA0\x81\xAE\xF3\xA0\x81\xA7\xF3\xA0\x81\xBF",
      "scotland" => "\xF0\x9F\x8F\xB4\xF3\xA0\x81\xA7\xF3\xA0\x81\xA2\xF3\xA0\x81\xB3\xF3\xA0\x81\xA3\xF3\xA0\x81\xB4\xF3\xA0\x81\xBF",
      "wales" => "\xF0\x9F\x8F\xB4\xF3\xA0\x81\xA7\xF3\xA0\x81\xA2\xF3\xA0\x81\xB7\xF3\xA0\x81\xAC\xF3\xA0\x81\xB3\xF3\xA0\x81\xBF",
      "flag_us" => "\xF0\x9F\x87\xBA\xF0\x9F\x87\xB8",
      "flag_uy" => "\xF0\x9F\x87\xBA\xF0\x9F\x87\xBE",
      "flag_uz" => "\xF0\x9F\x87\xBA\xF0\x9F\x87\xBF",
      "flag_vu" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xBA",
      "flag_va" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xA6",
      "flag_ve" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xAA",
      "flag_vn" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xB3",
      "flag_wf" => "\xF0\x9F\x87\xBC\xF0\x9F\x87\xAB",
      "flag_eh" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xAD",
      "flag_ye" => "\xF0\x9F\x87\xBE\xF0\x9F\x87\xAA",
      "flag_zm" => "\xF0\x9F\x87\xBF\xF0\x9F\x87\xB2",
      "flag_zw" => "\xF0\x9F\x87\xBF\xF0\x9F\x87\xBC",
      "flag_ac" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xA8",
      "flag_bv" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBB",
      "flag_cp" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB5",
      "flag_ea" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xA6",
      "flag_dg" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xAC",
      "flag_hm" => "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB2",
      "flag_mf" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAB",
      "flag_ci" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAE",
      "flag_hr" => "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB7",
      "flag_cu" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBA",
      "flag_cw" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBC",
      "flag_cy" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBE",
      "flag_cz" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBF",
      "flag_dk" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xB0",
      "flag_dj" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xAF",
      "flag_dm" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xB2",
      "flag_do" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xB4",
      "flag_ec" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xA8",
      "flag_eg" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xAC",
      "flag_sv" => "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBB",
      "flag_gq" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB6",
      "flag_er" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xB7",
      "flag_ee" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xAA",
      "flag_et" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xB9",
      "flag_eu" => "\xF0\x9F\x87\xAA\xF0\x9F\x87\xBA",
      "flag_fk" => "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB0",
      "flag_fo" => "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB4",
      "flag_fj" => "\xF0\x9F\x87\xAB\xF0\x9F\x87\xAF",
      "flag_fi" => "\xF0\x9F\x87\xAB\xF0\x9F\x87\xAE",
      "flag_fr" => "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB7",
      "flag_gf" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAB",
      "flag_pf" => "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAB",
      "flag_tf" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAB",
      "flag_ga" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xA6",
      "flag_gm" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB2",
      "flag_ge" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAA",
      "flag_de" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xAA",
      "flag_gh" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAD",
      "flag_gi" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAE",
      "flag_gr" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB7",
      "flag_gl" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB1",
      "flag_gd" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xA9",
      "flag_gp" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB5",
      "flag_gu" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xBA",
      "flag_gt" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB9",
      "flag_gg" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAC",
      "flag_gn" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB3",
      "flag_gw" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xBC",
      "flag_gy" => "\xF0\x9F\x87\xAC\xF0\x9F\x87\xBE",
      "flag_ht" => "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB9",
      "flag_hn" => "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB3",
      "flag_hk" => "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB0",
      "flag_hu" => "\xF0\x9F\x87\xAD\xF0\x9F\x87\xBA",
      "flag_is" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB8",
      "flag_in" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB3",
      "flag_id" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xA9",
      "flag_ir" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB7",
      "flag_iq" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB6",
      "flag_ie" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xAA",
      "flag_im" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB2",
      "flag_il" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB1",
      "flag_it" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB9",
      "flag_jm" => "\xF0\x9F\x87\xAF\xF0\x9F\x87\xB2",
      "flag_jp" => "\xF0\x9F\x87\xAF\xF0\x9F\x87\xB5",
      "crossed_flags" => "\xF0\x9F\x8E\x8C",
      "flag_je" => "\xF0\x9F\x87\xAF\xF0\x9F\x87\xAA",
      "flag_jo" => "\xF0\x9F\x87\xAF\xF0\x9F\x87\xB4",
      "flag_kz" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xBF",
      "flag_ke" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAA",
      "flag_ki" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAE",
      "flag_xk" => "\xF0\x9F\x87\xBD\xF0\x9F\x87\xB0",
      "flag_kw" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xBC",
      "flag_kg" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAC",
      "flag_la" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xA6",
      "flag_lv" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xBB",
      "flag_lb" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xA7",
      "flag_ls" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB8",
      "flag_lr" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB7",
      "flag_ly" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xBE",
      "flag_li" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xAE",
      "flag_lt" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB9",
      "flag_lu" => "\xF0\x9F\x87\xB1\xF0\x9F\x87\xBA",
      "flag_mo" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB4",
      "flag_mk" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB0",
      "flag_mg" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAC",
      "flag_mw" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBC",
      "flag_my" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBE",
      "flag_mv" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBB",
      "flag_ml" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB1",
      "flag_mt" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB9",
      "flag_mh" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAD",
      "flag_mq" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB6",
      "flag_mr" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB7",
      "flag_mu" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBA",
      "flag_yt" => "\xF0\x9F\x87\xBE\xF0\x9F\x87\xB9",
      "flag_mx" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBD",
      "flag_fm" => "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB2",
      "flag_md" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xA9",
      "flag_mc" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xA8",
      "flag_mn" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB3",
      "flag_me" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAA",
      "flag_ms" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB8",
      "flag_ma" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xA6",
      "flag_mz" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBF",
      "flag_mm" => "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB2",
      "flag_na" => "\xF0\x9F\x87\xB3\xF0\x9F\x87\xA6",
      "regional_indicator_p" => "\xF0\x9F\x87\xB5",
      "regional_indicator_o" => "\xF0\x9F\x87\xB4",
      "regional_indicator_n" => "\xF0\x9F\x87\xB3",
      "regional_indicator_m" => "\xF0\x9F\x87\xB2",
      "regional_indicator_l" => "\xF0\x9F\x87\xB1",
      "regional_indicator_k" => "\xF0\x9F\x87\xB0",
      "regional_indicator_j" => "\xF0\x9F\x87\xAF",
      "regional_indicator_i" => "\xF0\x9F\x87\xAE",
      "regional_indicator_h" => "\xF0\x9F\x87\xAD",
      "regional_indicator_g" => "\xF0\x9F\x87\xAC",
      "regional_indicator_f" => "\xF0\x9F\x87\xAB",
      "regional_indicator_e" => "\xF0\x9F\x87\xAA",
      "regional_indicator_d" => "\xF0\x9F\x87\xA9",
      "regional_indicator_c" => "\xF0\x9F\x87\xA8",
      "regional_indicator_b" => "\xF0\x9F\x87\xA7",
      "regional_indicator_a" => "\xF0\x9F\x87\xA6",
      "flag_white" => "\xF0\x9F\x8F\xB3\xEF\xB8\x8F",
      "flag_black" => "\xF0\x9F\x8F\xB4",
      "checkered_flag" => "\xF0\x9F\x8F\x81",
      "triangular_flag_on_post" => "\xF0\x9F\x9A\xA9",
      "rainbow_flag" => "\xF0\x9F\x8F\xB3\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x8C\x88",
      "gay_pride_flag" => "\xF0\x9F\x8F\xB3\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x8C\x88",
      "transgender_flag" => "\xF0\x9F\x8F\xB3\xEF\xB8\x8F\xE2\x80\x8D\xE2\x9A\xA7\xEF\xB8\x8F",
      "pirate_flag" => "\xF0\x9F\x8F\xB4\xE2\x80\x8D\xE2\x98\xA0\xEF\xB8\x8F",
      "flag_af" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAB",
      "flag_ax" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBD",
      "flag_al" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB1",
      "flag_dz" => "\xF0\x9F\x87\xA9\xF0\x9F\x87\xBF",
      "flag_as" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB8",
      "flag_ad" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xA9",
      "flag_ao" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB4",
      "flag_ai" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAE",
      "flag_aq" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB6",
      "flag_ag" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAC",
      "flag_ar" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB7",
      "flag_am" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB2",
      "flag_aw" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBC",
      "flag_au" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBA",
      "flag_at" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB9",
      "flag_az" => "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBF",
      "flag_bs" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB8",
      "flag_bh" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAD",
      "flag_bd" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xA9",
      "flag_bb" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xA7",
      "flag_by" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBE",
      "flag_be" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAA",
      "flag_bz" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBF",
      "flag_bj" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAF",
      "flag_bm" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB2",
      "flag_bt" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB9",
      "flag_bo" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB4",
      "flag_ba" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xA6",
      "flag_bw" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBC",
      "flag_br" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB7",
      "flag_io" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB4",
      "flag_vg" => "\xF0\x9F\x87\xBB\xF0\x9F\x87\xAC",
      "flag_bn" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB3",
      "flag_bg" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAC",
      "flag_bf" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAB",
      "flag_bi" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAE",
      "flag_kh" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAD",
      "flag_cm" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB2",
      "flag_ca" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xA6",
      "flag_ic" => "\xF0\x9F\x87\xAE\xF0\x9F\x87\xA8",
      "flag_cv" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBB",
      "flag_bq" => "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB6",
      "flag_ky" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xBE",
      "flag_cf" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAB",
      "flag_td" => "\xF0\x9F\x87\xB9\xF0\x9F\x87\xA9",
      "flag_cl" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB1",
      "flag_cn" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB3",
      "flag_cx" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBD",
      "flag_cc" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xA8",
      "flag_co" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB4",
      "flag_km" => "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB2",
      "flag_cg" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAC",
      "flag_cd" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xA9",
      "flag_ck" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB0",
      "flag_cr" => "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB7",
      "black_medium_small_square" => "\xE2\x97\xBE",
      "white_medium_small_square" => "\xE2\x97\xBD",
      "black_medium_square" => "\xE2\x97\xBC\xEF\xB8\x8F",
      "white_medium_square" => "\xE2\x97\xBB\xEF\xB8\x8F",
      "black_large_square" => "\xE2\xAC\x9B",
      "white_large_square" => "\xE2\xAC\x9C",
      "orange_square" => "\xF0\x9F\x9F\xA7",
      "blue_square" => "\xF0\x9F\x9F\xA6",
      "red_square" => "\xF0\x9F\x9F\xA5",
      "brown_square" => "\xF0\x9F\x9F\xAB",
      "purple_square" => "\xF0\x9F\x9F\xAA",
      "green_square" => "\xF0\x9F\x9F\xA9",
      "yellow_square" => "\xF0\x9F\x9F\xA8",
      "speaker" => "\xF0\x9F\x94\x88",
      "mute" => "\xF0\x9F\x94\x87",
      "sound" => "\xF0\x9F\x94\x89",
      "loud_sound" => "\xF0\x9F\x94\x8A",
      "no_bell" => "\xF0\x9F\x94\x95",
      "mega" => "\xF0\x9F\x93\xA3",
      "loudspeaker" => "\xF0\x9F\x93\xA2",
      "speech_left" => "\xF0\x9F\x97\xA8\xEF\xB8\x8F",
      "left_speech_bubble" => "\xF0\x9F\x97\xA8\xEF\xB8\x8F",
      "eye_in_speech_bubble" => "\xF0\x9F\x91\x81\xE2\x80\x8D\xF0\x9F\x97\xA8",
      "speech_balloon" => "\xF0\x9F\x92\xAC",
      "thought_balloon" => "\xF0\x9F\x92\xAD",
      "anger_right" => "\xF0\x9F\x97\xAF\xEF\xB8\x8F",
      "right_anger_bubble" => "\xF0\x9F\x97\xAF\xEF\xB8\x8F",
      "spades" => "\xE2\x99\xA0\xEF\xB8\x8F",
      "clubs" => "\xE2\x99\xA3\xEF\xB8\x8F",
      "hearts" => "\xE2\x99\xA5\xEF\xB8\x8F",
      "diamonds" => "\xE2\x99\xA6\xEF\xB8\x8F",
      "black_joker" => "\xF0\x9F\x83\x8F",
      "flower_playing_cards" => "\xF0\x9F\x8E\xB4",
      "mahjong" => "\xF0\x9F\x80\x84",

      "clock" => "\xF0\x9F\x95\xB0\xEF\xB8\x8F",
      "mantlepiece_clock" => "\xF0\x9F\x95\xB0\xEF\xB8\x8F",
      "female_sign" => "\xE2\x99\x80\xEF\xB8\x8F",
      "male_sign" => "\xE2\x99\x82\xEF\xB8\x8F",
      "transgender_symbol" => "\xE2\x9A\xA7",
      "medical_symbol" => "\xE2\x9A\x95\xEF\xB8\x8F",
      "regional_indicator_z" => "\xF0\x9F\x87\xBF",
      "regional_indicator_y" => "\xF0\x9F\x87\xBE",
      "regional_indicator_x" => "\xF0\x9F\x87\xBD",
      "regional_indicator_w" => "\xF0\x9F\x87\xBC",
      "regional_indicator_v" => "\xF0\x9F\x87\xBB",
      "regional_indicator_u" => "\xF0\x9F\x87\xBA",
      "regional_indicator_t" => "\xF0\x9F\x87\xB9",
      "regional_indicator_s" => "\xF0\x9F\x87\xB8",
      "regional_indicator_r" => "\xF0\x9F\x87\xB7",
      "regional_indicator_q" => "\xF0\x9F\x87\xB6",
      "arrow_down_small" => "\xF0\x9F\x94\xBD",
      "arrow_right" => "\xE2\x9E\xA1\xEF\xB8\x8F",
      "arrow_left" => "\xE2\xAC\x85\xEF\xB8\x8F",
      "arrow_up" => "\xE2\xAC\x86\xEF\xB8\x8F",
      "arrow_down" => "\xE2\xAC\x87\xEF\xB8\x8F",
      "arrow_upper_right" => "\xE2\x86\x97\xEF\xB8\x8F",
      "arrow_lower_right" => "\xE2\x86\x98\xEF\xB8\x8F",
      "arrow_lower_left" => "\xE2\x86\x99\xEF\xB8\x8F",
      "arrow_upper_left" => "\xE2\x86\x96\xEF\xB8\x8F",
      "arrow_up_down" => "\xE2\x86\x95\xEF\xB8\x8F",
      "left_right_arrow" => "\xE2\x86\x94\xEF\xB8\x8F",
      "arrow_right_hook" => "\xE2\x86\xAA\xEF\xB8\x8F",
      "leftwards_arrow_with_hook" => "\xE2\x86\xA9\xEF\xB8\x8F",
      "arrow_heading_up" => "\xE2\xA4\xB4\xEF\xB8\x8F",
      "arrow_heading_down" => "\xE2\xA4\xB5\xEF\xB8\x8F",
      "twisted_rightwards_arrows" => "\xF0\x9F\x94\x80",
      "repeat" => "\xF0\x9F\x94\x81",
      "repeat_one" => "\xF0\x9F\x94\x82",
      "arrows_counterclockwise" => "\xF0\x9F\x94\x84",
      "arrows_clockwise" => "\xF0\x9F\x94\x83",
      "musical_note" => "\xF0\x9F\x8E\xB5",
      "notes" => "\xF0\x9F\x8E\xB6",
      "heavy_plus_sign" => "\xE2\x9E\x95",
      "heavy_minus_sign" => "\xE2\x9E\x96",
      "heavy_division_sign" => "\xE2\x9E\x97",
      "heavy_multiplication_x" => "\xE2\x9C\x96\xEF\xB8\x8F",
      "infinity" => "\xE2\x99\xBE\xEF\xB8\x8F",
      "heavy_dollar_sign" => "\xF0\x9F\x92\xB2",
      "currency_exchange" => "\xF0\x9F\x92\xB1",
      "tm" => "\xE2\x84\xA2\xEF\xB8\x8F",
      "copyright" => "\xC2\xA9\xEF\xB8\x8F",
      "registered" => "\xC2\xAE\xEF\xB8\x8F",
      "wavy_dash" => "\xE3\x80\xB0\xEF\xB8\x8F",
      "curly_loop" => "\xE2\x9E\xB0",
      "loop" => "\xE2\x9E\xBF",
      "end" => "\xF0\x9F\x94\x9A",
      "back" => "\xF0\x9F\x94\x99",
      "on" => "\xF0\x9F\x94\x9B",
      "top" => "\xF0\x9F\x94\x9D",
      "soon" => "\xF0\x9F\x94\x9C",
      "heavy_check_mark" => "\xE2\x9C\x94\xEF\xB8\x8F",
      "ballot_box_with_check" => "\xE2\x98\x91\xEF\xB8\x8F",
      "radio_button" => "\xF0\x9F\x94\x98",
      "white_circle" => "\xE2\x9A\xAA",
      "black_circle" => "\xE2\x9A\xAB",
      "red_circle" => "\xF0\x9F\x94\xB4",
      "blue_circle" => "\xF0\x9F\x94\xB5",
      "brown_circle" => "\xF0\x9F\x9F\xA4",
      "purple_circle" => "\xF0\x9F\x9F\xA3",
      "green_circle" => "\xF0\x9F\x9F\xA2",
      "yellow_circle" => "\xF0\x9F\x9F\xA1",
      "orange_circle" => "\xF0\x9F\x9F\xA0",
      "small_red_triangle" => "\xF0\x9F\x94\xBA",
      "small_red_triangle_down" => "\xF0\x9F\x94\xBB",
      "small_orange_diamond" => "\xF0\x9F\x94\xB8",
      "small_blue_diamond" => "\xF0\x9F\x94\xB9",
      "large_orange_diamond" => "\xF0\x9F\x94\xB6",
      "large_blue_diamond" => "\xF0\x9F\x94\xB7",
      "white_square_button" => "\xF0\x9F\x94\xB3",
      "black_square_button" => "\xF0\x9F\x94\xB2",
      "black_small_square" => "\xE2\x96\xAA\xEF\xB8\x8F",
      "white_small_square" => "\xE2\x96\xAB\xEF\xB8\x8F",
      "no_smoking" => "\xF0\x9F\x9A\xAD",
      "exclamation" => "\xE2\x9D\x97",
      "grey_exclamation" => "\xE2\x9D\x95",
      "question" => "\xE2\x9D\x93",
      "grey_question" => "\xE2\x9D\x94",
      "bangbang" => "\xE2\x80\xBC\xEF\xB8\x8F",
      "interrobang" => "\xE2\x81\x89\xEF\xB8\x8F",
      "low_brightness" => "\xF0\x9F\x94\x85",
      "high_brightness" => "\xF0\x9F\x94\x86",
      "part_alternation_mark" => "\xE3\x80\xBD\xEF\xB8\x8F",
      "warning" => "\xE2\x9A\xA0\xEF\xB8\x8F",
      "children_crossing" => "\xF0\x9F\x9A\xB8",
      "trident" => "\xF0\x9F\x94\xB1",
      "fleur_de_lis" => "\xE2\x9A\x9C\xEF\xB8\x8F",
      "recycle" => "\xE2\x99\xBB\xEF\xB8\x8F",
      "white_check_mark" => "\xE2\x9C\x85",
      "u" => "7981\xF0\x9F\x88\xB2",
      "chart" => "\xF0\x9F\x92\xB9",
      "sparkle" => "\xE2\x9D\x87\xEF\xB8\x8F",
      "eight_spoked_asterisk" => "\xE2\x9C\xB3\xEF\xB8\x8F",
      "negative_squared_cross_mark" => "\xE2\x9D\x8E",
      "globe_with_meridians" => "\xF0\x9F\x8C\x90",
      "diamond_shape_with_a_dot_inside" => "\xF0\x9F\x92\xA0",
      "m" => "\xE2\x93\x82\xEF\xB8\x8F",
      "cyclone" => "\xF0\x9F\x8C\x80",
      "zzz" => "\xF0\x9F\x92\xA4",
      "atm" => "\xF0\x9F\x8F\xA7",
      "wc" => "\xF0\x9F\x9A\xBE",
      "wheelchair" => "\xE2\x99\xBF",
      "parking" => "\xF0\x9F\x85\xBF\xEF\xB8\x8F",
      "sa" => "\xF0\x9F\x88\x82\xEF\xB8\x8F",
      "passport_control" => "\xF0\x9F\x9B\x82",
      "customs" => "\xF0\x9F\x9B\x83",
      "baggage_claim" => "\xF0\x9F\x9B\x84",
      "left_luggage" => "\xF0\x9F\x9B\x85",
      "elevator" => "\xF0\x9F\x9B\x97",
      "mens" => "\xF0\x9F\x9A\xB9",
      "womens" => "\xF0\x9F\x9A\xBA",
      "baby_symbol" => "\xF0\x9F\x9A\xBC",
      "restroom" => "\xF0\x9F\x9A\xBB",
      "put_litter_in_its_place" => "\xF0\x9F\x9A\xAE",
      "cinema" => "\xF0\x9F\x8E\xA6",
      "signal_strength" => "\xF0\x9F\x93\xB6",
      "koko" => "\xF0\x9F\x88\x81",
      "symbols" => "\xF0\x9F\x94\xA3",
      "information_source" => "\xE2\x84\xB9\xEF\xB8\x8F",
      "abc" => "\xF0\x9F\x94\xA4",
      "abcd" => "\xF0\x9F\x94\xA1",
      "capital_abcd" => "\xF0\x9F\x94\xA0",
      "ng" => "\xF0\x9F\x86\x96",
      "ok" => "\xF0\x9F\x86\x97",
      "up" => "\xF0\x9F\x86\x99",
      "cool" => "\xF0\x9F\x86\x92",
      "new" => "\xF0\x9F\x86\x95",
      "free" => "\xF0\x9F\x86\x93",
      "zero" => "0\xEF\xB8\x8F\xE2\x83\xA3",
      "one" => "1\xEF\xB8\x8F\xE2\x83\xA3",
      "two" => "2\xEF\xB8\x8F\xE2\x83\xA3",
      "three" => "3\xEF\xB8\x8F\xE2\x83\xA3",
      "four" => "4\xEF\xB8\x8F\xE2\x83\xA3",
      "five" => "5\xEF\xB8\x8F\xE2\x83\xA3",
      "six" => "6\xEF\xB8\x8F\xE2\x83\xA3",
      "seven" => "7\xEF\xB8\x8F\xE2\x83\xA3",
      "eight" => "8\xEF\xB8\x8F\xE2\x83\xA3",
      "nine" => "9\xEF\xB8\x8F\xE2\x83\xA3",
      "keycap_ten" => "\xF0\x9F\x94\x9F",
      "hash" => "#\xEF\xB8\x8F\xE2\x83\xA3",
      "asterisk" => "*\xEF\xB8\x8F\xE2\x83\xA3",
      "keycap_asterisk" => "*\xEF\xB8\x8F\xE2\x83\xA3",
      "eject" => "\xE2\x8F\x8F\xEF\xB8\x8F",
      "eject_symbol" => "\xE2\x8F\x8F\xEF\xB8\x8F",
      "arrow_forward" => "\xE2\x96\xB6\xEF\xB8\x8F",
      "pause_button" => "\xE2\x8F\xB8\xEF\xB8\x8F",
      "double_vertical_bar" => "\xE2\x8F\xB8\xEF\xB8\x8F",
      "play_pause" => "\xE2\x8F\xAF\xEF\xB8\x8F",
      "stop_button" => "\xE2\x8F\xB9\xEF\xB8\x8F",
      "record_button" => "\xE2\x8F\xBA\xEF\xB8\x8F",
      "track_next" => "\xE2\x8F\xAD\xEF\xB8\x8F",
      "next_track" => "\xE2\x8F\xAD\xEF\xB8\x8F",
      "track_previous" => "\xE2\x8F\xAE\xEF\xB8\x8F",
      "previous_track" => "\xE2\x8F\xAE\xEF\xB8\x8F",
      "fast_forward" => "\xE2\x8F\xA9",
      "rewind" => "\xE2\x8F\xAA",
      "arrow_double_up" => "\xE2\x8F\xAB",
      "arrow_double_down" => "\xE2\x8F\xAC",
      "arrow_backward" => "\xE2\x97\x80\xEF\xB8\x8F",
      "arrow_up_small" => "\xF0\x9F\x94\xBC",
      "yellow_heart" => "\xF0\x9F\x92\x9B",
      "green_heart" => "\xF0\x9F\x92\x9A",
      "blue_heart" => "\xF0\x9F\x92\x99",
      "purple_heart" => "\xF0\x9F\x92\x9C",
      "black_heart" => "\xF0\x9F\x96\xA4",
      "brown_heart" => "\xF0\x9F\xA4\x8E",
      "white_heart" => "\xF0\x9F\xA4\x8D",
      "broken_heart" => "\xF0\x9F\x92\x94",
      "heart_exclamation" => "\xE2\x9D\xA3\xEF\xB8\x8F",
      "heavy_heart_exclamation_mark_ornament" => "\xE2\x9D\xA3\xEF\xB8\x8F",
      "two_hearts" => "\xF0\x9F\x92\x95",
      "revolving_hearts" => "\xF0\x9F\x92\x9E",
      "heartbeat" => "\xF0\x9F\x92\x93",
      "heartpulse" => "\xF0\x9F\x92\x97",
      "sparkling_heart" => "\xF0\x9F\x92\x96",
      "cupid" => "\xF0\x9F\x92\x98",
      "gift_heart" => "\xF0\x9F\x92\x9D",
      "mending_heart" => "\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\xA9\xB9",
      "heart_on_fire" => "\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x94\xA5",
      "heart_decoration" => "\xF0\x9F\x92\x9F",
      "peace" => "\xE2\x98\xAE\xEF\xB8\x8F",
      "peace_symbol" => "\xE2\x98\xAE\xEF\xB8\x8F",
      "cross" => "\xE2\x9C\x9D\xEF\xB8\x8F",
      "latin_cross" => "\xE2\x9C\x9D\xEF\xB8\x8F",
      "star_and_crescent" => "\xE2\x98\xAA\xEF\xB8\x8F",
      "om_symbol" => "\xF0\x9F\x95\x89\xEF\xB8\x8F",
      "wheel_of_dharma" => "\xE2\x98\xB8\xEF\xB8\x8F",
      "star_of_david" => "\xE2\x9C\xA1\xEF\xB8\x8F",
      "six_pointed_star" => "\xF0\x9F\x94\xAF",
      "menorah" => "\xF0\x9F\x95\x8E",
      "yin_yang" => "\xE2\x98\xAF\xEF\xB8\x8F",
      "orthodox_cross" => "\xE2\x98\xA6\xEF\xB8\x8F",
      "place_of_worship" => "\xF0\x9F\x9B\x90",
      "worship_symbol" => "\xF0\x9F\x9B\x90",
      "ophiuchus" => "\xE2\x9B\x8E",
      "aries" => "\xE2\x99\x88",
      "taurus" => "\xE2\x99\x89",
      "gemini" => "\xE2\x99\x8A",
      "cancer" => "\xE2\x99\x8B",
      "leo" => "\xE2\x99\x8C",
      "virgo" => "\xE2\x99\x8D",
      "libra" => "\xE2\x99\x8E",
      "scorpius" => "\xE2\x99\x8F",
      "sagittarius" => "\xE2\x99\x90",
      "capricorn" => "\xE2\x99\x91",
      "aquarius" => "\xE2\x99\x92",
      "pisces" => "\xE2\x99\x93",
      "id" => "\xF0\x9F\x86\x94",
      "atom" => "\xE2\x9A\x9B\xEF\xB8\x8F",
      "atom_symbol" => "\xE2\x9A\x9B\xEF\xB8\x8F",
      "accept" => "\xF0\x9F\x89\x91",
      "radioactive" => "\xE2\x98\xA2\xEF\xB8\x8F",
      "radioactive_sign" => "\xE2\x98\xA2\xEF\xB8\x8F",
      "biohazard" => "\xE2\x98\xA3\xEF\xB8\x8F",
      "biohazard_sign" => "\xE2\x98\xA3\xEF\xB8\x8F",
      "mobile_phone_off" => "\xF0\x9F\x93\xB4",
      "vibration_mode" => "\xF0\x9F\x93\xB3",
      "eight_pointed_black_star" => "\xE2\x9C\xB4\xEF\xB8\x8F",
      "vs" => "\xF0\x9F\x86\x9A",
      "white_flower" => "\xF0\x9F\x92\xAE",
      "ideograph_advantage" => "\xF0\x9F\x89\x90",
      "secret" => "\xE3\x8A\x99\xEF\xB8\x8F",
      "congratulations" => "\xE3\x8A\x97\xEF\xB8\x8F",
      "a" => "\xF0\x9F\x85\xB0\xEF\xB8\x8F",
      "b" => "\xF0\x9F\x85\xB1\xEF\xB8\x8F",
      "ab" => "\xF0\x9F\x86\x8E",
      "cl" => "\xF0\x9F\x86\x91",
      "o" => "\xE2\xAD\x95",
      "sos" => "\xF0\x9F\x86\x98",
      "x" => "\xE2\x9D\x8C",
      "octagonal_sign" => "\xF0\x9F\x9B\x91",
      "stop_sign" => "\xF0\x9F\x9B\x91",
      "no_entry" => "\xE2\x9B\x94",
      "name_badge" => "\xF0\x9F\x93\x9B",
      "no_entry_sign" => "\xF0\x9F\x9A\xAB",
      "anger" => "\xF0\x9F\x92\xA2",
      "hotsprings" => "\xE2\x99\xA8\xEF\xB8\x8F",
      "no_pedestrians" => "\xF0\x9F\x9A\xB7",
      "do_not_litter" => "\xF0\x9F\x9A\xAF",
      "no_bicycles" => "\xF0\x9F\x9A\xB3",
      "non_potable_water" => "\xF0\x9F\x9A\xB1",
      "underage" => "\xF0\x9F\x94\x9E",
      "no_mobile_phones" => "\xF0\x9F\x93\xB5",
      "wind_chime" => "\xF0\x9F\x8E\x90",
      "red_envelope" => "\xF0\x9F\xA7\xA7",
      "envelope" => "\xE2\x9C\x89\xEF\xB8\x8F",
      "envelope_with_arrow" => "\xF0\x9F\x93\xA9",
      "incoming_envelope" => "\xF0\x9F\x93\xA8",
      "e_mail" => "\xF0\x9F\x93\xA7",
      "email" => "\xF0\x9F\x93\xA7",
      "love_letter" => "\xF0\x9F\x92\x8C",
      "inbox_tray" => "\xF0\x9F\x93\xA5",
      "outbox_tray" => "\xF0\x9F\x93\xA4",
      "package" => "\xF0\x9F\x93\xA6",
      "label" => "\xF0\x9F\x8F\xB7\xEF\xB8\x8F",
      "mailbox_closed" => "\xF0\x9F\x93\xAA",
      "mailbox" => "\xF0\x9F\x93\xAB",
      "mailbox_with_mail" => "\xF0\x9F\x93\xAC",
      "mailbox_with_no_mail" => "\xF0\x9F\x93\xAD",
      "postbox" => "\xF0\x9F\x93\xAE",
      "postal_horn" => "\xF0\x9F\x93\xAF",
      "placard" => "\xF0\x9F\xAA\xA7",
      "scroll" => "\xF0\x9F\x93\x9C",
      "page_with_curl" => "\xF0\x9F\x93\x83",
      "page_facing_up" => "\xF0\x9F\x93\x84",
      "bookmark_tabs" => "\xF0\x9F\x93\x91",
      "receipt" => "\xF0\x9F\xA7\xBE",
      "bar_chart" => "\xF0\x9F\x93\x8A",
      "chart_with_upwards_trend" => "\xF0\x9F\x93\x88",
      "chart_with_downwards_trend" => "\xF0\x9F\x93\x89",
      "notepad_spiral" => "\xF0\x9F\x97\x92\xEF\xB8\x8F",
      "spiral_note_pad" => "\xF0\x9F\x97\x92\xEF\xB8\x8F",
      "calendar_spiral" => "\xF0\x9F\x97\x93\xEF\xB8\x8F",
      "spiral_calendar_pad" => "\xF0\x9F\x97\x93\xEF\xB8\x8F",
      "calendar" => "\xF0\x9F\x93\x86",
      "date" => "\xF0\x9F\x93\x85",
      "wastebasket" => "\xF0\x9F\x97\x91\xEF\xB8\x8F",
      "card_index" => "\xF0\x9F\x93\x87",
      "card_box" => "\xF0\x9F\x97\x83\xEF\xB8\x8F",
      "card_file_box" => "\xF0\x9F\x97\x83\xEF\xB8\x8F",
      "ballot_box" => "\xF0\x9F\x97\xB3\xEF\xB8\x8F",
      "ballot_box_with_ballot" => "\xF0\x9F\x97\xB3\xEF\xB8\x8F",
      "file_cabinet" => "\xF0\x9F\x97\x84\xEF\xB8\x8F",
      "clipboard" => "\xF0\x9F\x93\x8B",
      "file_folder" => "\xF0\x9F\x93\x81",
      "open_file_folder" => "\xF0\x9F\x93\x82",
      "dividers" => "\xF0\x9F\x97\x82\xEF\xB8\x8F",
      "card_index_dividers" => "\xF0\x9F\x97\x82\xEF\xB8\x8F",
      "newspaper" => "\xF0\x9F\x93\xB0",
      "notebook" => "\xF0\x9F\x93\x93",
      "notebook_with_decorative_cover" => "\xF0\x9F\x93\x94",
      "ledger" => "\xF0\x9F\x93\x92",
      "closed_book" => "\xF0\x9F\x93\x95",
      "green_book" => "\xF0\x9F\x93\x97",
      "blue_book" => "\xF0\x9F\x93\x98",
      "orange_book" => "\xF0\x9F\x93\x99",
      "books" => "\xF0\x9F\x93\x9A",
      "book" => "\xF0\x9F\x93\x96",
      "bookmark" => "\xF0\x9F\x94\x96",
      "safety_pin" => "\xF0\x9F\xA7\xB7",
      "link" => "\xF0\x9F\x94\x97",
      "paperclip" => "\xF0\x9F\x93\x8E",
      "paperclips" => "\xF0\x9F\x96\x87\xEF\xB8\x8F",
      "linked_paperclips" => "\xF0\x9F\x96\x87\xEF\xB8\x8F",
      "triangular_ruler" => "\xF0\x9F\x93\x90",
      "straight_ruler" => "\xF0\x9F\x93\x8F",
      "abacus" => "\xF0\x9F\xA7\xAE",
      "pushpin" => "\xF0\x9F\x93\x8C",
      "round_pushpin" => "\xF0\x9F\x93\x8D",
      "scissors" => "\xE2\x9C\x82\xEF\xB8\x8F",
      "pen_ballpoint" => "\xF0\x9F\x96\x8A\xEF\xB8\x8F",
      "lower_left_ballpoint_pen" => "\xF0\x9F\x96\x8A\xEF\xB8\x8F",
      "pen_fountain" => "\xF0\x9F\x96\x8B\xEF\xB8\x8F",
      "lower_left_fountain_pen" => "\xF0\x9F\x96\x8B\xEF\xB8\x8F",
      "black_nib" => "\xE2\x9C\x92\xEF\xB8\x8F",
      "paintbrush" => "\xF0\x9F\x96\x8C\xEF\xB8\x8F",
      "lower_left_paintbrush" => "\xF0\x9F\x96\x8C\xEF\xB8\x8F",
      "crayon" => "\xF0\x9F\x96\x8D\xEF\xB8\x8F",
      "lower_left_crayon" => "\xF0\x9F\x96\x8D\xEF\xB8\x8F",
      "pencil" => "\xE2\x9C\x8F\xEF\xB8\x8F",
      "memo" => "\xE2\x9C\x8F\xEF\xB8\x8F",
      "mag" => "\xF0\x9F\x94\x8D",
      "mag_right" => "\xF0\x9F\x94\x8E",
      "lock_with_ink_pen" => "\xF0\x9F\x94\x8F",
      "closed_lock_with_key" => "\xF0\x9F\x94\x90",
      "lock" => "\xF0\x9F\x94\x92",
      "unlock" => "\xF0\x9F\x94\x93",
      "heart" => "\xE2\x9D\xA4\xEF\xB8\x8F",
      "orange_heart" => "\xF0\x9F\xA7\xA1",
      "money_with_wings" => "\xF0\x9F\x92\xB8",
      "dollar" => "\xF0\x9F\x92\xB5",
      "yen" => "\xF0\x9F\x92\xB4",
      "euro" => "\xF0\x9F\x92\xB6",
      "pound" => "\xF0\x9F\x92\xB7",
      "coin" => "\xF0\x9F\xAA\x99",
      "moneybag" => "\xF0\x9F\x92\xB0",
      "credit_card" => "\xF0\x9F\x92\xB3",
      "gem" => "\xF0\x9F\x92\x8E",
      "scales" => "\xE2\x9A\x96\xEF\xB8\x8F",
      "ladder" => "\xF0\x9F\xAA\x9C",
      "toolbox" => "\xF0\x9F\xA7\xB0",
      "screwdriver" => "\xF0\x9F\xAA\x9B",
      "wrench" => "\xF0\x9F\x94\xA7",
      "hammer" => "\xF0\x9F\x94\xA8",
      "hammer_pick" => "\xE2\x9A\x92\xEF\xB8\x8F",
      "hammer_and_pick" => "\xE2\x9A\x92\xEF\xB8\x8F",
      "tools" => "\xF0\x9F\x9B\xA0\xEF\xB8\x8F",
      "hammer_and_wrench" => "\xF0\x9F\x9B\xA0\xEF\xB8\x8F",
      "pick" => "\xE2\x9B\x8F\xEF\xB8\x8F",
      "nut_and_bolt" => "\xF0\x9F\x94\xA9",
      "bricks" => "\xF0\x9F\xA7\xB1",
      "chains" => "\xE2\x9B\x93\xEF\xB8\x8F",
      "hook" => "\xF0\x9F\xAA\x9D",
      "knot" => "\xF0\x9F\xAA\xA2",
      "magnet" => "\xF0\x9F\xA7\xB2",
      "gun" => "\xF0\x9F\x94\xAB",
      "bomb" => "\xF0\x9F\x92\xA3",
      "firecracker" => "\xF0\x9F\xA7\xA8",
      "axe" => "\xF0\x9F\xAA\x93",
      "carpentry_saw" => "\xF0\x9F\xAA\x9A",
      "knife" => "\xF0\x9F\x94\xAA",
      "dagger" => "\xF0\x9F\x97\xA1\xEF\xB8\x8F",
      "dagger_knife" => "\xF0\x9F\x97\xA1\xEF\xB8\x8F",
      "crossed_swords" => "\xE2\x9A\x94\xEF\xB8\x8F",
      "shield" => "\xF0\x9F\x9B\xA1\xEF\xB8\x8F",
      "smoking" => "\xF0\x9F\x9A\xAC",
      "coffin" => "\xE2\x9A\xB0\xEF\xB8\x8F",
      "headstone" => "\xF0\x9F\xAA\xA6",
      "urn" => "\xE2\x9A\xB1\xEF\xB8\x8F",
      "funeral_urn" => "\xE2\x9A\xB1\xEF\xB8\x8F",
      "amphora" => "\xF0\x9F\x8F\xBA",
      "magic_wand" => "\xF0\x9F\xAA\x84",
      "crystal_ball" => "\xF0\x9F\x94\xAE",
      "prayer_beads" => "\xF0\x9F\x93\xBF",
      "nazar_amulet" => "\xF0\x9F\xA7\xBF",
      "barber" => "\xF0\x9F\x92\x88",
      "alembic" => "\xE2\x9A\x97\xEF\xB8\x8F",
      "telescope" => "\xF0\x9F\x94\xAD",
      "microscope" => "\xF0\x9F\x94\xAC",
      "hole" => "\xF0\x9F\x95\xB3\xEF\xB8\x8F",
      "window" => "\xF0\x9F\xAA\x9F",
      "adhesive_bandage" => "\xF0\x9F\xA9\xB9",
      "stethoscope" => "\xF0\x9F\xA9\xBA",
      "pill" => "\xF0\x9F\x92\x8A",
      "syringe" => "\xF0\x9F\x92\x89",
      "drop_of_blood" => "\xF0\x9F\xA9\xB8",
      "dna" => "\xF0\x9F\xA7\xAC",
      "microbe" => "\xF0\x9F\xA6\xA0",
      "petri_dish" => "\xF0\x9F\xA7\xAB",
      "test_tube" => "\xF0\x9F\xA7\xAA",
      "thermometer" => "\xF0\x9F\x8C\xA1\xEF\xB8\x8F",
      "mouse_trap" => "\xF0\x9F\xAA\xA4",
      "broom" => "\xF0\x9F\xA7\xB9",
      "basket" => "\xF0\x9F\xA7\xBA",
      "sewing_needle" => "\xF0\x9F\xAA\xA1",
      "roll_of_paper" => "\xF0\x9F\xA7\xBB",
      "toilet" => "\xF0\x9F\x9A\xBD",
      "plunger" => "\xF0\x9F\xAA\xA0",
      "bucket" => "\xF0\x9F\xAA\xA3",
      "potable_water" => "\xF0\x9F\x9A\xB0",
      "shower" => "\xF0\x9F\x9A\xBF",
      "bathtub" => "\xF0\x9F\x9B\x81",
      "bath" => "\xF0\x9F\x9B\x80",
      "toothbrush" => "\xF0\x9F\xAA\xA5",
      "soap" => "\xF0\x9F\xA7\xBC",
      "razor" => "\xF0\x9F\xAA\x92",
      "sponge" => "\xF0\x9F\xA7\xBD",
      "squeeze_bottle" => "\xF0\x9F\xA7\xB4",
      "bellhop" => "\xF0\x9F\x9B\x8E\xEF\xB8\x8F",
      "bellhop_bell" => "\xF0\x9F\x9B\x8E\xEF\xB8\x8F",
      "key" => "\xF0\x9F\x97\x9D\xEF\xB8\x8F",
      "door" => "\xF0\x9F\x9A\xAA",
      "chair" => "\xF0\x9F\xAA\x91",
      "mirror" => "\xF0\x9F\xAA\x9E",
      "couch" => "\xF0\x9F\x9B\x8B\xEF\xB8\x8F",
      "couch_and_lamp" => "\xF0\x9F\x9B\x8B\xEF\xB8\x8F",
      "bed" => "\xF0\x9F\x9B\x8F\xEF\xB8\x8F",
      "sleeping_accommodation" => "\xF0\x9F\x9B\x8C",
      "teddy_bear" => "\xF0\x9F\xA7\xB8",
      "frame_photo" => "\xF0\x9F\x96\xBC\xEF\xB8\x8F",
      "frame_with_picture" => "\xF0\x9F\x96\xBC\xEF\xB8\x8F",
      "shopping_bags" => "\xF0\x9F\x9B\x8D\xEF\xB8\x8F",
      "shopping_cart" => "\xF0\x9F\x9B\x92",
      "shopping_trolley" => "\xF0\x9F\x9B\x92",
      "gift" => "\xF0\x9F\x8E\x81",
      "balloon" => "\xF0\x9F\x8E\x88",
      "flags" => "\xF0\x9F\x8E\x8F",
      "ribbon" => "\xF0\x9F\x8E\x80",
      "confetti_ball" => "\xF0\x9F\x8E\x8A",
      "tada" => "\xF0\x9F\x8E\x89",
      "pi" => "\xC3\xB1ata\xF0\x9F\xAA\x85",
      "nesting_dolls" => "\xF0\x9F\xAA\x86",
      "dolls" => "\xF0\x9F\x8E\x8E",
      "izakaya_lantern" => "\xF0\x9F\x8F\xAE",
      "construction_site" => "\xF0\x9F\x8F\x97\xEF\xB8\x8F",
      "building_construction" => "\xF0\x9F\x8F\x97\xEF\xB8\x8F",
      "factory" => "\xF0\x9F\x8F\xAD",
      "office" => "\xF0\x9F\x8F\xA2",
      "department_store" => "\xF0\x9F\x8F\xAC",
      "post_office" => "\xF0\x9F\x8F\xA3",
      "european_post_office" => "\xF0\x9F\x8F\xA4",
      "hospital" => "\xF0\x9F\x8F\xA5",
      "bank" => "\xF0\x9F\x8F\xA6",
      "hotel" => "\xF0\x9F\x8F\xA8",
      "convenience_store" => "\xF0\x9F\x8F\xAA",
      "school" => "\xF0\x9F\x8F\xAB",
      "love_hotel" => "\xF0\x9F\x8F\xA9",
      "wedding" => "\xF0\x9F\x92\x92",
      "classical_building" => "\xF0\x9F\x8F\x9B\xEF\xB8\x8F",
      "church" => "\xE2\x9B\xAA",
      "mosque" => "\xF0\x9F\x95\x8C",
      "synagogue" => "\xF0\x9F\x95\x8D",
      "hindu_temple" => "\xF0\x9F\x9B\x95",
      "kaaba" => "\xF0\x9F\x95\x8B",
      "shinto_shrine" => "\xE2\x9B\xA9\xEF\xB8\x8F",
      "railway_track" => "\xF0\x9F\x9B\xA4\xEF\xB8\x8F",
      "railroad_track" => "\xF0\x9F\x9B\xA4\xEF\xB8\x8F",
      "motorway" => "\xF0\x9F\x9B\xA3\xEF\xB8\x8F",
      "japan" => "\xF0\x9F\x97\xBE",
      "rice_scene" => "\xF0\x9F\x8E\x91",
      "park" => "\xF0\x9F\x8F\x9E\xEF\xB8\x8F",
      "national_park" => "\xF0\x9F\x8F\x9E\xEF\xB8\x8F",
      "sunrise" => "\xF0\x9F\x8C\x85",
      "sunrise_over_mountains" => "\xF0\x9F\x8C\x84",
      "stars" => "\xF0\x9F\x8C\xA0",
      "sparkler" => "\xF0\x9F\x8E\x87",
      "fireworks" => "\xF0\x9F\x8E\x86",
      "city_sunset" => "\xF0\x9F\x8C\x87",
      "city_sunrise" => "\xF0\x9F\x8C\x87",
      "city_dusk" => "\xF0\x9F\x8C\x86",
      "cityscape" => "\xF0\x9F\x8F\x99\xEF\xB8\x8F",
      "night_with_stars" => "\xF0\x9F\x8C\x83",
      "milky_way" => "\xF0\x9F\x8C\x8C",
      "bridge_at_night" => "\xF0\x9F\x8C\x89",
      "foggy" => "\xF0\x9F\x8C\x81",
      "watch" => "\xE2\x8C\x9A",
      "mobile_phone" => "\xF0\x9F\x93\xB1",
      "iphone" => "\xF0\x9F\x93\xB1",
      "calling" => "\xF0\x9F\x93\xB2",
      "computer" => "\xF0\x9F\x92\xBB",
      "keyboard" => "\xE2\x8C\xA8\xEF\xB8\x8F",
      "desktop" => "\xF0\x9F\x96\xA5\xEF\xB8\x8F",
      "desktop_computer" => "\xF0\x9F\x96\xA5\xEF\xB8\x8F",
      "printer" => "\xF0\x9F\x96\xA8\xEF\xB8\x8F",
      "mouse_three_button" => "\xF0\x9F\x96\xB1\xEF\xB8\x8F",
      "three_button_mouse" => "\xF0\x9F\x96\xB1\xEF\xB8\x8F",
      "trackball" => "\xF0\x9F\x96\xB2\xEF\xB8\x8F",
      "joystick" => "\xF0\x9F\x95\xB9\xEF\xB8\x8F",
      "compression" => "\xF0\x9F\x97\x9C\xEF\xB8\x8F",
      "minidisc" => "\xF0\x9F\x92\xBD",
      "floppy_disk" => "\xF0\x9F\x92\xBE",
      "cd" => "\xF0\x9F\x92\xBF",
      "dvd" => "\xF0\x9F\x93\x80",
      "vhs" => "\xF0\x9F\x93\xBC",
      "camera" => "\xF0\x9F\x93\xB7",
      "camera_with_flash" => "\xF0\x9F\x93\xB8",
      "video_camera" => "\xF0\x9F\x93\xB9",
      "movie_camera" => "\xF0\x9F\x8E\xA5",
      "projector" => "\xF0\x9F\x93\xBD\xEF\xB8\x8F",
      "film_projector" => "\xF0\x9F\x93\xBD\xEF\xB8\x8F",
      "film_frames" => "\xF0\x9F\x8E\x9E\xEF\xB8\x8F",
      "telephone_receiver" => "\xF0\x9F\x93\x9E",
      "telephone" => "\xE2\x98\x8E\xEF\xB8\x8F",
      "pager" => "\xF0\x9F\x93\x9F",
      "fax" => "\xF0\x9F\x93\xA0",
      "tv" => "\xF0\x9F\x93\xBA",
      "radio" => "\xF0\x9F\x93\xBB",
      "microphone" => "\xF0\x9F\x8E\xA4",
      "level_slider" => "\xF0\x9F\x8E\x9A\xEF\xB8\x8F",
      "control_knobs" => "\xF0\x9F\x8E\x9B\xEF\xB8\x8F",
      "compass" => "\xF0\x9F\xA7\xAD",
      "stopwatch" => "\xE2\x8F\xB1\xEF\xB8\x8F",
      "timer" => "\xE2\x8F\xB2\xEF\xB8\x8F",
      "timer_clock" => "\xE2\x8F\xB2\xEF\xB8\x8F",
      "alarm_clock" => "\xE2\x8F\xB0",
      "hourglass" => "\xE2\x8C\x9B",
      "hourglass_flowing_sand" => "\xE2\x8F\xB3",
      "satellite" => "\xF0\x9F\x93\xA1",
      "battery" => "\xF0\x9F\x94\x8B",
      "electric_plug" => "\xF0\x9F\x94\x8C",
      "bulb" => "\xF0\x9F\x92\xA1",
      "flashlight" => "\xF0\x9F\x94\xA6",
      "candle" => "\xF0\x9F\x95\xAF\xEF\xB8\x8F",
      "diya_lamp" => "\xF0\x9F\xAA\x94",
      "fire_extinguisher" => "\xF0\x9F\xA7\xAF",
      "oil" => "\xF0\x9F\x9B\xA2\xEF\xB8\x8F",
      "oil_drum" => "\xF0\x9F\x9B\xA2\xEF\xB8\x8F",
      "manual_wheelchair" => "\xF0\x9F\xA6\xBD",
      "motorized_wheelchair" => "\xF0\x9F\xA6\xBC",
      "scooter" => "\xF0\x9F\x9B\xB4",
      "bike" => "\xF0\x9F\x9A\xB2",
      "motor_scooter" => "\xF0\x9F\x9B\xB5",
      "motorbike" => "\xF0\x9F\x9B\xB5",
      "motorcycle" => "\xF0\x9F\x8F\x8D\xEF\xB8\x8F",
      "racing_motorcycle" => "\xF0\x9F\x8F\x8D\xEF\xB8\x8F",
      "auto_rickshaw" => "\xF0\x9F\x9B\xBA",
      "rotating_light" => "\xF0\x9F\x9A\xA8",
      "oncoming_police_car" => "\xF0\x9F\x9A\x94",
      "oncoming_bus" => "\xF0\x9F\x9A\x8D",
      "oncoming_automobile" => "\xF0\x9F\x9A\x98",
      "oncoming_taxi" => "\xF0\x9F\x9A\x96",
      "aerial_tramway" => "\xF0\x9F\x9A\xA1",
      "mountain_cableway" => "\xF0\x9F\x9A\xA0",
      "suspension_railway" => "\xF0\x9F\x9A\x9F",
      "railway_car" => "\xF0\x9F\x9A\x83",
      "train" => "\xF0\x9F\x9A\x86",
      "mountain_railway" => "\xF0\x9F\x9A\x9E",
      "monorail" => "\xF0\x9F\x9A\x9D",
      "bullettrain_side" => "\xF0\x9F\x9A\x84",
      "bullettrain_front" => "\xF0\x9F\x9A\x85",
      "light_rail" => "\xF0\x9F\x9A\x88",
      "steam_locomotive" => "\xF0\x9F\x9A\x82",
      "metro" => "\xF0\x9F\x9A\x87",
      "tram" => "\xF0\x9F\x9A\x8A",
      "station" => "\xF0\x9F\x9A\x89",
      "airplane" => "\xE2\x9C\x88\xEF\xB8\x8F",
      "airplane_departure" => "\xF0\x9F\x9B\xAB",
      "airplane_arriving" => "\xF0\x9F\x9B\xAC",
      "airplane_small" => "\xF0\x9F\x9B\xA9\xEF\xB8\x8F",
      "small_airplane" => "\xF0\x9F\x9B\xA9\xEF\xB8\x8F",
      "seat" => "\xF0\x9F\x92\xBA",
      "satellite_orbital" => "\xF0\x9F\x9B\xB0\xEF\xB8\x8F",
      "rocket" => "\xF0\x9F\x9A\x80",
      "flying_saucer" => "\xF0\x9F\x9B\xB8",
      "helicopter" => "\xF0\x9F\x9A\x81",
      "canoe" => "\xF0\x9F\x9B\xB6",
      "kayak" => "\xF0\x9F\x9B\xB6",
      "sailboat" => "\xE2\x9B\xB5",
      "speedboat" => "\xF0\x9F\x9A\xA4",
      "motorboat" => "\xF0\x9F\x9B\xA5\xEF\xB8\x8F",
      "cruise_ship" => "\xF0\x9F\x9B\xB3\xEF\xB8\x8F",
      "passenger_ship" => "\xF0\x9F\x9B\xB3\xEF\xB8\x8F",
      "ferry" => "\xE2\x9B\xB4\xEF\xB8\x8F",
      "ship" => "\xF0\x9F\x9A\xA2",
      "anchor" => "\xE2\x9A\x93",
      "fuelpump" => "\xE2\x9B\xBD",
      "construction" => "\xF0\x9F\x9A\xA7",
      "vertical_traffic_light" => "\xF0\x9F\x9A\xA6",
      "traffic_light" => "\xF0\x9F\x9A\xA5",
      "busstop" => "\xF0\x9F\x9A\x8F",
      "map" => "\xF0\x9F\x97\xBA\xEF\xB8\x8F",
      "world_map" => "\xF0\x9F\x97\xBA\xEF\xB8\x8F",
      "moyai" => "\xF0\x9F\x97\xBF",
      "statue_of_liberty" => "\xF0\x9F\x97\xBD",
      "tokyo_tower" => "\xF0\x9F\x97\xBC",
      "european_castle" => "\xF0\x9F\x8F\xB0",
      "japanese_castle" => "\xF0\x9F\x8F\xAF",
      "stadium" => "\xF0\x9F\x8F\x9F\xEF\xB8\x8F",
      "ferris_wheel" => "\xF0\x9F\x8E\xA1",
      "roller_coaster" => "\xF0\x9F\x8E\xA2",
      "carousel_horse" => "\xF0\x9F\x8E\xA0",
      "fountain" => "\xE2\x9B\xB2",
      "beach_umbrella" => "\xE2\x9B\xB1\xEF\xB8\x8F",
      "umbrella_on_ground" => "\xE2\x9B\xB1\xEF\xB8\x8F",
      "beach" => "\xF0\x9F\x8F\x96\xEF\xB8\x8F",
      "beach_with_umbrella" => "\xF0\x9F\x8F\x96\xEF\xB8\x8F",
      "island" => "\xF0\x9F\x8F\x9D\xEF\xB8\x8F",
      "desert_island" => "\xF0\x9F\x8F\x9D\xEF\xB8\x8F",
      "desert" => "\xF0\x9F\x8F\x9C\xEF\xB8\x8F",
      "volcano" => "\xF0\x9F\x8C\x8B",
      "mountain" => "\xE2\x9B\xB0\xEF\xB8\x8F",
      "mountain_snow" => "\xF0\x9F\x8F\x94\xEF\xB8\x8F",
      "snow_capped_mountain" => "\xF0\x9F\x8F\x94\xEF\xB8\x8F",
      "mount_fuji" => "\xF0\x9F\x97\xBB",
      "camping" => "\xF0\x9F\x8F\x95\xEF\xB8\x8F",
      "tent" => "\xE2\x9B\xBA",
      "house" => "\xF0\x9F\x8F\xA0",
      "house_with_garden" => "\xF0\x9F\x8F\xA1",
      "homes" => "\xF0\x9F\x8F\x98\xEF\xB8\x8F",
      "house_buildings" => "\xF0\x9F\x8F\x98\xEF\xB8\x8F",
      "house_abandoned" => "\xF0\x9F\x8F\x9A\xEF\xB8\x8F",
      "derelict_house_building" => "\xF0\x9F\x8F\x9A\xEF\xB8\x8F",
      "hut" => "\xF0\x9F\x9B\x96",
      "person_surfing" => "\xF0\x9F\x8F\x84",
      "surfer" => "\xF0\x9F\x8F\x84",
      "woman_surfing" => "\xF0\x9F\x8F\x84\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_surfing" => "\xF0\x9F\x8F\x84\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_swimming" => "\xF0\x9F\x8F\x8A",
      "swimmer" => "\xF0\x9F\x8F\x8A",
      "woman_swimming" => "\xF0\x9F\x8F\x8A\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_swimming" => "\xF0\x9F\x8F\x8A\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_playing_water_polo" => "\xF0\x9F\xA4\xBD",
      "water_polo" => "\xF0\x9F\xA4\xBD",
      "woman_playing_water_polo" => "\xF0\x9F\xA4\xBD\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_playing_water_polo" => "\xF0\x9F\xA4\xBD\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_rowing_boat" => "\xF0\x9F\x9A\xA3",
      "rowboat" => "\xF0\x9F\x9A\xA3",
      "woman_rowing_boat" => "\xF0\x9F\x9A\xA3\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_rowing_boat" => "\xF0\x9F\x9A\xA3\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_climbing" => "\xF0\x9F\xA7\x97",
      "woman_climbing" => "\xF0\x9F\xA7\x97\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_climbing" => "\xF0\x9F\xA7\x97\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_mountain_biking" => "\xF0\x9F\x9A\xB5",
      "mountain_bicyclist" => "\xF0\x9F\x9A\xB5",
      "woman_mountain_biking" => "\xF0\x9F\x9A\xB5\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_mountain_biking" => "\xF0\x9F\x9A\xB5\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_biking" => "\xF0\x9F\x9A\xB4",
      "bicyclist" => "\xF0\x9F\x9A\xB4",
      "woman_biking" => "\xF0\x9F\x9A\xB4\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_biking" => "\xF0\x9F\x9A\xB4\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "trophy" => "\xF0\x9F\x8F\x86",
      "first_place" => "\xF0\x9F\xA5\x87",
      "first_place_medal" => "\xF0\x9F\xA5\x87",
      "second_place" => "\xF0\x9F\xA5\x88",
      "second_place_medal" => "\xF0\x9F\xA5\x88",
      "third_place" => "\xF0\x9F\xA5\x89",
      "third_place_medal" => "\xF0\x9F\xA5\x89",
      "medal" => "\xF0\x9F\x8F\x85",
      "sports_medal" => "\xF0\x9F\x8F\x85",
      "military_medal" => "\xF0\x9F\x8E\x96\xEF\xB8\x8F",
      "rosette" => "\xF0\x9F\x8F\xB5\xEF\xB8\x8F",
      "reminder_ribbon" => "\xF0\x9F\x8E\x97\xEF\xB8\x8F",
      "ticket" => "\xF0\x9F\x8E\xAB",
      "tickets" => "\xF0\x9F\x8E\x9F\xEF\xB8\x8F",
      "admission_tickets" => "\xF0\x9F\x8E\x9F\xEF\xB8\x8F",
      "circus_tent" => "\xF0\x9F\x8E\xAA",
      "person_juggling" => "\xF0\x9F\xA4\xB9",
      "juggling" => "\xF0\x9F\xA4\xB9",
      "juggler" => "\xF0\x9F\xA4\xB9",
      "woman_juggling" => "\xF0\x9F\xA4\xB9\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_juggling" => "\xF0\x9F\xA4\xB9\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "performing_arts" => "\xF0\x9F\x8E\xAD",
      "ballet_shoes" => "\xF0\x9F\xA9\xB0",
      "art" => "\xF0\x9F\x8E\xA8",
      "clapper" => "\xF0\x9F\x8E\xAC",
      "headphones" => "\xF0\x9F\x8E\xA7",
      "musical_score" => "\xF0\x9F\x8E\xBC",
      "musical_keyboard" => "\xF0\x9F\x8E\xB9",
      "drum" => "\xF0\x9F\xA5\x81",
      "drum_with_drumsticks" => "\xF0\x9F\xA5\x81",
      "long_drum" => "\xF0\x9F\xAA\x98",
      "saxophone" => "\xF0\x9F\x8E\xB7",
      "trumpet" => "\xF0\x9F\x8E\xBA",
      "guitar" => "\xF0\x9F\x8E\xB8",
      "banjo" => "\xF0\x9F\xAA\x95",
      "violin" => "\xF0\x9F\x8E\xBB",
      "accordion" => "\xF0\x9F\xAA\x97",
      "game_die" => "\xF0\x9F\x8E\xB2",
      "chess_pawn" => "\xE2\x99\x9F\xEF\xB8\x8F",
      "dart" => "\xF0\x9F\x8E\xAF",
      "bowling" => "\xF0\x9F\x8E\xB3",
      "video_game" => "\xF0\x9F\x8E\xAE",
      "slot_machine" => "\xF0\x9F\x8E\xB0",
      "jigsaw" => "\xF0\x9F\xA7\xA9",
      "red_car" => "\xF0\x9F\x9A\x97",
      "taxi" => "\xF0\x9F\x9A\x95",
      "blue_car" => "\xF0\x9F\x9A\x99",
      "pickup_truck" => "\xF0\x9F\x9B\xBB",
      "bus" => "\xF0\x9F\x9A\x8C",
      "trolleybus" => "\xF0\x9F\x9A\x8E",
      "race_car" => "\xF0\x9F\x8F\x8E\xEF\xB8\x8F",
      "racing_car" => "\xF0\x9F\x8F\x8E\xEF\xB8\x8F",
      "police_car" => "\xF0\x9F\x9A\x93",
      "ambulance" => "\xF0\x9F\x9A\x91",
      "fire_engine" => "\xF0\x9F\x9A\x92",
      "minibus" => "\xF0\x9F\x9A\x90",
      "truck" => "\xF0\x9F\x9A\x9A",
      "articulated_lorry" => "\xF0\x9F\x9A\x9B",
      "tractor" => "\xF0\x9F\x9A\x9C",
      "probing_cane" => "\xF0\x9F\xA6\xAF",
      "fork_and_knife" => "\xF0\x9F\x8D\xB4",
      "fork_knife_plate" => "\xF0\x9F\x8D\xBD\xEF\xB8\x8F",
      "fork_and_knife_with_plate" => "\xF0\x9F\x8D\xBD\xEF\xB8\x8F",
      "bowl_with_spoon" => "\xF0\x9F\xA5\xA3",
      "takeout_box" => "\xF0\x9F\xA5\xA1",
      "chopsticks" => "\xF0\x9F\xA5\xA2",
      "salt" => "\xF0\x9F\xA7\x82",
      "soccer" => "\xE2\x9A\xBD",
      "basketball" => "\xF0\x9F\x8F\x80",
      "football" => "\xF0\x9F\x8F\x88",
      "baseball" => "\xE2\x9A\xBE",
      "softball" => "\xF0\x9F\xA5\x8E",
      "tennis" => "\xF0\x9F\x8E\xBE",
      "volleyball" => "\xF0\x9F\x8F\x90",
      "rugby_football" => "\xF0\x9F\x8F\x89",
      "flying_disc" => "\xF0\x9F\xA5\x8F",
      "boomerang" => "\xF0\x9F\xAA\x83",
      "ball" => "\xF0\x9F\x8E\xB1",
      "yo_yo" => "\xF0\x9F\xAA\x80",
      "ping_pong" => "\xF0\x9F\x8F\x93",
      "table_tennis" => "\xF0\x9F\x8F\x93",
      "badminton" => "\xF0\x9F\x8F\xB8",
      "hockey" => "\xF0\x9F\x8F\x92",
      "field_hockey" => "\xF0\x9F\x8F\x91",
      "lacrosse" => "\xF0\x9F\xA5\x8D",
      "cricket_game" => "\xF0\x9F\x8F\x8F",
      "cricket_bat_ball" => "\xF0\x9F\x8F\x8F",
      "goal" => "\xF0\x9F\xA5\x85",
      "goal_net" => "\xF0\x9F\xA5\x85",
      "golf" => "\xE2\x9B\xB3",
      "kite" => "\xF0\x9F\xAA\x81",
      "bow_and_arrow" => "\xF0\x9F\x8F\xB9",
      "archery" => "\xF0\x9F\x8F\xB9",
      "fishing_pole_and_fish" => "\xF0\x9F\x8E\xA3",
      "diving_mask" => "\xF0\x9F\xA4\xBF",
      "boxing_glove" => "\xF0\x9F\xA5\x8A",
      "boxing_gloves" => "\xF0\x9F\xA5\x8A",
      "martial_arts_uniform" => "\xF0\x9F\xA5\x8B",
      "karate_uniform" => "\xF0\x9F\xA5\x8B",
      "running_shirt_with_sash" => "\xF0\x9F\x8E\xBD",
      "skateboard" => "\xF0\x9F\x9B\xB9",
      "roller_skate" => "\xF0\x9F\x9B\xBC",
      "sled" => "\xF0\x9F\x9B\xB7",
      "ice_skate" => "\xE2\x9B\xB8\xEF\xB8\x8F",
      "curling_stone" => "\xF0\x9F\xA5\x8C",
      "ski" => "\xF0\x9F\x8E\xBF",
      "skier" => "\xE2\x9B\xB7\xEF\xB8\x8F",
      "snowboarder" => "\xF0\x9F\x8F\x82",
      "parachute" => "\xF0\x9F\xAA\x82",
      "person_lifting_weights" => "\xF0\x9F\x8F\x8B\xEF\xB8\x8F",
      "lifter" => "\xF0\x9F\x8F\x8B\xEF\xB8\x8F",
      "weight_lifter" => "\xF0\x9F\x8F\x8B\xEF\xB8\x8F",
      "woman_lifting_weights" => "\xF0\x9F\x8F\x8B\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_lifting_weights" => "\xF0\x9F\x8F\x8B\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "people_wrestling" => "\xF0\x9F\xA4\xBC",
      "wrestlers" => "\xF0\x9F\xA4\xBC",
      "wrestling" => "\xF0\x9F\xA4\xBC",
      "women_wrestling" => "\xF0\x9F\xA4\xBC\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "men_wrestling" => "\xF0\x9F\xA4\xBC\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_doing_cartwheel" => "\xF0\x9F\xA4\xB8",
      "cartwheel" => "\xF0\x9F\xA4\xB8",
      "woman_cartwheeling" => "\xF0\x9F\xA4\xB8\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_cartwheeling" => "\xF0\x9F\xA4\xB8\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_bouncing_ball" => "\xE2\x9B\xB9\xEF\xB8\x8F",
      "basketball_player" => "\xE2\x9B\xB9\xEF\xB8\x8F",
      "person_with_ball" => "\xE2\x9B\xB9\xEF\xB8\x8F",
      "woman_bouncing_ball" => "\xE2\x9B\xB9\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_bouncing_ball" => "\xE2\x9B\xB9\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_fencing" => "\xF0\x9F\xA4\xBA",
      "fencer" => "\xF0\x9F\xA4\xBA",
      "fencing" => "\xF0\x9F\xA4\xBA",
      "person_playing_handball" => "\xF0\x9F\xA4\xBE",
      "handball" => "\xF0\x9F\xA4\xBE",
      "woman_playing_handball" => "\xF0\x9F\xA4\xBE\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_playing_handball" => "\xF0\x9F\xA4\xBE\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_golfing" => "\xF0\x9F\x8F\x8C\xEF\xB8\x8F",
      "golfer" => "\xF0\x9F\x8F\x8C\xEF\xB8\x8F",
      "woman_golfing" => "\xF0\x9F\x8F\x8C\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_golfing" => "\xF0\x9F\x8F\x8C\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "horse_racing" => "\xF0\x9F\x8F\x87",
      "person_in_lotus_position" => "\xF0\x9F\xA7\x98",
      "woman_in_lotus_position" => "\xF0\x9F\xA7\x98\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_in_lotus_position" => "\xF0\x9F\xA7\x98\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "avocado" => "\xF0\x9F\xA5\x91",
      "olive" => "\xF0\x9F\xAB\x92",
      "broccoli" => "\xF0\x9F\xA5\xA6",
      "leafy_green" => "\xF0\x9F\xA5\xAC",
      "bell_pepper" => "\xF0\x9F\xAB\x91",
      "cucumber" => "\xF0\x9F\xA5\x92",
      "hot_pepper" => "\xF0\x9F\x8C\xB6\xEF\xB8\x8F",
      "corn" => "\xF0\x9F\x8C\xBD",
      "carrot" => "\xF0\x9F\xA5\x95",
      "garlic" => "\xF0\x9F\xA7\x84",
      "onion" => "\xF0\x9F\xA7\x85",
      "potato" => "\xF0\x9F\xA5\x94",
      "sweet_potato" => "\xF0\x9F\x8D\xA0",
      "croissant" => "\xF0\x9F\xA5\x90",
      "bagel" => "\xF0\x9F\xA5\xAF",
      "bread" => "\xF0\x9F\x8D\x9E",
      "french_bread" => "\xF0\x9F\xA5\x96",
      "baguette_bread" => "\xF0\x9F\xA5\x96",
      "flatbread" => "\xF0\x9F\xAB\x93",
      "pretzel" => "\xF0\x9F\xA5\xA8",
      "cheese" => "\xF0\x9F\xA7\x80",
      "cheese_wedge" => "\xF0\x9F\xA7\x80",
      "egg" => "\xF0\x9F\xA5\x9A",
      "cooking" => "\xF0\x9F\x8D\xB3",
      "butter" => "\xF0\x9F\xA7\x88",
      "pancakes" => "\xF0\x9F\xA5\x9E",
      "waffle" => "\xF0\x9F\xA7\x87",
      "bacon" => "\xF0\x9F\xA5\x93",
      "cut_of_meat" => "\xF0\x9F\xA5\xA9",
      "poultry_leg" => "\xF0\x9F\x8D\x97",
      "meat_on_bone" => "\xF0\x9F\x8D\x96",
      "hotdog" => "\xF0\x9F\x8C\xAD",
      "hot_dog" => "\xF0\x9F\x8C\xAD",
      "hamburger" => "\xF0\x9F\x8D\x94",
      "fries" => "\xF0\x9F\x8D\x9F",
      "pizza" => "\xF0\x9F\x8D\x95",
      "sandwich" => "\xF0\x9F\xA5\xAA",
      "stuffed_flatbread" => "\xF0\x9F\xA5\x99",
      "stuffed_pita" => "\xF0\x9F\xA5\x99",
      "falafel" => "\xF0\x9F\xA7\x86",
      "taco" => "\xF0\x9F\x8C\xAE",
      "burrito" => "\xF0\x9F\x8C\xAF",
      "tamale" => "\xF0\x9F\xAB\x94",
      "salad" => "\xF0\x9F\xA5\x97",
      "green_salad" => "\xF0\x9F\xA5\x97",
      "shallow_pan_of_food" => "\xF0\x9F\xA5\x98",
      "paella" => "\xF0\x9F\xA5\x98",
      "fondue" => "\xF0\x9F\xAB\x95",
      "canned_food" => "\xF0\x9F\xA5\xAB",
      "spaghetti" => "\xF0\x9F\x8D\x9D",
      "ramen" => "\xF0\x9F\x8D\x9C",
      "stew" => "\xF0\x9F\x8D\xB2",
      "curry" => "\xF0\x9F\x8D\x9B",
      "sushi" => "\xF0\x9F\x8D\xA3",
      "bento" => "\xF0\x9F\x8D\xB1",
      "dumpling" => "\xF0\x9F\xA5\x9F",
      "oyster" => "\xF0\x9F\xA6\xAA",
      "fried_shrimp" => "\xF0\x9F\x8D\xA4",
      "rice_ball" => "\xF0\x9F\x8D\x99",
      "rice" => "\xF0\x9F\x8D\x9A",
      "rice_cracker" => "\xF0\x9F\x8D\x98",
      "fish_cake" => "\xF0\x9F\x8D\xA5",
      "fortune_cookie" => "\xF0\x9F\xA5\xA0",
      "moon_cake" => "\xF0\x9F\xA5\xAE",
      "oden" => "\xF0\x9F\x8D\xA2",
      "dango" => "\xF0\x9F\x8D\xA1",
      "shaved_ice" => "\xF0\x9F\x8D\xA7",
      "ice_cream" => "\xF0\x9F\x8D\xA8",
      "icecream" => "\xF0\x9F\x8D\xA6",
      "pie" => "\xF0\x9F\xA5\xA7",
      "cupcake" => "\xF0\x9F\xA7\x81",
      "cake" => "\xF0\x9F\x8D\xB0",
      "birthday" => "\xF0\x9F\x8E\x82",
      "custard" => "\xF0\x9F\x8D\xAE",
      "pudding" => "\xF0\x9F\x8D\xAE",
      "flan" => "\xF0\x9F\x8D\xAE",
      "lollipop" => "\xF0\x9F\x8D\xAD",
      "candy" => "\xF0\x9F\x8D\xAC",
      "chocolate_bar" => "\xF0\x9F\x8D\xAB",
      "popcorn" => "\xF0\x9F\x8D\xBF",
      "doughnut" => "\xF0\x9F\x8D\xA9",
      "cookie" => "\xF0\x9F\x8D\xAA",
      "chestnut" => "\xF0\x9F\x8C\xB0",
      "peanuts" => "\xF0\x9F\xA5\x9C",
      "shelled_peanut" => "\xF0\x9F\xA5\x9C",
      "honey_pot" => "\xF0\x9F\x8D\xAF",
      "milk" => "\xF0\x9F\xA5\x9B",
      "glass_of_milk" => "\xF0\x9F\xA5\x9B",
      "baby_bottle" => "\xF0\x9F\x8D\xBC",
      "coffee" => "\xE2\x98\x95",
      "teapot" => "\xF0\x9F\xAB\x96",
      "mate" => "\xF0\x9F\xA7\x89",
      "bubble_tea" => "\xF0\x9F\xA7\x8B",
      "beverage_box" => "\xF0\x9F\xA7\x83",
      "cup_with_straw" => "\xF0\x9F\xA5\xA4",
      "sake" => "\xF0\x9F\x8D\xB6",
      "beer" => "\xF0\x9F\x8D\xBA",
      "beers" => "\xF0\x9F\x8D\xBB",
      "champagne_glass" => "\xF0\x9F\xA5\x82",
      "clinking_glass" => "\xF0\x9F\xA5\x82",
      "wine_glass" => "\xF0\x9F\x8D\xB7",
      "tumbler_glass" => "\xF0\x9F\xA5\x83",
      "whisky" => "\xF0\x9F\xA5\x83",
      "cocktail" => "\xF0\x9F\x8D\xB8",
      "tropical_drink" => "\xF0\x9F\x8D\xB9",
      "champagne" => "\xF0\x9F\x8D\xBE",
      "bottle_with_popping_cork" => "\xF0\x9F\x8D\xBE",
      "ice_cube" => "\xF0\x9F\xA7\x8A",
      "spoon" => "\xF0\x9F\xA5\x84",
      "ear_of_rice" => "\xF0\x9F\x8C\xBE",
      "potted_plant" => "\xF0\x9F\xAA\xB4",
      "bouquet" => "\xF0\x9F\x92\x90",
      "tulip" => "\xF0\x9F\x8C\xB7",
      "rose" => "\xF0\x9F\x8C\xB9",
      "wilted_rose" => "\xF0\x9F\xA5\x80",
      "wilted_flower" => "\xF0\x9F\xA5\x80",
      "hibiscus" => "\xF0\x9F\x8C\xBA",
      "cherry_blossom" => "\xF0\x9F\x8C\xB8",
      "blossom" => "\xF0\x9F\x8C\xBC",
      "sunflower" => "\xF0\x9F\x8C\xBB",
      "sun_with_face" => "\xF0\x9F\x8C\x9E",
      "full_moon_with_face" => "\xF0\x9F\x8C\x9D",
      "first_quarter_moon_with_face" => "\xF0\x9F\x8C\x9B",
      "last_quarter_moon_with_face" => "\xF0\x9F\x8C\x9C",
      "new_moon_with_face" => "\xF0\x9F\x8C\x9A",
      "full_moon" => "\xF0\x9F\x8C\x95",
      "waning_gibbous_moon" => "\xF0\x9F\x8C\x96",
      "last_quarter_moon" => "\xF0\x9F\x8C\x97",
      "waning_crescent_moon" => "\xF0\x9F\x8C\x98",
      "new_moon" => "\xF0\x9F\x8C\x91",
      "waxing_crescent_moon" => "\xF0\x9F\x8C\x92",
      "first_quarter_moon" => "\xF0\x9F\x8C\x93",
      "waxing_gibbous_moon" => "\xF0\x9F\x8C\x94",
      "crescent_moon" => "\xF0\x9F\x8C\x99",
      "earth_americas" => "\xF0\x9F\x8C\x8E",
      "earth_africa" => "\xF0\x9F\x8C\x8D",
      "earth_asia" => "\xF0\x9F\x8C\x8F",
      "ringed_planet" => "\xF0\x9F\xAA\x90",
      "dizzy" => "\xF0\x9F\x92\xAB",
      "star" => "\xF0\x9F\x8C\x9F",
      "sparkles" => "\xE2\x9C\xA8",
      "zap" => "\xE2\x9A\xA1",
      "comet" => "\xE2\x98\x84\xEF\xB8\x8F",
      "boom" => "\xF0\x9F\x92\xA5",
      "fire" => "\xF0\x9F\x94\xA5",
      "flame" => "\xF0\x9F\x94\xA5",
      "cloud_tornado" => "\xF0\x9F\x8C\xAA\xEF\xB8\x8F",
      "cloud_with_tornado" => "\xF0\x9F\x8C\xAA\xEF\xB8\x8F",
      "rainbow" => "\xF0\x9F\x8C\x88",
      "sunny" => "\xE2\x98\x80\xEF\xB8\x8F",
      "white_sun_small_cloud" => "\xF0\x9F\x8C\xA4\xEF\xB8\x8F",
      "white_sun_with_small_cloud" => "\xF0\x9F\x8C\xA4\xEF\xB8\x8F",
      "partly_sunny" => "\xE2\x9B\x85",
      "white_sun_cloud" => "\xF0\x9F\x8C\xA5\xEF\xB8\x8F",
      "white_sun_behind_cloud" => "\xF0\x9F\x8C\xA5\xEF\xB8\x8F",
      "cloud" => "\xE2\x98\x81\xEF\xB8\x8F",
      "white_sun_rain_cloud" => "\xF0\x9F\x8C\xA6\xEF\xB8\x8F",
      "white_sun_behind_cloud_with_rain" => "\xF0\x9F\x8C\xA6\xEF\xB8\x8F",
      "cloud_rain" => "\xF0\x9F\x8C\xA7\xEF\xB8\x8F",
      "cloud_with_rain" => "\xF0\x9F\x8C\xA7\xEF\xB8\x8F",
      "thunder_cloud_rain" => "\xE2\x9B\x88\xEF\xB8\x8F",
      "thunder_cloud_and_rain" => "\xE2\x9B\x88\xEF\xB8\x8F",
      "cloud_lightning" => "\xF0\x9F\x8C\xA9\xEF\xB8\x8F",
      "cloud_with_lightning" => "\xF0\x9F\x8C\xA9\xEF\xB8\x8F",
      "cloud_snow" => "\xF0\x9F\x8C\xA8\xEF\xB8\x8F",
      "cloud_with_snow" => "\xF0\x9F\x8C\xA8\xEF\xB8\x8F",
      "snowflake" => "\xE2\x9D\x84\xEF\xB8\x8F",
      "snowman" => "\xE2\x9B\x84",
      "wind_blowing_face" => "\xF0\x9F\x8C\xAC\xEF\xB8\x8F",
      "dash" => "\xF0\x9F\x92\xA8",
      "droplet" => "\xF0\x9F\x92\xA7",
      "sweat_drops" => "\xF0\x9F\x92\xA6",
      "umbrella" => "\xE2\x98\x82\xEF\xB8\x8F",
      "ocean" => "\xF0\x9F\x8C\x8A",
      "fog" => "\xF0\x9F\x8C\xAB\xEF\xB8\x8F",
      "green_apple" => "\xF0\x9F\x8D\x8F",
      "apple" => "\xF0\x9F\x8D\x8E",
      "pear" => "\xF0\x9F\x8D\x90",
      "tangerine" => "\xF0\x9F\x8D\x8A",
      "lemon" => "\xF0\x9F\x8D\x8B",
      "banana" => "\xF0\x9F\x8D\x8C",
      "watermelon" => "\xF0\x9F\x8D\x89",
      "grapes" => "\xF0\x9F\x8D\x87",
      "blueberries" => "\xF0\x9F\xAB\x90",
      "strawberry" => "\xF0\x9F\x8D\x93",
      "melon" => "\xF0\x9F\x8D\x88",
      "cherries" => "\xF0\x9F\x8D\x92",
      "peach" => "\xF0\x9F\x8D\x91",
      "mango" => "\xF0\x9F\xA5\xAD",
      "pineapple" => "\xF0\x9F\x8D\x8D",
      "coconut" => "\xF0\x9F\xA5\xA5",
      "kiwi" => "\xF0\x9F\xA5\x9D",
      "kiwifruit" => "\xF0\x9F\xA5\x9D",
      "tomato" => "\xF0\x9F\x8D\x85",
      "eggplant" => "\xF0\x9F\x8D\x86",
      "horse" => "\xF0\x9F\x90\xB4",
      "unicorn" => "\xF0\x9F\xA6\x84",
      "unicorn_face" => "\xF0\x9F\xA6\x84",
      "bee" => "\xF0\x9F\x90\x9D",
      "bug" => "\xF0\x9F\x90\x9B",
      "butterfly" => "\xF0\x9F\xA6\x8B",
      "snail" => "\xF0\x9F\x90\x8C",
      "worm" => "\xF0\x9F\xAA\xB1",
      "lady_beetle" => "\xF0\x9F\x90\x9E",
      "ant" => "\xF0\x9F\x90\x9C",
      "fly" => "\xF0\x9F\xAA\xB0",
      "mosquito" => "\xF0\x9F\xA6\x9F",
      "cockroach" => "\xF0\x9F\xAA\xB3",
      "beetle" => "\xF0\x9F\xAA\xB2",
      "cricket" => "\xF0\x9F\xA6\x97",
      "spider" => "\xF0\x9F\x95\xB7\xEF\xB8\x8F",
      "spider_web" => "\xF0\x9F\x95\xB8\xEF\xB8\x8F",
      "scorpion" => "\xF0\x9F\xA6\x82",
      "turtle" => "\xF0\x9F\x90\xA2",
      "snake" => "\xF0\x9F\x90\x8D",
      "lizard" => "\xF0\x9F\xA6\x8E",
      "t_rex" => "\xF0\x9F\xA6\x96",
      "sauropod" => "\xF0\x9F\xA6\x95",
      "octopus" => "\xF0\x9F\x90\x99",
      "squid" => "\xF0\x9F\xA6\x91",
      "shrimp" => "\xF0\x9F\xA6\x90",
      "lobster" => "\xF0\x9F\xA6\x9E",
      "crab" => "\xF0\x9F\xA6\x80",
      "blowfish" => "\xF0\x9F\x90\xA1",
      "tropical_fish" => "\xF0\x9F\x90\xA0",
      "fish" => "\xF0\x9F\x90\x9F",
      "seal" => "\xF0\x9F\xA6\xAD",
      "dolphin" => "\xF0\x9F\x90\xAC",
      "whale" => "\xF0\x9F\x90\x8B",
      "shark" => "\xF0\x9F\xA6\x88",
      "crocodile" => "\xF0\x9F\x90\x8A",
      "tiger" => "\xF0\x9F\x90\xAF",
      "leopard" => "\xF0\x9F\x90\x86",
      "zebra" => "\xF0\x9F\xA6\x93",
      "gorilla" => "\xF0\x9F\xA6\x8D",
      "orangutan" => "\xF0\x9F\xA6\xA7",
      "elephant" => "\xF0\x9F\x90\x98",
      "mammoth" => "\xF0\x9F\xA6\xA3",
      "bison" => "\xF0\x9F\xA6\xAC",
      "hippopotamus" => "\xF0\x9F\xA6\x9B",
      "rhino" => "\xF0\x9F\xA6\x8F",
      "rhinoceros" => "\xF0\x9F\xA6\x8F",
      "dromedary_camel" => "\xF0\x9F\x90\xAA",
      "camel" => "\xF0\x9F\x90\xAB",
      "giraffe" => "\xF0\x9F\xA6\x92",
      "kangaroo" => "\xF0\x9F\xA6\x98",
      "water_buffalo" => "\xF0\x9F\x90\x83",
      "ox" => "\xF0\x9F\x90\x82",
      "cow" => "\xF0\x9F\x90\xAE",
      "racehorse" => "\xF0\x9F\x90\x8E",
      "pig" => "\xF0\x9F\x90\xB7",
      "ram" => "\xF0\x9F\x90\x8F",
      "sheep" => "\xF0\x9F\x90\x91",
      "llama" => "\xF0\x9F\xA6\x99",
      "goat" => "\xF0\x9F\x90\x90",
      "deer" => "\xF0\x9F\xA6\x8C",
      "dog" => "\xF0\x9F\x90\xB6",
      "poodle" => "\xF0\x9F\x90\xA9",
      "guide_dog" => "\xF0\x9F\xA6\xAE",
      "service_dog" => "\xF0\x9F\x90\x95\xE2\x80\x8D\xF0\x9F\xA6\xBA",
      "cat" => "\xF0\x9F\x90\xB1",
      "black_cat" => "\xF0\x9F\x90\x88\xE2\x80\x8D\xE2\xAC\x9B",
      "rooster" => "\xF0\x9F\x90\x93",
      "turkey" => "\xF0\x9F\xA6\x83",
      "peacock" => "\xF0\x9F\xA6\x9A",
      "parrot" => "\xF0\x9F\xA6\x9C",
      "swan" => "\xF0\x9F\xA6\xA2",
      "flamingo" => "\xF0\x9F\xA6\xA9",
      "dove" => "\xF0\x9F\x95\x8A\xEF\xB8\x8F",
      "dove_of_peace" => "\xF0\x9F\x95\x8A\xEF\xB8\x8F",
      "rabbit" => "\xF0\x9F\x90\xB0",
      "raccoon" => "\xF0\x9F\xA6\x9D",
      "skunk" => "\xF0\x9F\xA6\xA8",
      "badger" => "\xF0\x9F\xA6\xA1",
      "beaver" => "\xF0\x9F\xA6\xAB",
      "otter" => "\xF0\x9F\xA6\xA6",
      "sloth" => "\xF0\x9F\xA6\xA5",
      "mouse" => "\xF0\x9F\x90\xAD",
      "rat" => "\xF0\x9F\x90\x80",
      "chipmunk" => "\xF0\x9F\x90\xBF\xEF\xB8\x8F",
      "hedgehog" => "\xF0\x9F\xA6\x94",
      "feet" => "\xF0\x9F\x90\xBE",
      "paw_prints" => "\xF0\x9F\x90\xBE",
      "dragon" => "\xF0\x9F\x90\x89",
      "dragon_face" => "\xF0\x9F\x90\xB2",
      "cactus" => "\xF0\x9F\x8C\xB5",
      "christmas_tree" => "\xF0\x9F\x8E\x84",
      "evergreen_tree" => "\xF0\x9F\x8C\xB2",
      "deciduous_tree" => "\xF0\x9F\x8C\xB3",
      "palm_tree" => "\xF0\x9F\x8C\xB4",
      "seedling" => "\xF0\x9F\x8C\xB1",
      "herb" => "\xF0\x9F\x8C\xBF",
      "shamrock" => "\xE2\x98\x98\xEF\xB8\x8F",
      "four_leaf_clover" => "\xF0\x9F\x8D\x80",
      "bamboo" => "\xF0\x9F\x8E\x8D",
      "tanabata_tree" => "\xF0\x9F\x8E\x8B",
      "leaves" => "\xF0\x9F\x8D\x83",
      "family_woman_girl" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_woman_girl_boy" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_woman_boy_boy" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_woman_girl_girl" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_man_boy" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_man_girl" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_man_girl_boy" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_man_boy_boy" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_man_girl_girl" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "yarn" => "\xF0\x9F\xA7\xB6",
      "thread" => "\xF0\x9F\xA7\xB5",
      "coat" => "\xF0\x9F\xA7\xA5",
      "lab_coat" => "\xF0\x9F\xA5\xBC",
      "safety_vest" => "\xF0\x9F\xA6\xBA",
      "womans_clothes" => "\xF0\x9F\x91\x9A",
      "shirt" => "\xF0\x9F\x91\x95",
      "jeans" => "\xF0\x9F\x91\x96",
      "briefs" => "\xF0\x9F\xA9\xB2",
      "shorts" => "\xF0\x9F\xA9\xB3",
      "necktie" => "\xF0\x9F\x91\x94",
      "dress" => "\xF0\x9F\x91\x97",
      "bikini" => "\xF0\x9F\x91\x99",
      "one_piece_swimsuit" => "\xF0\x9F\xA9\xB1",
      "kimono" => "\xF0\x9F\x91\x98",
      "sari" => "\xF0\x9F\xA5\xBB",
      "womans_flat_shoe" => "\xF0\x9F\xA5\xBF",
      "high_heel" => "\xF0\x9F\x91\xA0",
      "sandal" => "\xF0\x9F\x91\xA1",
      "boot" => "\xF0\x9F\x91\xA2",
      "mans_shoe" => "\xF0\x9F\x91\x9E",
      "athletic_shoe" => "\xF0\x9F\x91\x9F",
      "hiking_boot" => "\xF0\x9F\xA5\xBE",
      "thong_sandal" => "\xF0\x9F\xA9\xB4",
      "socks" => "\xF0\x9F\xA7\xA6",
      "gloves" => "\xF0\x9F\xA7\xA4",
      "scarf" => "\xF0\x9F\xA7\xA3",
      "tophat" => "\xF0\x9F\x8E\xA9",
      "billed_cap" => "\xF0\x9F\xA7\xA2",
      "womans_hat" => "\xF0\x9F\x91\x92",
      "mortar_board" => "\xF0\x9F\x8E\x93",
      "helmet_with_cross" => "\xE2\x9B\x91\xEF\xB8\x8F",
      "helmet_with_white_cross" => "\xE2\x9B\x91\xEF\xB8\x8F",
      "military_helmet" => "\xF0\x9F\xAA\x96",
      "crown" => "\xF0\x9F\x91\x91",
      "ring" => "\xF0\x9F\x92\x8D",
      "pouch" => "\xF0\x9F\x91\x9D",
      "purse" => "\xF0\x9F\x91\x9B",
      "handbag" => "\xF0\x9F\x91\x9C",
      "briefcase" => "\xF0\x9F\x92\xBC",
      "school_satchel" => "\xF0\x9F\x8E\x92",
      "luggage" => "\xF0\x9F\xA7\xB3",
      "eyeglasses" => "\xF0\x9F\x91\x93",
      "dark_sunglasses" => "\xF0\x9F\x95\xB6\xEF\xB8\x8F",
      "goggles" => "\xF0\x9F\xA5\xBD",
      "closed_umbrella" => "\xF0\x9F\x8C\x82",
      "hamster" => "\xF0\x9F\x90\xB9",
      "fox" => "\xF0\x9F\xA6\x8A",
      "fox_face" => "\xF0\x9F\xA6\x8A",
      "bear" => "\xF0\x9F\x90\xBB",
      "panda_face" => "\xF0\x9F\x90\xBC",
      "polar_bear" => "\xF0\x9F\x90\xBB\xE2\x80\x8D\xE2\x9D\x84\xEF\xB8\x8F",
      "koala" => "\xF0\x9F\x90\xA8",
      "lion_face" => "\xF0\x9F\xA6\x81",
      "lion" => "\xF0\x9F\xA6\x81",
      "pig_nose" => "\xF0\x9F\x90\xBD",
      "frog" => "\xF0\x9F\x90\xB8",
      "monkey_face" => "\xF0\x9F\x90\xB5",
      "see_no_evil" => "\xF0\x9F\x99\x88",
      "hear_no_evil" => "\xF0\x9F\x99\x89",
      "speak_no_evil" => "\xF0\x9F\x99\x8A",
      "monkey" => "\xF0\x9F\x90\x92",
      "chicken" => "\xF0\x9F\x90\x94",
      "penguin" => "\xF0\x9F\x90\xA7",
      "bird" => "\xF0\x9F\x90\xA6",
      "baby_chick" => "\xF0\x9F\x90\xA4",
      "hatching_chick" => "\xF0\x9F\x90\xA3",
      "hatched_chick" => "\xF0\x9F\x90\xA5",
      "duck" => "\xF0\x9F\xA6\x86",
      "dodo" => "\xF0\x9F\xA6\xA4",
      "eagle" => "\xF0\x9F\xA6\x85",
      "owl" => "\xF0\x9F\xA6\x89",
      "bat" => "\xF0\x9F\xA6\x87",
      "wolf" => "\xF0\x9F\x90\xBA",
      "boar" => "\xF0\x9F\x90\x97",
      "man_dancing" => "\xF0\x9F\x95\xBA",
      "male_dancer" => "\xF0\x9F\x95\xBA",
      "people_with_bunny_ears_partying" => "\xF0\x9F\x91\xAF",
      "dancers" => "\xF0\x9F\x91\xAF",
      "women_with_bunny_ears_partying" => "\xF0\x9F\x91\xAF\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "men_with_bunny_ears_partying" => "\xF0\x9F\x91\xAF\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "levitate" => "\xF0\x9F\x95\xB4\xEF\xB8\x8F",
      "man_in_business_suit_levitating" => "\xF0\x9F\x95\xB4\xEF\xB8\x8F",
      "person_in_manual_wheelchair" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xBD",
      "woman_in_manual_wheelchair" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xBD",
      "man_in_manual_wheelchair" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xBD",
      "person_in_motorized_wheelchair" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xBC",
      "woman_in_motorized_wheelchair" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xBC",
      "man_in_motorized_wheelchair" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xBC",
      "person_walking" => "\xF0\x9F\x9A\xB6",
      "walking" => "\xF0\x9F\x9A\xB6",
      "woman_walking" => "\xF0\x9F\x9A\xB6\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_walking" => "\xF0\x9F\x9A\xB6\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_with_probing_cane" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xAF",
      "woman_with_probing_cane" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xAF",
      "man_with_probing_cane" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xAF",
      "person_kneeling" => "\xF0\x9F\xA7\x8E",
      "woman_kneeling" => "\xF0\x9F\xA7\x8E\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_kneeling" => "\xF0\x9F\xA7\x8E\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_running" => "\xF0\x9F\x8F\x83",
      "runner" => "\xF0\x9F\x8F\x83",
      "woman_running" => "\xF0\x9F\x8F\x83\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_running" => "\xF0\x9F\x8F\x83\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_standing" => "\xF0\x9F\xA7\x8D",
      "woman_standing" => "\xF0\x9F\xA7\x8D\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_standing" => "\xF0\x9F\xA7\x8D\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "people_holding_hands" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA4\x9D\xE2\x80\x8D\xF0\x9F\xA7\x91",
      "couple" => "\xF0\x9F\x91\xAB",
      "two_women_holding_hands" => "\xF0\x9F\x91\xAD",
      "two_men_holding_hands" => "\xF0\x9F\x91\xAC",
      "couple_with_heart" => "\xF0\x9F\x92\x91",
      "couple_with_heart_woman_man" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA8",
      "couple_ww" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA9",
      "couple_with_heart_ww" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA9",
      "couple_mm" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA8",
      "couple_with_heart_mm" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA8",
      "couplekiss" => "\xF0\x9F\x92\x8F",
      "kiss_woman_man" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA8",
      "kiss_ww" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA9",
      "couplekiss_ww" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA9",
      "kiss_mm" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA8",
      "couplekiss_mm" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA8",
      "family" => "\xF0\x9F\x91\xAA",
      "family_man_woman_boy" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_mwg" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_mwgb" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_mwbb" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_mwgg" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_wwb" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_wwg" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_wwgb" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_wwbb" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_wwgg" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_mmb" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_mmg" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_mmgb" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_mmbb" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "family_mmgg" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7",
      "family_woman_boy" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6",
      "woman_zombie" => "\xF0\x9F\xA7\x9F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_zombie" => "\xF0\x9F\xA7\x9F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "genie" => "\xF0\x9F\xA7\x9E",
      "woman_genie" => "\xF0\x9F\xA7\x9E\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_genie" => "\xF0\x9F\xA7\x9E\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "merperson" => "\xF0\x9F\xA7\x9C",
      "mermaid" => "\xF0\x9F\xA7\x9C\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "merman" => "\xF0\x9F\xA7\x9C\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "fairy" => "\xF0\x9F\xA7\x9A",
      "woman_fairy" => "\xF0\x9F\xA7\x9A\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_fairy" => "\xF0\x9F\xA7\x9A\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "angel" => "\xF0\x9F\x91\xBC",
      "pregnant_woman" => "\xF0\x9F\xA4\xB0",
      "expecting_woman" => "\xF0\x9F\xA4\xB0",
      "breast_feeding" => "\xF0\x9F\xA4\xB1",
      "person_feeding_baby" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8D\xBC",
      "woman_feeding_baby" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8D\xBC",
      "man_feeding_baby" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8D\xBC",
      "person_bowing" => "\xF0\x9F\x99\x87",
      "bow" => "\xF0\x9F\x99\x87",
      "woman_bowing" => "\xF0\x9F\x99\x87\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_bowing" => "\xF0\x9F\x99\x87\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_tipping_hand" => "\xF0\x9F\x92\x81",
      "information_desk_person" => "\xF0\x9F\x92\x81",
      "woman_tipping_hand" => "\xF0\x9F\x92\x81\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_tipping_hand" => "\xF0\x9F\x92\x81\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_gesturing_no" => "\xF0\x9F\x99\x85",
      "no_good" => "\xF0\x9F\x99\x85",
      "woman_gesturing_no" => "\xF0\x9F\x99\x85\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_gesturing_no" => "\xF0\x9F\x99\x85\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_gesturing_ok" => "\xF0\x9F\x99\x86",
      "ok_woman" => "\xF0\x9F\x99\x86",
      "woman_gesturing_ok" => "\xF0\x9F\x99\x86\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_gesturing_ok" => "\xF0\x9F\x99\x86\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_raising_hand" => "\xF0\x9F\x99\x8B",
      "raising_hand" => "\xF0\x9F\x99\x8B",
      "woman_raising_hand" => "\xF0\x9F\x99\x8B\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_raising_hand" => "\xF0\x9F\x99\x8B\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "deaf_person" => "\xF0\x9F\xA7\x8F",
      "deaf_woman" => "\xF0\x9F\xA7\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "deaf_man" => "\xF0\x9F\xA7\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_facepalming" => "\xF0\x9F\xA4\xA6",
      "face_palm" => "\xF0\x9F\xA4\xA6",
      "facepalm" => "\xF0\x9F\xA4\xA6",
      "woman_facepalming" => "\xF0\x9F\xA4\xA6\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_facepalming" => "\xF0\x9F\xA4\xA6\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_shrugging" => "\xF0\x9F\xA4\xB7",
      "shrug" => "\xF0\x9F\xA4\xB7",
      "woman_shrugging" => "\xF0\x9F\xA4\xB7\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_shrugging" => "\xF0\x9F\xA4\xB7\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_pouting" => "\xF0\x9F\x99\x8E",
      "person_with_pouting_face" => "\xF0\x9F\x99\x8E",
      "woman_pouting" => "\xF0\x9F\x99\x8E\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_pouting" => "\xF0\x9F\x99\x8E\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_frowning" => "\xF0\x9F\x99\x8D",
      "woman_frowning" => "\xF0\x9F\x99\x8D\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_frowning" => "\xF0\x9F\x99\x8D\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_getting_haircut" => "\xF0\x9F\x92\x87",
      "haircut" => "\xF0\x9F\x92\x87",
      "woman_getting_haircut" => "\xF0\x9F\x92\x87\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_getting_haircut" => "\xF0\x9F\x92\x87\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_getting_massage" => "\xF0\x9F\x92\x86",
      "massage" => "\xF0\x9F\x92\x86",
      "woman_getting_face_massage" => "\xF0\x9F\x92\x86\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_getting_face_massage" => "\xF0\x9F\x92\x86\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_in_steamy_room" => "\xF0\x9F\xA7\x96",
      "woman_in_steamy_room" => "\xF0\x9F\xA7\x96\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_in_steamy_room" => "\xF0\x9F\xA7\x96\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "nail_care" => "\xF0\x9F\x92\x85",
      "selfie" => "\xF0\x9F\xA4\xB3",
      "dancer" => "\xF0\x9F\x92\x83",
      "farmer" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8C\xBE",
      "woman_farmer" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8C\xBE",
      "man_farmer" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8C\xBE",
      "cook" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8D\xB3",
      "woman_cook" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8D\xB3",
      "man_cook" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8D\xB3",
      "student" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\x93",
      "woman_student" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8E\x93",
      "man_student" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8E\x93",
      "singer" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\xA4",
      "woman_singer" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8E\xA4",
      "man_singer" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8E\xA4",
      "teacher" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8F\xAB",
      "woman_teacher" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8F\xAB",
      "man_teacher" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8F\xAB",
      "factory_worker" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8F\xAD",
      "woman_factory_worker" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8F\xAD",
      "man_factory_worker" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8F\xAD",
      "technologist" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x92\xBB",
      "woman_technologist" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x92\xBB",
      "man_technologist" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x92\xBB",
      "office_worker" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x92\xBC",
      "woman_office_worker" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x92\xBC",
      "man_office_worker" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x92\xBC",
      "mechanic" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x94\xA7",
      "woman_mechanic" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x94\xA7",
      "man_mechanic" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x94\xA7",
      "scientist" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x94\xAC",
      "woman_scientist" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x94\xAC",
      "man_scientist" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x94\xAC",
      "artist" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\xA8",
      "woman_artist" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8E\xA8",
      "man_artist" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8E\xA8",
      "firefighter" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x9A\x92",
      "woman_firefighter" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x9A\x92",
      "man_firefighter" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x9A\x92",
      "pilot" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xE2\x9C\x88\xEF\xB8\x8F",
      "woman_pilot" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9C\x88\xEF\xB8\x8F",
      "man_pilot" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9C\x88\xEF\xB8\x8F",
      "astronaut" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x9A\x80",
      "woman_astronaut" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x9A\x80",
      "man_astronaut" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x9A\x80",
      "judge" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xE2\x9A\x96\xEF\xB8\x8F",
      "woman_judge" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9A\x96\xEF\xB8\x8F",
      "man_judge" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9A\x96\xEF\xB8\x8F",
      "person_with_veil" => "\xF0\x9F\x91\xB0",
      "woman_with_veil" => "\xF0\x9F\x91\xB0\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "bride_with_veil" => "\xF0\x9F\x91\xB0\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_with_veil" => "\xF0\x9F\x91\xB0\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_in_tuxedo" => "\xF0\x9F\xA4\xB5",
      "woman_in_tuxedo" => "\xF0\x9F\xA4\xB5\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_in_tuxedo" => "\xF0\x9F\xA4\xB5\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "princess" => "\xF0\x9F\x91\xB8",
      "prince" => "\xF0\x9F\xA4\xB4",
      "superhero" => "\xF0\x9F\xA6\xB8",
      "woman_superhero" => "\xF0\x9F\xA6\xB8\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_superhero" => "\xF0\x9F\xA6\xB8\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "supervillain" => "\xF0\x9F\xA6\xB9",
      "woman_supervillain" => "\xF0\x9F\xA6\xB9\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_supervillain" => "\xF0\x9F\xA6\xB9\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "ninja" => "\xF0\x9F\xA5\xB7",
      "mx_claus" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\x84",
      "mrs_claus" => "\xF0\x9F\xA4\xB6",
      "mother_christmas" => "\xF0\x9F\xA4\xB6",
      "santa" => "\xF0\x9F\x8E\x85",
      "mage" => "\xF0\x9F\xA7\x99",
      "woman_mage" => "\xF0\x9F\xA7\x99\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_mage" => "\xF0\x9F\xA7\x99\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "elf" => "\xF0\x9F\xA7\x9D",
      "woman_elf" => "\xF0\x9F\xA7\x9D\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_elf" => "\xF0\x9F\xA7\x9D\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "vampire" => "\xF0\x9F\xA7\x9B",
      "woman_vampire" => "\xF0\x9F\xA7\x9B\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_vampire" => "\xF0\x9F\xA7\x9B\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "zombie" => "\xF0\x9F\xA7\x9F",
      "leg" => "\xF0\x9F\xA6\xB5",
      "mechanical_leg" => "\xF0\x9F\xA6\xBF",
      "lipstick" => "\xF0\x9F\x92\x84",
      "kiss" => "\xF0\x9F\x92\x8B",
      "lips" => "\xF0\x9F\x91\x84",
      "tooth" => "\xF0\x9F\xA6\xB7",
      "tongue" => "\xF0\x9F\x91\x85",
      "ear" => "\xF0\x9F\x91\x82",
      "ear_with_hearing_aid" => "\xF0\x9F\xA6\xBB",
      "nose" => "\xF0\x9F\x91\x83",
      "footprints" => "\xF0\x9F\x91\xA3",
      "eye" => "\xF0\x9F\x91\x81\xEF\xB8\x8F",
      "brain" => "\xF0\x9F\xA7\xA0",
      "anatomical_heart" => "\xF0\x9F\xAB\x80",
      "lungs" => "\xF0\x9F\xAB\x81",
      "bone" => "\xF0\x9F\xA6\xB4",
      "speaking_head" => "\xF0\x9F\x97\xA3\xEF\xB8\x8F",
      "speaking_head_in_silhouette" => "\xF0\x9F\x97\xA3\xEF\xB8\x8F",
      "bust_in_silhouette" => "\xF0\x9F\x91\xA4",
      "busts_in_silhouette" => "\xF0\x9F\x91\xA5",
      "people_hugging" => "\xF0\x9F\xAB\x82",
      "baby" => "\xF0\x9F\x91\xB6",
      "girl" => "\xF0\x9F\x91\xA7",
      "child" => "\xF0\x9F\xA7\x92",
      "boy" => "\xF0\x9F\x91\xA6",
      "woman" => "\xF0\x9F\x91\xA9",
      "adult" => "\xF0\x9F\xA7\x91",
      "man" => "\xF0\x9F\x91\xA8",
      "person_curly_hair" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB1",
      "woman_curly_haired" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB1",
      "man_curly_haired" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB1",
      "person_red_hair" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB0",
      "woman_red_haired" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB0",
      "man_red_haired" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB0",
      "blond_haired_woman" => "\xF0\x9F\x91\xB1\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "blond_haired_person" => "\xF0\x9F\x91\xB1",
      "person_with_blond_hair" => "\xF0\x9F\x91\xB1",
      "blond_haired_man" => "\xF0\x9F\x91\xB1\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "person_white_hair" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB3",
      "woman_white_haired" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB3",
      "man_white_haired" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB3",
      "person_bald" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB2",
      "woman_bald" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB2",
      "man_bald" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB2",
      "bearded_person" => "\xF0\x9F\xA7\x94",
      "man_beard" => "\xF0\x9F\xA7\x94\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "woman_beard" => "\xF0\x9F\xA7\x94\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "older_woman" => "\xF0\x9F\x91\xB5",
      "grandma" => "\xF0\x9F\x91\xB5",
      "older_adult" => "\xF0\x9F\xA7\x93",
      "older_man" => "\xF0\x9F\x91\xB4",
      "man_with_chinese_cap" => "\xF0\x9F\x91\xB2",
      "man_with_gua_pi_mao" => "\xF0\x9F\x91\xB2",
      "person_wearing_turban" => "\xF0\x9F\x91\xB3",
      "man_with_turban" => "\xF0\x9F\x91\xB3",
      "woman_wearing_turban" => "\xF0\x9F\x91\xB3\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_wearing_turban" => "\xF0\x9F\x91\xB3\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "woman_with_headscarf" => "\xF0\x9F\xA7\x95",
      "police_officer" => "\xF0\x9F\x91\xAE",
      "cop" => "\xF0\x9F\x91\xAE",
      "woman_police_officer" => "\xF0\x9F\x91\xAE\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_police_officer" => "\xF0\x9F\x91\xAE\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "construction_worker" => "\xF0\x9F\x91\xB7",
      "woman_construction_worker" => "\xF0\x9F\x91\xB7\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_construction_worker" => "\xF0\x9F\x91\xB7\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "guard" => "\xF0\x9F\x92\x82",
      "guardsman" => "\xF0\x9F\x92\x82",
      "woman_guard" => "\xF0\x9F\x92\x82\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_guard" => "\xF0\x9F\x92\x82\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "detective" => "\xF0\x9F\x95\xB5\xEF\xB8\x8F",
      "spy" => "\xF0\x9F\x95\xB5\xEF\xB8\x8F",
      "sleuth_or_spy" => "\xF0\x9F\x95\xB5\xEF\xB8\x8F",
      "woman_detective" => "\xF0\x9F\x95\xB5\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F",
      "man_detective" => "\xF0\x9F\x95\xB5\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F",
      "health_worker" => "\xF0\x9F\xA7\x91\xE2\x80\x8D\xE2\x9A\x95\xEF\xB8\x8F",
      "woman_health_worker" => "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9A\x95\xEF\xB8\x8F",
      "man_health_worker" => "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9A\x95\xEF\xB8\x8F",
      "grimacing" => "\xF0\x9F\x98\xAC",
      "rolling_eyes" => "\xF0\x9F\x99\x84",
      "face_with_rolling_eyes" => "\xF0\x9F\x99\x84",
      "hushed" => "\xF0\x9F\x98\xAF",
      "frowning" => "\xE2\x98\xB9\xEF\xB8\x8F",
      "anguished" => "\xF0\x9F\x98\xA7",
      "open_mouth" => "\xF0\x9F\x98\xAE",
      "astonished" => "\xF0\x9F\x98\xB2",
      "sleeping" => "\xF0\x9F\x98\xB4",
      "drooling_face" => "\xF0\x9F\xA4\xA4",
      "drool" => "\xF0\x9F\xA4\xA4",
      "sleepy" => "\xF0\x9F\x98\xAA",
      "dizzy_face" => "\xF0\x9F\x98\xB5",
      "face_with_spiral_eyes" => "\xF0\x9F\x98\xB5\xE2\x80\x8D\xF0\x9F\x92\xAB",
      "zipper_mouth" => "\xF0\x9F\xA4\x90",
      "zipper_mouth_face" => "\xF0\x9F\xA4\x90",
      "woozy_face" => "\xF0\x9F\xA5\xB4",
      "nauseated_face" => "\xF0\x9F\xA4\xA2",
      "sick" => "\xF0\x9F\xA4\xA2",
      "face_vomiting" => "\xF0\x9F\xA4\xAE",
      "sneezing_face" => "\xF0\x9F\xA4\xA7",
      "sneeze" => "\xF0\x9F\xA4\xA7",
      "mask" => "\xF0\x9F\x98\xB7",
      "thermometer_face" => "\xF0\x9F\xA4\x92",
      "face_with_thermometer" => "\xF0\x9F\xA4\x92",
      "head_bandage" => "\xF0\x9F\xA4\x95",
      "face_with_head_bandage" => "\xF0\x9F\xA4\x95",
      "money_mouth" => "\xF0\x9F\xA4\x91",
      "money_mouth_face" => "\xF0\x9F\xA4\x91",
      "cowboy" => "\xF0\x9F\xA4\xA0",
      "face_with_cowboy_hat" => "\xF0\x9F\xA4\xA0",
      "disguised_face" => "\xF0\x9F\xA5\xB8",
      "smiling_imp" => "\xF0\x9F\x98\x88",
      "imp" => "\xF0\x9F\x91\xBF",
      "japanese_ogre" => "\xF0\x9F\x91\xB9",
      "japanese_goblin" => "\xF0\x9F\x91\xBA",
      "clown" => "\xF0\x9F\xA4\xA1",
      "clown_face" => "\xF0\x9F\xA4\xA1",
      "ghost" => "\xF0\x9F\x91\xBB",
      "skull" => "\xF0\x9F\x92\x80",
      "skeleton" => "\xF0\x9F\x92\x80",
      "skull_crossbones" => "\xE2\x98\xA0\xEF\xB8\x8F",
      "skull_and_crossbones" => "\xE2\x98\xA0\xEF\xB8\x8F",
      "alien" => "\xF0\x9F\x91\xBD",
      "space_invader" => "\xF0\x9F\x91\xBE",
      "robot" => "\xF0\x9F\xA4\x96",
      "robot_face" => "\xF0\x9F\xA4\x96",
      "jack_o_lantern" => "\xF0\x9F\x8E\x83",
      "smiley_cat" => "\xF0\x9F\x98\xBA",
      "smile_cat" => "\xF0\x9F\x98\xB8",
      "joy_cat" => "\xF0\x9F\x98\xB9",
      "heart_eyes_cat" => "\xF0\x9F\x98\xBB",
      "smirk_cat" => "\xF0\x9F\x98\xBC",
      "kissing_cat" => "\xF0\x9F\x98\xBD",
      "scream_cat" => "\xF0\x9F\x99\x80",
      "crying_cat_face" => "\xF0\x9F\x98\xBF",
      "pouting_cat" => "\xF0\x9F\x98\xBE",
      "palms_up_together" => "\xF0\x9F\xA4\xB2",
      "open_hands" => "\xF0\x9F\x91\x90",
      "raised_hands" => "\xF0\x9F\x99\x8C",
      "clap" => "\xF0\x9F\x91\x8F",
      "handshake" => "\xF0\x9F\xA4\x9D",
      "shaking_hands" => "\xF0\x9F\xA4\x9D",
      "thumbsup" => "\xF0\x9F\x91\x8D",
      "+1" => "\xF0\x9F\x91\x8D",
      "thumbup" => "\xF0\x9F\x91\x8D",
      "thumbsdown" => "\xF0\x9F\x91\x8E",
      "-1" => "\xF0\x9F\x91\x8E",
      "thumbdown" => "\xF0\x9F\x91\x8E",
      "punch" => "\xF0\x9F\x91\x8A",
      "fist" => "\xE2\x9C\x8A",
      "left_facing_fist" => "\xF0\x9F\xA4\x9B",
      "left_fist" => "\xF0\x9F\xA4\x9B",
      "right_facing_fist" => "\xF0\x9F\xA4\x9C",
      "right_fist" => "\xF0\x9F\xA4\x9C",
      "fingers_crossed" => "\xF0\x9F\xA4\x9E",
      "hand_with_index_and_middle_finger_crossed" => "\xF0\x9F\xA4\x9E",
      "v" => "\xE2\x9C\x8C\xEF\xB8\x8F",
      "love_you_gesture" => "\xF0\x9F\xA4\x9F",
      "metal" => "\xF0\x9F\xA4\x98",
      "sign_of_the_horns" => "\xF0\x9F\xA4\x98",
      "ok_hand" => "\xF0\x9F\x91\x8C",
      "pinching_hand" => "\xF0\x9F\xA4\x8F",
      "pinched_fingers" => "\xF0\x9F\xA4\x8C",
      "point_left" => "\xF0\x9F\x91\x88",
      "point_right" => "\xF0\x9F\x91\x89",
      "point_up_" => "\xF0\x9F\x91\x86",
      "point_down" => "\xF0\x9F\x91\x87",
      "point_up" => "\xE2\x98\x9D\xEF\xB8\x8F",
      "raised_hand" => "\xE2\x9C\x8B",
      "raised_back_of_hand" => "\xF0\x9F\xA4\x9A",
      "back_of_hand" => "\xF0\x9F\xA4\x9A",
      "hand_splayed" => "\xF0\x9F\x96\x90\xEF\xB8\x8F",
      "raised_hand_with_fingers_splayed" => "\xF0\x9F\x96\x90\xEF\xB8\x8F",
      "vulcan" => "\xF0\x9F\x96\x96",
      "raised_hand_with_part_between_middle_and_ring_fingers" => "\xF0\x9F\x96\x96",
      "wave" => "\xF0\x9F\x91\x8B",
      "call_me" => "\xF0\x9F\xA4\x99",
      "call_me_hand" => "\xF0\x9F\xA4\x99",
      "muscle" => "\xF0\x9F\x92\xAA",
      "mechanical_arm" => "\xF0\x9F\xA6\xBE",
      "middle_finger" => "\xF0\x9F\x96\x95",
      "reversed_hand_with_middle_finger_extended" => "\xF0\x9F\x96\x95",
      "writing_hand" => "\xE2\x9C\x8D\xEF\xB8\x8F",
      "pray" => "\xF0\x9F\x99\x8F",
      "foot" => "\xF0\x9F\xA6\xB6",
      "poop" => "\xF0\x9F\x92\xA9",
      "shit" => "\xF0\x9F\x92\xA9",
      "hankey" => "\xF0\x9F\x92\xA9",
      "poo" => "\xF0\x9F\x92\xA9",
      "thinking" => "\xF0\x9F\xA4\x94",
      "thinking_face" => "\xF0\x9F\xA4\x94",
      "beginner" => "\xF0\x9F\x94\xB0",
      "eyes" => "\xF0\x9F\x91\x80",
      "laughing" => "\xF0\x9F\x98\x86",
      "satisfied" => "\xF0\x9F\x98\x86",
      "tea" => "\xF0\x9F\x8D\xB5",
      "gear" => "\xE2\x9A\x99\xEF\xB8\x8F",
      "bell" => "\xF0\x9F\x94\x94",
      "face_with_symbols_over_mouth" => "\xF0\x9F\xA4\xAC",
      "grinning" => "\xF0\x9F\x98\x80",
      "smiley" => "\xF0\x9F\x98\x83",
      "smile" => "\xF0\x9F\x98\x84",
      "grin" => "\xF0\x9F\x98\x81",
      "sweat_smile" => "\xF0\x9F\x98\x85",
      "joy" => "\xF0\x9F\x98\x82",
      "rofl" => "\xF0\x9F\xA4\xA3",
      "rolling_on_the_floor_laughing" => "\xF0\x9F\xA4\xA3",
      "relaxed" => "\xE2\x98\xBA\xEF\xB8\x8F",
      "blush" => "\xF0\x9F\x98\x8A",
      "innocent" => "\xF0\x9F\x98\x87",
      "slight_smile" => "\xF0\x9F\x99\x82",
      "slightly_smiling_face" => "\xF0\x9F\x99\x82",
      "upside_down" => "\xF0\x9F\x99\x83",
      "upside_down_face" => "\xF0\x9F\x99\x83",
      "wink" => "\xF0\x9F\x98\x89",
      "relieved" => "\xF0\x9F\x98\x8C",
      "smiling_face_with_tear" => "\xF0\x9F\xA5\xB2",
      "heart_eyes" => "\xF0\x9F\x98\x8D",
      "smiling_face_with_" => "3_hearts\xF0\x9F\xA5\xB0",
      "kissing_heart" => "\xF0\x9F\x98\x98",
      "kissing" => "\xF0\x9F\x98\x97",
      "kissing_smiling_eyes" => "\xF0\x9F\x98\x99",
      "kissing_closed_eyes" => "\xF0\x9F\x98\x9A",
      "yum" => "\xF0\x9F\x98\x8B",
      "stuck_out_tongue" => "\xF0\x9F\x98\x9B",
      "stuck_out_tongue_closed_eyes" => "\xF0\x9F\x98\x9D",
      "stuck_out_tongue_winking_eye" => "\xF0\x9F\x98\x9C",
      "zany_face" => "\xF0\x9F\xA4\xAA",
      "face_with_raised_eyebrow" => "\xF0\x9F\xA4\xA8",
      "face_with_monocle" => "\xF0\x9F\xA7\x90",
      "nerd" => "\xF0\x9F\xA4\x93",
      "nerd_face" => "\xF0\x9F\xA4\x93",
      "sunglasses" => "\xF0\x9F\x98\x8E",
      "star_struck" => "\xF0\x9F\xA4\xA9",
      "partying_face" => "\xF0\x9F\xA5\xB3",
      "smirk" => "\xF0\x9F\x98\x8F",
      "unamused" => "\xF0\x9F\x98\x92",
      "disappointed" => "\xF0\x9F\x98\x9E",
      "pensive" => "\xF0\x9F\x98\x94",
      "worried" => "\xF0\x9F\x98\x9F",
      "confused" => "\xF0\x9F\x98\x95",
      "slight_frown" => "\xF0\x9F\x99\x81",
      "slightly_frowning_face" => "\xF0\x9F\x99\x81",
      "persevere" => "\xF0\x9F\x98\xA3",
      "confounded" => "\xF0\x9F\x98\x96",
      "tired_face" => "\xF0\x9F\x98\xAB",
      "weary" => "\xF0\x9F\x98\xA9",
      "pleading_face" => "\xF0\x9F\xA5\xBA",
      "cry" => "\xF0\x9F\x98\xA2",
      "sob" => "\xF0\x9F\x98\xAD",
      "triumph" => "\xF0\x9F\x98\xA4",
      "face_exhaling" => "\xF0\x9F\x98\xAE\xE2\x80\x8D\xF0\x9F\x92\xA8",
      "angry" => "\xF0\x9F\x98\xA0",
      "rage" => "\xF0\x9F\x98\xA1",
      "exploding_head" => "\xF0\x9F\xA4\xAF",
      "flushed" => "\xF0\x9F\x98\xB3",
      "face_in_clouds" => "\xF0\x9F\x98\xB6\xE2\x80\x8D\xF0\x9F\x8C\xAB\xEF\xB8\x8F",
      "hot_face" => "\xF0\x9F\xA5\xB5",
      "cold_face" => "\xF0\x9F\xA5\xB6",
      "scream" => "\xF0\x9F\x98\xB1",
      "fearful" => "\xF0\x9F\x98\xA8",
      "cold_sweat" => "\xF0\x9F\x98\xB0",
      "disappointed_relieved" => "\xF0\x9F\x98\xA5",
      "sweat" => "\xF0\x9F\x98\x93",
      "hugging" => "\xF0\x9F\xA4\x97",
      "hugging_face" => "\xF0\x9F\xA4\x97",
      "face_with_hand_over_mouth" => "\xF0\x9F\xA4\xAD",
      "yawning_face" => "\xF0\x9F\xA5\xB1",
      "shushing_face" => "\xF0\x9F\xA4\xAB",
      "lying_face" => "\xF0\x9F\xA4\xA5",
      "liar" => "\xF0\x9F\xA4\xA5",
      "no_mouth" => "\xF0\x9F\x98\xB6",
      "neutral_face" => "\xF0\x9F\x98\x90",
      "expressionless" => "\xF0\x9F\x98\x91",
      "clock1" => "\xF0\x9F\x95\x90",
      "clock130" => "\xF0\x9F\x95\x9C",
      "clock2" => "\xF0\x9F\x95\x91",
      "clock230" => "\xF0\x9F\x95\x9D",
      "clock3" => "\xF0\x9F\x95\x92",
      "clock330" => "\xF0\x9F\x95\x9E",
      "clock4" => "\xF0\x9F\x95\x93",
      "clock430" => "\xF0\x9F\x95\x9F",
      "clock5" => "\xF0\x9F\x95\x94",
      "clock530" => "\xF0\x9F\x95\xA0",
      "clock6" => "\xF0\x9F\x95\x95",
      "clock630" => "\xF0\x9F\x95\xA1",
      "clock7" => "\xF0\x9F\x95\x96",
      "clock730" => "\xF0\x9F\x95\xA2",
      "clock8" => "\xF0\x9F\x95\x97",
      "clock830" => "\xF0\x9F\x95\xA3",
      "clock9" => "\xF0\x9F\x95\x98",
      "clock930" => "\xF0\x9F\x95\xA4",
      "clock10" => "\xF0\x9F\x95\x99",
      "clock1030" => "\xF0\x9F\x95\xA5",
      "clock11" => "\xF0\x9F\x95\x9A",
      "clock1130" => "\xF0\x9F\x95\xA6",
      "clock12" => "\xF0\x9F\x95\x9B",
      "clock1230" => "\xF0\x9F\x95\xA7",
    }.freeze

    # A hash of unicode charcaters to their Discord's emoji names.
    UNICODE_TO_DISCORD = {
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAE" => %w[flag_ni],
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAA" => %w[flag_ne],
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAC" => %w[flag_ng],
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xBA" => %w[flag_nu],
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xAB" => %w[flag_nf],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB5" => %w[flag_kp],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB5" => %w[flag_mp],
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xB4" => %w[flag_no],
      "\xF0\x9F\x87\xB4\xF0\x9F\x87\xB2" => %w[flag_om],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB0" => %w[flag_pk],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xBC" => %w[flag_pw],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB8" => %w[flag_ps],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xA6" => %w[flag_pa],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAC" => %w[flag_pg],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xBE" => %w[flag_py],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAA" => %w[flag_pe],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAD" => %w[flag_ph],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB3" => %w[flag_pn],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB1" => %w[flag_pl],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB9" => %w[flag_pt],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB7" => %w[flag_pr],
      "\xF0\x9F\x87\xB6\xF0\x9F\x87\xA6" => %w[flag_qa],
      "\xF0\x9F\x87\xB7\xF0\x9F\x87\xAA" => %w[flag_re],
      "\xF0\x9F\x87\xB7\xF0\x9F\x87\xB4" => %w[flag_ro],
      "\xF0\x9F\x87\xB7\xF0\x9F\x87\xBA" => %w[flag_ru],
      "\xF0\x9F\x87\xB7\xF0\x9F\x87\xBC" => %w[flag_rw],
      "\xF0\x9F\x87\xBC\xF0\x9F\x87\xB8" => %w[flag_ws],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB2" => %w[flag_sm],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB9" => %w[flag_st],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA6" => %w[flag_sa],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB3" => %w[flag_sn],
      "\xF0\x9F\x87\xB7\xF0\x9F\x87\xB8" => %w[flag_rs],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA8" => %w[flag_sc],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB1" => %w[flag_sl],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAC" => %w[flag_sg],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBD" => %w[flag_sx],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB0" => %w[flag_sk],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAE" => %w[flag_si],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB8" => %w[flag_gs],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA7" => %w[flag_sb],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB4" => %w[flag_so],
      "\xF0\x9F\x87\xBF\xF0\x9F\x87\xA6" => %w[flag_za],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB7" => %w[flag_kr],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB8" => %w[flag_ss],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xB8" => %w[flag_es],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB0" => %w[flag_lk],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB1" => %w[flag_bl],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAD" => %w[flag_sh],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB3" => %w[flag_kn],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xA8" => %w[flag_lc],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xB2" => %w[flag_pm],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xA8" => %w[flag_vc],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xA9" => %w[flag_sd],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xB7" => %w[flag_sr],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBF" => %w[flag_sz],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xAA" => %w[flag_se],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAD" => %w[flag_ch],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBE" => %w[flag_sy],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xBC" => %w[flag_tw],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAF" => %w[flag_tj],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xBF" => %w[flag_tz],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAD" => %w[flag_th],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB1" => %w[flag_tl],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAC" => %w[flag_tg],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB0" => %w[flag_tk],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB4" => %w[flag_to],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB9" => %w[flag_tt],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB3" => %w[flag_tn],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB7" => %w[flag_tr],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xB2" => %w[flag_tm],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xA8" => %w[flag_tc],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xAE" => %w[flag_vi],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xBB" => %w[flag_tv],
      "\xF0\x9F\x87\xBA\xF0\x9F\x87\xAC" => %w[flag_ug],
      "\xF0\x9F\x87\xBA\xF0\x9F\x87\xA6" => %w[flag_ua],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAA" => %w[flag_ae],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xA7" => %w[flag_gb],
      "\xF0\x9F\x8F\xB4\xF3\xA0\x81\xA7\xF3\xA0\x81\xA2\xF3\xA0\x81\xA5\xF3\xA0\x81\xAE\xF3\xA0\x81\xA7\xF3\xA0\x81\xBF" => %w[england],
      "\xF0\x9F\x8F\xB4\xF3\xA0\x81\xA7\xF3\xA0\x81\xA2\xF3\xA0\x81\xB3\xF3\xA0\x81\xA3\xF3\xA0\x81\xB4\xF3\xA0\x81\xBF" => %w[scotland],
      "\xF0\x9F\x8F\xB4\xF3\xA0\x81\xA7\xF3\xA0\x81\xA2\xF3\xA0\x81\xB7\xF3\xA0\x81\xAC\xF3\xA0\x81\xB3\xF3\xA0\x81\xBF" => %w[wales],
      "\xF0\x9F\x87\xBA\xF0\x9F\x87\xB8" => %w[flag_us],
      "\xF0\x9F\x87\xBA\xF0\x9F\x87\xBE" => %w[flag_uy],
      "\xF0\x9F\x87\xBA\xF0\x9F\x87\xBF" => %w[flag_uz],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xBA" => %w[flag_vu],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xA6" => %w[flag_va],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xAA" => %w[flag_ve],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xB3" => %w[flag_vn],
      "\xF0\x9F\x87\xBC\xF0\x9F\x87\xAB" => %w[flag_wf],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xAD" => %w[flag_eh],
      "\xF0\x9F\x87\xBE\xF0\x9F\x87\xAA" => %w[flag_ye],
      "\xF0\x9F\x87\xBF\xF0\x9F\x87\xB2" => %w[flag_zm],
      "\xF0\x9F\x87\xBF\xF0\x9F\x87\xBC" => %w[flag_zw],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xA8" => %w[flag_ac],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBB" => %w[flag_bv],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB5" => %w[flag_cp],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xA6" => %w[flag_ea],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xAC" => %w[flag_dg],
      "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB2" => %w[flag_hm],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAB" => %w[flag_mf],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAE" => %w[flag_ci],
      "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB7" => %w[flag_hr],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBA" => %w[flag_cu],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBC" => %w[flag_cw],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBE" => %w[flag_cy],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBF" => %w[flag_cz],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xB0" => %w[flag_dk],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xAF" => %w[flag_dj],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xB2" => %w[flag_dm],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xB4" => %w[flag_do],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xA8" => %w[flag_ec],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xAC" => %w[flag_eg],
      "\xF0\x9F\x87\xB8\xF0\x9F\x87\xBB" => %w[flag_sv],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB6" => %w[flag_gq],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xB7" => %w[flag_er],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xAA" => %w[flag_ee],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xB9" => %w[flag_et],
      "\xF0\x9F\x87\xAA\xF0\x9F\x87\xBA" => %w[flag_eu],
      "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB0" => %w[flag_fk],
      "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB4" => %w[flag_fo],
      "\xF0\x9F\x87\xAB\xF0\x9F\x87\xAF" => %w[flag_fj],
      "\xF0\x9F\x87\xAB\xF0\x9F\x87\xAE" => %w[flag_fi],
      "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB7" => %w[flag_fr],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAB" => %w[flag_gf],
      "\xF0\x9F\x87\xB5\xF0\x9F\x87\xAB" => %w[flag_pf],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xAB" => %w[flag_tf],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xA6" => %w[flag_ga],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB2" => %w[flag_gm],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAA" => %w[flag_ge],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xAA" => %w[flag_de],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAD" => %w[flag_gh],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAE" => %w[flag_gi],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB7" => %w[flag_gr],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB1" => %w[flag_gl],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xA9" => %w[flag_gd],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB5" => %w[flag_gp],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xBA" => %w[flag_gu],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB9" => %w[flag_gt],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xAC" => %w[flag_gg],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xB3" => %w[flag_gn],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xBC" => %w[flag_gw],
      "\xF0\x9F\x87\xAC\xF0\x9F\x87\xBE" => %w[flag_gy],
      "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB9" => %w[flag_ht],
      "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB3" => %w[flag_hn],
      "\xF0\x9F\x87\xAD\xF0\x9F\x87\xB0" => %w[flag_hk],
      "\xF0\x9F\x87\xAD\xF0\x9F\x87\xBA" => %w[flag_hu],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB8" => %w[flag_is],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB3" => %w[flag_in],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xA9" => %w[flag_id],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB7" => %w[flag_ir],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB6" => %w[flag_iq],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xAA" => %w[flag_ie],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB2" => %w[flag_im],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB1" => %w[flag_il],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB9" => %w[flag_it],
      "\xF0\x9F\x87\xAF\xF0\x9F\x87\xB2" => %w[flag_jm],
      "\xF0\x9F\x87\xAF\xF0\x9F\x87\xB5" => %w[flag_jp],
      "\xF0\x9F\x8E\x8C" => %w[crossed_flags],
      "\xF0\x9F\x87\xAF\xF0\x9F\x87\xAA" => %w[flag_je],
      "\xF0\x9F\x87\xAF\xF0\x9F\x87\xB4" => %w[flag_jo],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xBF" => %w[flag_kz],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAA" => %w[flag_ke],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAE" => %w[flag_ki],
      "\xF0\x9F\x87\xBD\xF0\x9F\x87\xB0" => %w[flag_xk],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xBC" => %w[flag_kw],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAC" => %w[flag_kg],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xA6" => %w[flag_la],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xBB" => %w[flag_lv],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xA7" => %w[flag_lb],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB8" => %w[flag_ls],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB7" => %w[flag_lr],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xBE" => %w[flag_ly],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xAE" => %w[flag_li],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xB9" => %w[flag_lt],
      "\xF0\x9F\x87\xB1\xF0\x9F\x87\xBA" => %w[flag_lu],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB4" => %w[flag_mo],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB0" => %w[flag_mk],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAC" => %w[flag_mg],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBC" => %w[flag_mw],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBE" => %w[flag_my],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBB" => %w[flag_mv],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB1" => %w[flag_ml],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB9" => %w[flag_mt],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAD" => %w[flag_mh],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB6" => %w[flag_mq],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB7" => %w[flag_mr],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBA" => %w[flag_mu],
      "\xF0\x9F\x87\xBE\xF0\x9F\x87\xB9" => %w[flag_yt],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBD" => %w[flag_mx],
      "\xF0\x9F\x87\xAB\xF0\x9F\x87\xB2" => %w[flag_fm],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xA9" => %w[flag_md],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xA8" => %w[flag_mc],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB3" => %w[flag_mn],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xAA" => %w[flag_me],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB8" => %w[flag_ms],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xA6" => %w[flag_ma],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xBF" => %w[flag_mz],
      "\xF0\x9F\x87\xB2\xF0\x9F\x87\xB2" => %w[flag_mm],
      "\xF0\x9F\x87\xB3\xF0\x9F\x87\xA6" => %w[flag_na],
      "\xF0\x9F\x87\xB5" => %w[regional_indicator_p],
      "\xF0\x9F\x87\xB4" => %w[regional_indicator_o],
      "\xF0\x9F\x87\xB3" => %w[regional_indicator_n],
      "\xF0\x9F\x87\xB2" => %w[regional_indicator_m],
      "\xF0\x9F\x87\xB1" => %w[regional_indicator_l],
      "\xF0\x9F\x87\xB0" => %w[regional_indicator_k],
      "\xF0\x9F\x87\xAF" => %w[regional_indicator_j],
      "\xF0\x9F\x87\xAE" => %w[regional_indicator_i],
      "\xF0\x9F\x87\xAD" => %w[regional_indicator_h],
      "\xF0\x9F\x87\xAC" => %w[regional_indicator_g],
      "\xF0\x9F\x87\xAB" => %w[regional_indicator_f],
      "\xF0\x9F\x87\xAA" => %w[regional_indicator_e],
      "\xF0\x9F\x87\xA9" => %w[regional_indicator_d],
      "\xF0\x9F\x87\xA8" => %w[regional_indicator_c],
      "\xF0\x9F\x87\xA7" => %w[regional_indicator_b],
      "\xF0\x9F\x87\xA6" => %w[regional_indicator_a],
      "\xF0\x9F\x8F\xB3\xEF\xB8\x8F" => %w[flag_white],
      "\xF0\x9F\x8F\xB4" => %w[flag_black],
      "\xF0\x9F\x8F\x81" => %w[checkered_flag],
      "\xF0\x9F\x9A\xA9" => %w[triangular_flag_on_post],
      "\xF0\x9F\x8F\xB3\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x8C\x88" => %w[rainbow_flag gay_pride_flag],
      "\xF0\x9F\x8F\xB3\xEF\xB8\x8F\xE2\x80\x8D\xE2\x9A\xA7\xEF\xB8\x8F" => %w[transgender_flag],
      "\xF0\x9F\x8F\xB4\xE2\x80\x8D\xE2\x98\xA0\xEF\xB8\x8F" => %w[pirate_flag],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAB" => %w[flag_af],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBD" => %w[flag_ax],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB1" => %w[flag_al],
      "\xF0\x9F\x87\xA9\xF0\x9F\x87\xBF" => %w[flag_dz],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB8" => %w[flag_as],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xA9" => %w[flag_ad],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB4" => %w[flag_ao],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAE" => %w[flag_ai],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB6" => %w[flag_aq],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xAC" => %w[flag_ag],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB7" => %w[flag_ar],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB2" => %w[flag_am],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBC" => %w[flag_aw],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBA" => %w[flag_au],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xB9" => %w[flag_at],
      "\xF0\x9F\x87\xA6\xF0\x9F\x87\xBF" => %w[flag_az],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB8" => %w[flag_bs],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAD" => %w[flag_bh],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xA9" => %w[flag_bd],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xA7" => %w[flag_bb],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBE" => %w[flag_by],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAA" => %w[flag_be],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBF" => %w[flag_bz],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAF" => %w[flag_bj],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB2" => %w[flag_bm],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB9" => %w[flag_bt],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB4" => %w[flag_bo],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xA6" => %w[flag_ba],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xBC" => %w[flag_bw],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB7" => %w[flag_br],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xB4" => %w[flag_io],
      "\xF0\x9F\x87\xBB\xF0\x9F\x87\xAC" => %w[flag_vg],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB3" => %w[flag_bn],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAC" => %w[flag_bg],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAB" => %w[flag_bf],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xAE" => %w[flag_bi],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xAD" => %w[flag_kh],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB2" => %w[flag_cm],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xA6" => %w[flag_ca],
      "\xF0\x9F\x87\xAE\xF0\x9F\x87\xA8" => %w[flag_ic],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBB" => %w[flag_cv],
      "\xF0\x9F\x87\xA7\xF0\x9F\x87\xB6" => %w[flag_bq],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xBE" => %w[flag_ky],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAB" => %w[flag_cf],
      "\xF0\x9F\x87\xB9\xF0\x9F\x87\xA9" => %w[flag_td],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB1" => %w[flag_cl],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB3" => %w[flag_cn],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xBD" => %w[flag_cx],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xA8" => %w[flag_cc],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB4" => %w[flag_co],
      "\xF0\x9F\x87\xB0\xF0\x9F\x87\xB2" => %w[flag_km],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xAC" => %w[flag_cg],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xA9" => %w[flag_cd],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB0" => %w[flag_ck],
      "\xF0\x9F\x87\xA8\xF0\x9F\x87\xB7" => %w[flag_cr],
      "\xE2\x97\xBE" => %w[black_medium_small_square],
      "\xE2\x97\xBD" => %w[white_medium_small_square],
      "\xE2\x97\xBC\xEF\xB8\x8F" => %w[black_medium_square],
      "\xE2\x97\xBB\xEF\xB8\x8F" => %w[white_medium_square],
      "\xE2\xAC\x9B" => %w[black_large_square],
      "\xE2\xAC\x9C" => %w[white_large_square],
      "\xF0\x9F\x9F\xA7" => %w[orange_square],
      "\xF0\x9F\x9F\xA6" => %w[blue_square],
      "\xF0\x9F\x9F\xA5" => %w[red_square],
      "\xF0\x9F\x9F\xAB" => %w[brown_square],
      "\xF0\x9F\x9F\xAA" => %w[purple_square],
      "\xF0\x9F\x9F\xA9" => %w[green_square],
      "\xF0\x9F\x9F\xA8" => %w[yellow_square],
      "\xF0\x9F\x94\x88" => %w[speaker],
      "\xF0\x9F\x94\x87" => %w[mute],
      "\xF0\x9F\x94\x89" => %w[sound],
      "\xF0\x9F\x94\x8A" => %w[loud_sound],
      "\xF0\x9F\x94\x95" => %w[no_bell],
      "\xF0\x9F\x93\xA3" => %w[mega],
      "\xF0\x9F\x93\xA2" => %w[loudspeaker],
      "\xF0\x9F\x97\xA8\xEF\xB8\x8F" => %w[speech_left left_speech_bubble],
      "\xF0\x9F\x91\x81\xE2\x80\x8D\xF0\x9F\x97\xA8" => %w[eye_in_speech_bubble],
      "\xF0\x9F\x92\xAC" => %w[speech_balloon],
      "\xF0\x9F\x92\xAD" => %w[thought_balloon],
      "\xF0\x9F\x97\xAF\xEF\xB8\x8F" => %w[anger_right right_anger_bubble],
      "\xE2\x99\xA0\xEF\xB8\x8F" => %w[spades],
      "\xE2\x99\xA3\xEF\xB8\x8F" => %w[clubs],
      "\xE2\x99\xA5\xEF\xB8\x8F" => %w[hearts],
      "\xE2\x99\xA6\xEF\xB8\x8F" => %w[diamonds],
      "\xF0\x9F\x83\x8F" => %w[black_joker],
      "\xF0\x9F\x8E\xB4" => %w[flower_playing_cards],
      "\xF0\x9F\x80\x84" => %w[mahjong],
      "\xF0\x9F\x95\xB0\xEF\xB8\x8F" => %w[clock mantlepiece_clock],
      "\xE2\x99\x80\xEF\xB8\x8F" => %w[female_sign],
      "\xE2\x99\x82\xEF\xB8\x8F" => %w[male_sign],
      "\xE2\x9A\xA7" => %w[transgender_symbol],
      "\xE2\x9A\x95\xEF\xB8\x8F" => %w[medical_symbol],
      "\xF0\x9F\x87\xBF" => %w[regional_indicator_z],
      "\xF0\x9F\x87\xBE" => %w[regional_indicator_y],
      "\xF0\x9F\x87\xBD" => %w[regional_indicator_x],
      "\xF0\x9F\x87\xBC" => %w[regional_indicator_w],
      "\xF0\x9F\x87\xBB" => %w[regional_indicator_v],
      "\xF0\x9F\x87\xBA" => %w[regional_indicator_u],
      "\xF0\x9F\x87\xB9" => %w[regional_indicator_t],
      "\xF0\x9F\x87\xB8" => %w[regional_indicator_s],
      "\xF0\x9F\x87\xB7" => %w[regional_indicator_r],
      "\xF0\x9F\x87\xB6" => %w[regional_indicator_q],
      "\xF0\x9F\x94\xBD" => %w[arrow_down_small],
      "\xE2\x9E\xA1\xEF\xB8\x8F" => %w[arrow_right],
      "\xE2\xAC\x85\xEF\xB8\x8F" => %w[arrow_left],
      "\xE2\xAC\x86\xEF\xB8\x8F" => %w[arrow_up],
      "\xE2\xAC\x87\xEF\xB8\x8F" => %w[arrow_down],
      "\xE2\x86\x97\xEF\xB8\x8F" => %w[arrow_upper_right],
      "\xE2\x86\x98\xEF\xB8\x8F" => %w[arrow_lower_right],
      "\xE2\x86\x99\xEF\xB8\x8F" => %w[arrow_lower_left],
      "\xE2\x86\x96\xEF\xB8\x8F" => %w[arrow_upper_left],
      "\xE2\x86\x95\xEF\xB8\x8F" => %w[arrow_up_down],
      "\xE2\x86\x94\xEF\xB8\x8F" => %w[left_right_arrow],
      "\xE2\x86\xAA\xEF\xB8\x8F" => %w[arrow_right_hook],
      "\xE2\x86\xA9\xEF\xB8\x8F" => %w[leftwards_arrow_with_hook],
      "\xE2\xA4\xB4\xEF\xB8\x8F" => %w[arrow_heading_up],
      "\xE2\xA4\xB5\xEF\xB8\x8F" => %w[arrow_heading_down],
      "\xF0\x9F\x94\x80" => %w[twisted_rightwards_arrows],
      "\xF0\x9F\x94\x81" => %w[repeat],
      "\xF0\x9F\x94\x82" => %w[repeat_one],
      "\xF0\x9F\x94\x84" => %w[arrows_counterclockwise],
      "\xF0\x9F\x94\x83" => %w[arrows_clockwise],
      "\xF0\x9F\x8E\xB5" => %w[musical_note],
      "\xF0\x9F\x8E\xB6" => %w[notes],
      "\xE2\x9E\x95" => %w[heavy_plus_sign],
      "\xE2\x9E\x96" => %w[heavy_minus_sign],
      "\xE2\x9E\x97" => %w[heavy_division_sign],
      "\xE2\x9C\x96\xEF\xB8\x8F" => %w[heavy_multiplication_x],
      "\xE2\x99\xBE\xEF\xB8\x8F" => %w[infinity],
      "\xF0\x9F\x92\xB2" => %w[heavy_dollar_sign],
      "\xF0\x9F\x92\xB1" => %w[currency_exchange],
      "\xE2\x84\xA2\xEF\xB8\x8F" => %w[tm],
      "\xC2\xA9\xEF\xB8\x8F" => %w[copyright],
      "\xC2\xAE\xEF\xB8\x8F" => %w[registered],
      "\xE3\x80\xB0\xEF\xB8\x8F" => %w[wavy_dash],
      "\xE2\x9E\xB0" => %w[curly_loop],
      "\xE2\x9E\xBF" => %w[loop],
      "\xF0\x9F\x94\x9A" => %w[end],
      "\xF0\x9F\x94\x99" => %w[back],
      "\xF0\x9F\x94\x9B" => %w[on],
      "\xF0\x9F\x94\x9D" => %w[top],
      "\xF0\x9F\x94\x9C" => %w[soon],
      "\xE2\x9C\x94\xEF\xB8\x8F" => %w[heavy_check_mark],
      "\xE2\x98\x91\xEF\xB8\x8F" => %w[ballot_box_with_check],
      "\xF0\x9F\x94\x98" => %w[radio_button],
      "\xE2\x9A\xAA" => %w[white_circle],
      "\xE2\x9A\xAB" => %w[black_circle],
      "\xF0\x9F\x94\xB4" => %w[red_circle],
      "\xF0\x9F\x94\xB5" => %w[blue_circle],
      "\xF0\x9F\x9F\xA4" => %w[brown_circle],
      "\xF0\x9F\x9F\xA3" => %w[purple_circle],
      "\xF0\x9F\x9F\xA2" => %w[green_circle],
      "\xF0\x9F\x9F\xA1" => %w[yellow_circle],
      "\xF0\x9F\x9F\xA0" => %w[orange_circle],
      "\xF0\x9F\x94\xBA" => %w[small_red_triangle],
      "\xF0\x9F\x94\xBB" => %w[small_red_triangle_down],
      "\xF0\x9F\x94\xB8" => %w[small_orange_diamond],
      "\xF0\x9F\x94\xB9" => %w[small_blue_diamond],
      "\xF0\x9F\x94\xB6" => %w[large_orange_diamond],
      "\xF0\x9F\x94\xB7" => %w[large_blue_diamond],
      "\xF0\x9F\x94\xB3" => %w[white_square_button],
      "\xF0\x9F\x94\xB2" => %w[black_square_button],
      "\xE2\x96\xAA\xEF\xB8\x8F" => %w[black_small_square],
      "\xE2\x96\xAB\xEF\xB8\x8F" => %w[white_small_square],
      "\xF0\x9F\x9A\xAD" => %w[no_smoking],
      "\xE2\x9D\x97" => %w[exclamation],
      "\xE2\x9D\x95" => %w[grey_exclamation],
      "\xE2\x9D\x93" => %w[question],
      "\xE2\x9D\x94" => %w[grey_question],
      "\xE2\x80\xBC\xEF\xB8\x8F" => %w[bangbang],
      "\xE2\x81\x89\xEF\xB8\x8F" => %w[interrobang],
      "\xF0\x9F\x94\x85" => %w[low_brightness],
      "\xF0\x9F\x94\x86" => %w[high_brightness],
      "\xE3\x80\xBD\xEF\xB8\x8F" => %w[part_alternation_mark],
      "\xE2\x9A\xA0\xEF\xB8\x8F" => %w[warning],
      "\xF0\x9F\x9A\xB8" => %w[children_crossing],
      "\xF0\x9F\x94\xB1" => %w[trident],
      "\xE2\x9A\x9C\xEF\xB8\x8F" => %w[fleur_de_lis],
      "\xE2\x99\xBB\xEF\xB8\x8F" => %w[recycle],
      "\xE2\x9C\x85" => %w[white_check_mark],
      "7981\xF0\x9F\x88\xB2" => %w[u],
      "\xF0\x9F\x92\xB9" => %w[chart],
      "\xE2\x9D\x87\xEF\xB8\x8F" => %w[sparkle],
      "\xE2\x9C\xB3\xEF\xB8\x8F" => %w[eight_spoked_asterisk],
      "\xE2\x9D\x8E" => %w[negative_squared_cross_mark],
      "\xF0\x9F\x8C\x90" => %w[globe_with_meridians],
      "\xF0\x9F\x92\xA0" => %w[diamond_shape_with_a_dot_inside],
      "\xE2\x93\x82\xEF\xB8\x8F" => %w[m],
      "\xF0\x9F\x8C\x80" => %w[cyclone],
      "\xF0\x9F\x92\xA4" => %w[zzz],
      "\xF0\x9F\x8F\xA7" => %w[atm],
      "\xF0\x9F\x9A\xBE" => %w[wc],
      "\xE2\x99\xBF" => %w[wheelchair],
      "\xF0\x9F\x85\xBF\xEF\xB8\x8F" => %w[parking],
      "\xF0\x9F\x88\x82\xEF\xB8\x8F" => %w[sa],
      "\xF0\x9F\x9B\x82" => %w[passport_control],
      "\xF0\x9F\x9B\x83" => %w[customs],
      "\xF0\x9F\x9B\x84" => %w[baggage_claim],
      "\xF0\x9F\x9B\x85" => %w[left_luggage],
      "\xF0\x9F\x9B\x97" => %w[elevator],
      "\xF0\x9F\x9A\xB9" => %w[mens],
      "\xF0\x9F\x9A\xBA" => %w[womens],
      "\xF0\x9F\x9A\xBC" => %w[baby_symbol],
      "\xF0\x9F\x9A\xBB" => %w[restroom],
      "\xF0\x9F\x9A\xAE" => %w[put_litter_in_its_place],
      "\xF0\x9F\x8E\xA6" => %w[cinema],
      "\xF0\x9F\x93\xB6" => %w[signal_strength],
      "\xF0\x9F\x88\x81" => %w[koko],
      "\xF0\x9F\x94\xA3" => %w[symbols],
      "\xE2\x84\xB9\xEF\xB8\x8F" => %w[information_source],
      "\xF0\x9F\x94\xA4" => %w[abc],
      "\xF0\x9F\x94\xA1" => %w[abcd],
      "\xF0\x9F\x94\xA0" => %w[capital_abcd],
      "\xF0\x9F\x86\x96" => %w[ng],
      "\xF0\x9F\x86\x97" => %w[ok],
      "\xF0\x9F\x86\x99" => %w[up],
      "\xF0\x9F\x86\x92" => %w[cool],
      "\xF0\x9F\x86\x95" => %w[new],
      "\xF0\x9F\x86\x93" => %w[free],
      "0\xEF\xB8\x8F\xE2\x83\xA3" => %w[zero],
      "1\xEF\xB8\x8F\xE2\x83\xA3" => %w[one],
      "2\xEF\xB8\x8F\xE2\x83\xA3" => %w[two],
      "3\xEF\xB8\x8F\xE2\x83\xA3" => %w[three],
      "4\xEF\xB8\x8F\xE2\x83\xA3" => %w[four],
      "5\xEF\xB8\x8F\xE2\x83\xA3" => %w[five],
      "6\xEF\xB8\x8F\xE2\x83\xA3" => %w[six],
      "7\xEF\xB8\x8F\xE2\x83\xA3" => %w[seven],
      "8\xEF\xB8\x8F\xE2\x83\xA3" => %w[eight],
      "9\xEF\xB8\x8F\xE2\x83\xA3" => %w[nine],
      "\xF0\x9F\x94\x9F" => %w[keycap_ten],
      "#\xEF\xB8\x8F\xE2\x83\xA3" => %w[hash],
      "*\xEF\xB8\x8F\xE2\x83\xA3" => %w[asterisk keycap_asterisk],
      "\xE2\x8F\x8F\xEF\xB8\x8F" => %w[eject eject_symbol],
      "\xE2\x96\xB6\xEF\xB8\x8F" => %w[arrow_forward],
      "\xE2\x8F\xB8\xEF\xB8\x8F" => %w[pause_button double_vertical_bar],
      "\xE2\x8F\xAF\xEF\xB8\x8F" => %w[play_pause],
      "\xE2\x8F\xB9\xEF\xB8\x8F" => %w[stop_button],
      "\xE2\x8F\xBA\xEF\xB8\x8F" => %w[record_button],
      "\xE2\x8F\xAD\xEF\xB8\x8F" => %w[track_next next_track],
      "\xE2\x8F\xAE\xEF\xB8\x8F" => %w[track_previous previous_track],
      "\xE2\x8F\xA9" => %w[fast_forward],
      "\xE2\x8F\xAA" => %w[rewind],
      "\xE2\x8F\xAB" => %w[arrow_double_up],
      "\xE2\x8F\xAC" => %w[arrow_double_down],
      "\xE2\x97\x80\xEF\xB8\x8F" => %w[arrow_backward],
      "\xF0\x9F\x94\xBC" => %w[arrow_up_small],
      "\xF0\x9F\x92\x9B" => %w[yellow_heart],
      "\xF0\x9F\x92\x9A" => %w[green_heart],
      "\xF0\x9F\x92\x99" => %w[blue_heart],
      "\xF0\x9F\x92\x9C" => %w[purple_heart],
      "\xF0\x9F\x96\xA4" => %w[black_heart],
      "\xF0\x9F\xA4\x8E" => %w[brown_heart],
      "\xF0\x9F\xA4\x8D" => %w[white_heart],
      "\xF0\x9F\x92\x94" => %w[broken_heart],
      "\xE2\x9D\xA3\xEF\xB8\x8F" => %w[heart_exclamation heavy_heart_exclamation_mark_ornament],
      "\xF0\x9F\x92\x95" => %w[two_hearts],
      "\xF0\x9F\x92\x9E" => %w[revolving_hearts],
      "\xF0\x9F\x92\x93" => %w[heartbeat],
      "\xF0\x9F\x92\x97" => %w[heartpulse],
      "\xF0\x9F\x92\x96" => %w[sparkling_heart],
      "\xF0\x9F\x92\x98" => %w[cupid],
      "\xF0\x9F\x92\x9D" => %w[gift_heart],
      "\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\xA9\xB9" => %w[mending_heart],
      "\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x94\xA5" => %w[heart_on_fire],
      "\xF0\x9F\x92\x9F" => %w[heart_decoration],
      "\xE2\x98\xAE\xEF\xB8\x8F" => %w[peace peace_symbol],
      "\xE2\x9C\x9D\xEF\xB8\x8F" => %w[cross latin_cross],
      "\xE2\x98\xAA\xEF\xB8\x8F" => %w[star_and_crescent],
      "\xF0\x9F\x95\x89\xEF\xB8\x8F" => %w[om_symbol],
      "\xE2\x98\xB8\xEF\xB8\x8F" => %w[wheel_of_dharma],
      "\xE2\x9C\xA1\xEF\xB8\x8F" => %w[star_of_david],
      "\xF0\x9F\x94\xAF" => %w[six_pointed_star],
      "\xF0\x9F\x95\x8E" => %w[menorah],
      "\xE2\x98\xAF\xEF\xB8\x8F" => %w[yin_yang],
      "\xE2\x98\xA6\xEF\xB8\x8F" => %w[orthodox_cross],
      "\xF0\x9F\x9B\x90" => %w[place_of_worship worship_symbol],
      "\xE2\x9B\x8E" => %w[ophiuchus],
      "\xE2\x99\x88" => %w[aries],
      "\xE2\x99\x89" => %w[taurus],
      "\xE2\x99\x8A" => %w[gemini],
      "\xE2\x99\x8B" => %w[cancer],
      "\xE2\x99\x8C" => %w[leo],
      "\xE2\x99\x8D" => %w[virgo],
      "\xE2\x99\x8E" => %w[libra],
      "\xE2\x99\x8F" => %w[scorpius],
      "\xE2\x99\x90" => %w[sagittarius],
      "\xE2\x99\x91" => %w[capricorn],
      "\xE2\x99\x92" => %w[aquarius],
      "\xE2\x99\x93" => %w[pisces],
      "\xF0\x9F\x86\x94" => %w[id],
      "\xE2\x9A\x9B\xEF\xB8\x8F" => %w[atom atom_symbol],
      "\xF0\x9F\x89\x91" => %w[accept],
      "\xE2\x98\xA2\xEF\xB8\x8F" => %w[radioactive radioactive_sign],
      "\xE2\x98\xA3\xEF\xB8\x8F" => %w[biohazard biohazard_sign],
      "\xF0\x9F\x93\xB4" => %w[mobile_phone_off],
      "\xF0\x9F\x93\xB3" => %w[vibration_mode],
      "\xE2\x9C\xB4\xEF\xB8\x8F" => %w[eight_pointed_black_star],
      "\xF0\x9F\x86\x9A" => %w[vs],
      "\xF0\x9F\x92\xAE" => %w[white_flower],
      "\xF0\x9F\x89\x90" => %w[ideograph_advantage],
      "\xE3\x8A\x99\xEF\xB8\x8F" => %w[secret],
      "\xE3\x8A\x97\xEF\xB8\x8F" => %w[congratulations],
      "\xF0\x9F\x85\xB0\xEF\xB8\x8F" => %w[a],
      "\xF0\x9F\x85\xB1\xEF\xB8\x8F" => %w[b],
      "\xF0\x9F\x86\x8E" => %w[ab],
      "\xF0\x9F\x86\x91" => %w[cl],
      "\xE2\xAD\x95" => %w[o],
      "\xF0\x9F\x86\x98" => %w[sos],
      "\xE2\x9D\x8C" => %w[x],
      "\xF0\x9F\x9B\x91" => %w[octagonal_sign stop_sign],
      "\xE2\x9B\x94" => %w[no_entry],
      "\xF0\x9F\x93\x9B" => %w[name_badge],
      "\xF0\x9F\x9A\xAB" => %w[no_entry_sign],
      "\xF0\x9F\x92\xA2" => %w[anger],
      "\xE2\x99\xA8\xEF\xB8\x8F" => %w[hotsprings],
      "\xF0\x9F\x9A\xB7" => %w[no_pedestrians],
      "\xF0\x9F\x9A\xAF" => %w[do_not_litter],
      "\xF0\x9F\x9A\xB3" => %w[no_bicycles],
      "\xF0\x9F\x9A\xB1" => %w[non_potable_water],
      "\xF0\x9F\x94\x9E" => %w[underage],
      "\xF0\x9F\x93\xB5" => %w[no_mobile_phones],
      "\xF0\x9F\x8E\x90" => %w[wind_chime],
      "\xF0\x9F\xA7\xA7" => %w[red_envelope],
      "\xE2\x9C\x89\xEF\xB8\x8F" => %w[envelope],
      "\xF0\x9F\x93\xA9" => %w[envelope_with_arrow],
      "\xF0\x9F\x93\xA8" => %w[incoming_envelope],
      "\xF0\x9F\x93\xA7" => %w[e_mail email],
      "\xF0\x9F\x92\x8C" => %w[love_letter],
      "\xF0\x9F\x93\xA5" => %w[inbox_tray],
      "\xF0\x9F\x93\xA4" => %w[outbox_tray],
      "\xF0\x9F\x93\xA6" => %w[package],
      "\xF0\x9F\x8F\xB7\xEF\xB8\x8F" => %w[label],
      "\xF0\x9F\x93\xAA" => %w[mailbox_closed],
      "\xF0\x9F\x93\xAB" => %w[mailbox],
      "\xF0\x9F\x93\xAC" => %w[mailbox_with_mail],
      "\xF0\x9F\x93\xAD" => %w[mailbox_with_no_mail],
      "\xF0\x9F\x93\xAE" => %w[postbox],
      "\xF0\x9F\x93\xAF" => %w[postal_horn],
      "\xF0\x9F\xAA\xA7" => %w[placard],
      "\xF0\x9F\x93\x9C" => %w[scroll],
      "\xF0\x9F\x93\x83" => %w[page_with_curl],
      "\xF0\x9F\x93\x84" => %w[page_facing_up],
      "\xF0\x9F\x93\x91" => %w[bookmark_tabs],
      "\xF0\x9F\xA7\xBE" => %w[receipt],
      "\xF0\x9F\x93\x8A" => %w[bar_chart],
      "\xF0\x9F\x93\x88" => %w[chart_with_upwards_trend],
      "\xF0\x9F\x93\x89" => %w[chart_with_downwards_trend],
      "\xF0\x9F\x97\x92\xEF\xB8\x8F" => %w[notepad_spiral spiral_note_pad],
      "\xF0\x9F\x97\x93\xEF\xB8\x8F" => %w[calendar_spiral spiral_calendar_pad],
      "\xF0\x9F\x93\x86" => %w[calendar],
      "\xF0\x9F\x93\x85" => %w[date],
      "\xF0\x9F\x97\x91\xEF\xB8\x8F" => %w[wastebasket],
      "\xF0\x9F\x93\x87" => %w[card_index],
      "\xF0\x9F\x97\x83\xEF\xB8\x8F" => %w[card_box card_file_box],
      "\xF0\x9F\x97\xB3\xEF\xB8\x8F" => %w[ballot_box ballot_box_with_ballot],
      "\xF0\x9F\x97\x84\xEF\xB8\x8F" => %w[file_cabinet],
      "\xF0\x9F\x93\x8B" => %w[clipboard],
      "\xF0\x9F\x93\x81" => %w[file_folder],
      "\xF0\x9F\x93\x82" => %w[open_file_folder],
      "\xF0\x9F\x97\x82\xEF\xB8\x8F" => %w[dividers card_index_dividers],
      "\xF0\x9F\x93\xB0" => %w[newspaper],
      "\xF0\x9F\x93\x93" => %w[notebook],
      "\xF0\x9F\x93\x94" => %w[notebook_with_decorative_cover],
      "\xF0\x9F\x93\x92" => %w[ledger],
      "\xF0\x9F\x93\x95" => %w[closed_book],
      "\xF0\x9F\x93\x97" => %w[green_book],
      "\xF0\x9F\x93\x98" => %w[blue_book],
      "\xF0\x9F\x93\x99" => %w[orange_book],
      "\xF0\x9F\x93\x9A" => %w[books],
      "\xF0\x9F\x93\x96" => %w[book],
      "\xF0\x9F\x94\x96" => %w[bookmark],
      "\xF0\x9F\xA7\xB7" => %w[safety_pin],
      "\xF0\x9F\x94\x97" => %w[link],
      "\xF0\x9F\x93\x8E" => %w[paperclip],
      "\xF0\x9F\x96\x87\xEF\xB8\x8F" => %w[paperclips linked_paperclips],
      "\xF0\x9F\x93\x90" => %w[triangular_ruler],
      "\xF0\x9F\x93\x8F" => %w[straight_ruler],
      "\xF0\x9F\xA7\xAE" => %w[abacus],
      "\xF0\x9F\x93\x8C" => %w[pushpin],
      "\xF0\x9F\x93\x8D" => %w[round_pushpin],
      "\xE2\x9C\x82\xEF\xB8\x8F" => %w[scissors],
      "\xF0\x9F\x96\x8A\xEF\xB8\x8F" => %w[pen_ballpoint lower_left_ballpoint_pen],
      "\xF0\x9F\x96\x8B\xEF\xB8\x8F" => %w[pen_fountain lower_left_fountain_pen],
      "\xE2\x9C\x92\xEF\xB8\x8F" => %w[black_nib],
      "\xF0\x9F\x96\x8C\xEF\xB8\x8F" => %w[paintbrush lower_left_paintbrush],
      "\xF0\x9F\x96\x8D\xEF\xB8\x8F" => %w[crayon lower_left_crayon],
      "\xE2\x9C\x8F\xEF\xB8\x8F" => %w[pencil memo],
      "\xF0\x9F\x94\x8D" => %w[mag],
      "\xF0\x9F\x94\x8E" => %w[mag_right],
      "\xF0\x9F\x94\x8F" => %w[lock_with_ink_pen],
      "\xF0\x9F\x94\x90" => %w[closed_lock_with_key],
      "\xF0\x9F\x94\x92" => %w[lock],
      "\xF0\x9F\x94\x93" => %w[unlock],
      "\xE2\x9D\xA4\xEF\xB8\x8F" => %w[heart],
      "\xF0\x9F\xA7\xA1" => %w[orange_heart],
      "\xF0\x9F\x92\xB8" => %w[money_with_wings],
      "\xF0\x9F\x92\xB5" => %w[dollar],
      "\xF0\x9F\x92\xB4" => %w[yen],
      "\xF0\x9F\x92\xB6" => %w[euro],
      "\xF0\x9F\x92\xB7" => %w[pound],
      "\xF0\x9F\xAA\x99" => %w[coin],
      "\xF0\x9F\x92\xB0" => %w[moneybag],
      "\xF0\x9F\x92\xB3" => %w[credit_card],
      "\xF0\x9F\x92\x8E" => %w[gem],
      "\xE2\x9A\x96\xEF\xB8\x8F" => %w[scales],
      "\xF0\x9F\xAA\x9C" => %w[ladder],
      "\xF0\x9F\xA7\xB0" => %w[toolbox],
      "\xF0\x9F\xAA\x9B" => %w[screwdriver],
      "\xF0\x9F\x94\xA7" => %w[wrench],
      "\xF0\x9F\x94\xA8" => %w[hammer],
      "\xE2\x9A\x92\xEF\xB8\x8F" => %w[hammer_pick hammer_and_pick],
      "\xF0\x9F\x9B\xA0\xEF\xB8\x8F" => %w[tools hammer_and_wrench],
      "\xE2\x9B\x8F\xEF\xB8\x8F" => %w[pick],
      "\xF0\x9F\x94\xA9" => %w[nut_and_bolt],
      "\xF0\x9F\xA7\xB1" => %w[bricks],
      "\xE2\x9B\x93\xEF\xB8\x8F" => %w[chains],
      "\xF0\x9F\xAA\x9D" => %w[hook],
      "\xF0\x9F\xAA\xA2" => %w[knot],
      "\xF0\x9F\xA7\xB2" => %w[magnet],
      "\xF0\x9F\x94\xAB" => %w[gun],
      "\xF0\x9F\x92\xA3" => %w[bomb],
      "\xF0\x9F\xA7\xA8" => %w[firecracker],
      "\xF0\x9F\xAA\x93" => %w[axe],
      "\xF0\x9F\xAA\x9A" => %w[carpentry_saw],
      "\xF0\x9F\x94\xAA" => %w[knife],
      "\xF0\x9F\x97\xA1\xEF\xB8\x8F" => %w[dagger dagger_knife],
      "\xE2\x9A\x94\xEF\xB8\x8F" => %w[crossed_swords],
      "\xF0\x9F\x9B\xA1\xEF\xB8\x8F" => %w[shield],
      "\xF0\x9F\x9A\xAC" => %w[smoking],
      "\xE2\x9A\xB0\xEF\xB8\x8F" => %w[coffin],
      "\xF0\x9F\xAA\xA6" => %w[headstone],
      "\xE2\x9A\xB1\xEF\xB8\x8F" => %w[urn funeral_urn],
      "\xF0\x9F\x8F\xBA" => %w[amphora],
      "\xF0\x9F\xAA\x84" => %w[magic_wand],
      "\xF0\x9F\x94\xAE" => %w[crystal_ball],
      "\xF0\x9F\x93\xBF" => %w[prayer_beads],
      "\xF0\x9F\xA7\xBF" => %w[nazar_amulet],
      "\xF0\x9F\x92\x88" => %w[barber],
      "\xE2\x9A\x97\xEF\xB8\x8F" => %w[alembic],
      "\xF0\x9F\x94\xAD" => %w[telescope],
      "\xF0\x9F\x94\xAC" => %w[microscope],
      "\xF0\x9F\x95\xB3\xEF\xB8\x8F" => %w[hole],
      "\xF0\x9F\xAA\x9F" => %w[window],
      "\xF0\x9F\xA9\xB9" => %w[adhesive_bandage],
      "\xF0\x9F\xA9\xBA" => %w[stethoscope],
      "\xF0\x9F\x92\x8A" => %w[pill],
      "\xF0\x9F\x92\x89" => %w[syringe],
      "\xF0\x9F\xA9\xB8" => %w[drop_of_blood],
      "\xF0\x9F\xA7\xAC" => %w[dna],
      "\xF0\x9F\xA6\xA0" => %w[microbe],
      "\xF0\x9F\xA7\xAB" => %w[petri_dish],
      "\xF0\x9F\xA7\xAA" => %w[test_tube],
      "\xF0\x9F\x8C\xA1\xEF\xB8\x8F" => %w[thermometer],
      "\xF0\x9F\xAA\xA4" => %w[mouse_trap],
      "\xF0\x9F\xA7\xB9" => %w[broom],
      "\xF0\x9F\xA7\xBA" => %w[basket],
      "\xF0\x9F\xAA\xA1" => %w[sewing_needle],
      "\xF0\x9F\xA7\xBB" => %w[roll_of_paper],
      "\xF0\x9F\x9A\xBD" => %w[toilet],
      "\xF0\x9F\xAA\xA0" => %w[plunger],
      "\xF0\x9F\xAA\xA3" => %w[bucket],
      "\xF0\x9F\x9A\xB0" => %w[potable_water],
      "\xF0\x9F\x9A\xBF" => %w[shower],
      "\xF0\x9F\x9B\x81" => %w[bathtub],
      "\xF0\x9F\x9B\x80" => %w[bath],
      "\xF0\x9F\xAA\xA5" => %w[toothbrush],
      "\xF0\x9F\xA7\xBC" => %w[soap],
      "\xF0\x9F\xAA\x92" => %w[razor],
      "\xF0\x9F\xA7\xBD" => %w[sponge],
      "\xF0\x9F\xA7\xB4" => %w[squeeze_bottle],
      "\xF0\x9F\x9B\x8E\xEF\xB8\x8F" => %w[bellhop bellhop_bell],
      "\xF0\x9F\x97\x9D\xEF\xB8\x8F" => %w[key],
      "\xF0\x9F\x9A\xAA" => %w[door],
      "\xF0\x9F\xAA\x91" => %w[chair],
      "\xF0\x9F\xAA\x9E" => %w[mirror],
      "\xF0\x9F\x9B\x8B\xEF\xB8\x8F" => %w[couch couch_and_lamp],
      "\xF0\x9F\x9B\x8F\xEF\xB8\x8F" => %w[bed],
      "\xF0\x9F\x9B\x8C" => %w[sleeping_accommodation],
      "\xF0\x9F\xA7\xB8" => %w[teddy_bear],
      "\xF0\x9F\x96\xBC\xEF\xB8\x8F" => %w[frame_photo frame_with_picture],
      "\xF0\x9F\x9B\x8D\xEF\xB8\x8F" => %w[shopping_bags],
      "\xF0\x9F\x9B\x92" => %w[shopping_cart shopping_trolley],
      "\xF0\x9F\x8E\x81" => %w[gift],
      "\xF0\x9F\x8E\x88" => %w[balloon],
      "\xF0\x9F\x8E\x8F" => %w[flags],
      "\xF0\x9F\x8E\x80" => %w[ribbon],
      "\xF0\x9F\x8E\x8A" => %w[confetti_ball],
      "\xF0\x9F\x8E\x89" => %w[tada],
      "\xC3\xB1ata\xF0\x9F\xAA\x85" => %w[pi],
      "\xF0\x9F\xAA\x86" => %w[nesting_dolls],
      "\xF0\x9F\x8E\x8E" => %w[dolls],
      "\xF0\x9F\x8F\xAE" => %w[izakaya_lantern],
      "\xF0\x9F\x8F\x97\xEF\xB8\x8F" => %w[construction_site building_construction],
      "\xF0\x9F\x8F\xAD" => %w[factory],
      "\xF0\x9F\x8F\xA2" => %w[office],
      "\xF0\x9F\x8F\xAC" => %w[department_store],
      "\xF0\x9F\x8F\xA3" => %w[post_office],
      "\xF0\x9F\x8F\xA4" => %w[european_post_office],
      "\xF0\x9F\x8F\xA5" => %w[hospital],
      "\xF0\x9F\x8F\xA6" => %w[bank],
      "\xF0\x9F\x8F\xA8" => %w[hotel],
      "\xF0\x9F\x8F\xAA" => %w[convenience_store],
      "\xF0\x9F\x8F\xAB" => %w[school],
      "\xF0\x9F\x8F\xA9" => %w[love_hotel],
      "\xF0\x9F\x92\x92" => %w[wedding],
      "\xF0\x9F\x8F\x9B\xEF\xB8\x8F" => %w[classical_building],
      "\xE2\x9B\xAA" => %w[church],
      "\xF0\x9F\x95\x8C" => %w[mosque],
      "\xF0\x9F\x95\x8D" => %w[synagogue],
      "\xF0\x9F\x9B\x95" => %w[hindu_temple],
      "\xF0\x9F\x95\x8B" => %w[kaaba],
      "\xE2\x9B\xA9\xEF\xB8\x8F" => %w[shinto_shrine],
      "\xF0\x9F\x9B\xA4\xEF\xB8\x8F" => %w[railway_track railroad_track],
      "\xF0\x9F\x9B\xA3\xEF\xB8\x8F" => %w[motorway],
      "\xF0\x9F\x97\xBE" => %w[japan],
      "\xF0\x9F\x8E\x91" => %w[rice_scene],
      "\xF0\x9F\x8F\x9E\xEF\xB8\x8F" => %w[park national_park],
      "\xF0\x9F\x8C\x85" => %w[sunrise],
      "\xF0\x9F\x8C\x84" => %w[sunrise_over_mountains],
      "\xF0\x9F\x8C\xA0" => %w[stars],
      "\xF0\x9F\x8E\x87" => %w[sparkler],
      "\xF0\x9F\x8E\x86" => %w[fireworks],
      "\xF0\x9F\x8C\x87" => %w[city_sunset city_sunrise],
      "\xF0\x9F\x8C\x86" => %w[city_dusk],
      "\xF0\x9F\x8F\x99\xEF\xB8\x8F" => %w[cityscape],
      "\xF0\x9F\x8C\x83" => %w[night_with_stars],
      "\xF0\x9F\x8C\x8C" => %w[milky_way],
      "\xF0\x9F\x8C\x89" => %w[bridge_at_night],
      "\xF0\x9F\x8C\x81" => %w[foggy],
      "\xE2\x8C\x9A" => %w[watch],
      "\xF0\x9F\x93\xB1" => %w[mobile_phone iphone],
      "\xF0\x9F\x93\xB2" => %w[calling],
      "\xF0\x9F\x92\xBB" => %w[computer],
      "\xE2\x8C\xA8\xEF\xB8\x8F" => %w[keyboard],
      "\xF0\x9F\x96\xA5\xEF\xB8\x8F" => %w[desktop desktop_computer],
      "\xF0\x9F\x96\xA8\xEF\xB8\x8F" => %w[printer],
      "\xF0\x9F\x96\xB1\xEF\xB8\x8F" => %w[mouse_three_button three_button_mouse],
      "\xF0\x9F\x96\xB2\xEF\xB8\x8F" => %w[trackball],
      "\xF0\x9F\x95\xB9\xEF\xB8\x8F" => %w[joystick],
      "\xF0\x9F\x97\x9C\xEF\xB8\x8F" => %w[compression],
      "\xF0\x9F\x92\xBD" => %w[minidisc],
      "\xF0\x9F\x92\xBE" => %w[floppy_disk],
      "\xF0\x9F\x92\xBF" => %w[cd],
      "\xF0\x9F\x93\x80" => %w[dvd],
      "\xF0\x9F\x93\xBC" => %w[vhs],
      "\xF0\x9F\x93\xB7" => %w[camera],
      "\xF0\x9F\x93\xB8" => %w[camera_with_flash],
      "\xF0\x9F\x93\xB9" => %w[video_camera],
      "\xF0\x9F\x8E\xA5" => %w[movie_camera],
      "\xF0\x9F\x93\xBD\xEF\xB8\x8F" => %w[projector film_projector],
      "\xF0\x9F\x8E\x9E\xEF\xB8\x8F" => %w[film_frames],
      "\xF0\x9F\x93\x9E" => %w[telephone_receiver],
      "\xE2\x98\x8E\xEF\xB8\x8F" => %w[telephone],
      "\xF0\x9F\x93\x9F" => %w[pager],
      "\xF0\x9F\x93\xA0" => %w[fax],
      "\xF0\x9F\x93\xBA" => %w[tv],
      "\xF0\x9F\x93\xBB" => %w[radio],
      "\xF0\x9F\x8E\xA4" => %w[microphone],
      "\xF0\x9F\x8E\x9A\xEF\xB8\x8F" => %w[level_slider],
      "\xF0\x9F\x8E\x9B\xEF\xB8\x8F" => %w[control_knobs],
      "\xF0\x9F\xA7\xAD" => %w[compass],
      "\xE2\x8F\xB1\xEF\xB8\x8F" => %w[stopwatch],
      "\xE2\x8F\xB2\xEF\xB8\x8F" => %w[timer timer_clock],
      "\xE2\x8F\xB0" => %w[alarm_clock],
      "\xE2\x8C\x9B" => %w[hourglass],
      "\xE2\x8F\xB3" => %w[hourglass_flowing_sand],
      "\xF0\x9F\x93\xA1" => %w[satellite],
      "\xF0\x9F\x94\x8B" => %w[battery],
      "\xF0\x9F\x94\x8C" => %w[electric_plug],
      "\xF0\x9F\x92\xA1" => %w[bulb],
      "\xF0\x9F\x94\xA6" => %w[flashlight],
      "\xF0\x9F\x95\xAF\xEF\xB8\x8F" => %w[candle],
      "\xF0\x9F\xAA\x94" => %w[diya_lamp],
      "\xF0\x9F\xA7\xAF" => %w[fire_extinguisher],
      "\xF0\x9F\x9B\xA2\xEF\xB8\x8F" => %w[oil oil_drum],
      "\xF0\x9F\xA6\xBD" => %w[manual_wheelchair],
      "\xF0\x9F\xA6\xBC" => %w[motorized_wheelchair],
      "\xF0\x9F\x9B\xB4" => %w[scooter],
      "\xF0\x9F\x9A\xB2" => %w[bike],
      "\xF0\x9F\x9B\xB5" => %w[motor_scooter motorbike],
      "\xF0\x9F\x8F\x8D\xEF\xB8\x8F" => %w[motorcycle racing_motorcycle],
      "\xF0\x9F\x9B\xBA" => %w[auto_rickshaw],
      "\xF0\x9F\x9A\xA8" => %w[rotating_light],
      "\xF0\x9F\x9A\x94" => %w[oncoming_police_car],
      "\xF0\x9F\x9A\x8D" => %w[oncoming_bus],
      "\xF0\x9F\x9A\x98" => %w[oncoming_automobile],
      "\xF0\x9F\x9A\x96" => %w[oncoming_taxi],
      "\xF0\x9F\x9A\xA1" => %w[aerial_tramway],
      "\xF0\x9F\x9A\xA0" => %w[mountain_cableway],
      "\xF0\x9F\x9A\x9F" => %w[suspension_railway],
      "\xF0\x9F\x9A\x83" => %w[railway_car],
      "\xF0\x9F\x9A\x86" => %w[train],
      "\xF0\x9F\x9A\x9E" => %w[mountain_railway],
      "\xF0\x9F\x9A\x9D" => %w[monorail],
      "\xF0\x9F\x9A\x84" => %w[bullettrain_side],
      "\xF0\x9F\x9A\x85" => %w[bullettrain_front],
      "\xF0\x9F\x9A\x88" => %w[light_rail],
      "\xF0\x9F\x9A\x82" => %w[steam_locomotive],
      "\xF0\x9F\x9A\x87" => %w[metro],
      "\xF0\x9F\x9A\x8A" => %w[tram],
      "\xF0\x9F\x9A\x89" => %w[station],
      "\xE2\x9C\x88\xEF\xB8\x8F" => %w[airplane],
      "\xF0\x9F\x9B\xAB" => %w[airplane_departure],
      "\xF0\x9F\x9B\xAC" => %w[airplane_arriving],
      "\xF0\x9F\x9B\xA9\xEF\xB8\x8F" => %w[airplane_small small_airplane],
      "\xF0\x9F\x92\xBA" => %w[seat],
      "\xF0\x9F\x9B\xB0\xEF\xB8\x8F" => %w[satellite_orbital],
      "\xF0\x9F\x9A\x80" => %w[rocket],
      "\xF0\x9F\x9B\xB8" => %w[flying_saucer],
      "\xF0\x9F\x9A\x81" => %w[helicopter],
      "\xF0\x9F\x9B\xB6" => %w[canoe kayak],
      "\xE2\x9B\xB5" => %w[sailboat],
      "\xF0\x9F\x9A\xA4" => %w[speedboat],
      "\xF0\x9F\x9B\xA5\xEF\xB8\x8F" => %w[motorboat],
      "\xF0\x9F\x9B\xB3\xEF\xB8\x8F" => %w[cruise_ship passenger_ship],
      "\xE2\x9B\xB4\xEF\xB8\x8F" => %w[ferry],
      "\xF0\x9F\x9A\xA2" => %w[ship],
      "\xE2\x9A\x93" => %w[anchor],
      "\xE2\x9B\xBD" => %w[fuelpump],
      "\xF0\x9F\x9A\xA7" => %w[construction],
      "\xF0\x9F\x9A\xA6" => %w[vertical_traffic_light],
      "\xF0\x9F\x9A\xA5" => %w[traffic_light],
      "\xF0\x9F\x9A\x8F" => %w[busstop],
      "\xF0\x9F\x97\xBA\xEF\xB8\x8F" => %w[map world_map],
      "\xF0\x9F\x97\xBF" => %w[moyai],
      "\xF0\x9F\x97\xBD" => %w[statue_of_liberty],
      "\xF0\x9F\x97\xBC" => %w[tokyo_tower],
      "\xF0\x9F\x8F\xB0" => %w[european_castle],
      "\xF0\x9F\x8F\xAF" => %w[japanese_castle],
      "\xF0\x9F\x8F\x9F\xEF\xB8\x8F" => %w[stadium],
      "\xF0\x9F\x8E\xA1" => %w[ferris_wheel],
      "\xF0\x9F\x8E\xA2" => %w[roller_coaster],
      "\xF0\x9F\x8E\xA0" => %w[carousel_horse],
      "\xE2\x9B\xB2" => %w[fountain],
      "\xE2\x9B\xB1\xEF\xB8\x8F" => %w[beach_umbrella umbrella_on_ground],
      "\xF0\x9F\x8F\x96\xEF\xB8\x8F" => %w[beach beach_with_umbrella],
      "\xF0\x9F\x8F\x9D\xEF\xB8\x8F" => %w[island desert_island],
      "\xF0\x9F\x8F\x9C\xEF\xB8\x8F" => %w[desert],
      "\xF0\x9F\x8C\x8B" => %w[volcano],
      "\xE2\x9B\xB0\xEF\xB8\x8F" => %w[mountain],
      "\xF0\x9F\x8F\x94\xEF\xB8\x8F" => %w[mountain_snow snow_capped_mountain],
      "\xF0\x9F\x97\xBB" => %w[mount_fuji],
      "\xF0\x9F\x8F\x95\xEF\xB8\x8F" => %w[camping],
      "\xE2\x9B\xBA" => %w[tent],
      "\xF0\x9F\x8F\xA0" => %w[house],
      "\xF0\x9F\x8F\xA1" => %w[house_with_garden],
      "\xF0\x9F\x8F\x98\xEF\xB8\x8F" => %w[homes house_buildings],
      "\xF0\x9F\x8F\x9A\xEF\xB8\x8F" => %w[house_abandoned derelict_house_building],
      "\xF0\x9F\x9B\x96" => %w[hut],
      "\xF0\x9F\x8F\x84" => %w[person_surfing surfer],
      "\xF0\x9F\x8F\x84\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_surfing],
      "\xF0\x9F\x8F\x84\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_surfing],
      "\xF0\x9F\x8F\x8A" => %w[person_swimming swimmer],
      "\xF0\x9F\x8F\x8A\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_swimming],
      "\xF0\x9F\x8F\x8A\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_swimming],
      "\xF0\x9F\xA4\xBD" => %w[person_playing_water_polo water_polo],
      "\xF0\x9F\xA4\xBD\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_playing_water_polo],
      "\xF0\x9F\xA4\xBD\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_playing_water_polo],
      "\xF0\x9F\x9A\xA3" => %w[person_rowing_boat rowboat],
      "\xF0\x9F\x9A\xA3\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_rowing_boat],
      "\xF0\x9F\x9A\xA3\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_rowing_boat],
      "\xF0\x9F\xA7\x97" => %w[person_climbing],
      "\xF0\x9F\xA7\x97\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_climbing],
      "\xF0\x9F\xA7\x97\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_climbing],
      "\xF0\x9F\x9A\xB5" => %w[person_mountain_biking mountain_bicyclist],
      "\xF0\x9F\x9A\xB5\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_mountain_biking],
      "\xF0\x9F\x9A\xB5\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_mountain_biking],
      "\xF0\x9F\x9A\xB4" => %w[person_biking bicyclist],
      "\xF0\x9F\x9A\xB4\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_biking],
      "\xF0\x9F\x9A\xB4\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_biking],
      "\xF0\x9F\x8F\x86" => %w[trophy],
      "\xF0\x9F\xA5\x87" => %w[first_place first_place_medal],
      "\xF0\x9F\xA5\x88" => %w[second_place second_place_medal],
      "\xF0\x9F\xA5\x89" => %w[third_place third_place_medal],
      "\xF0\x9F\x8F\x85" => %w[medal sports_medal],
      "\xF0\x9F\x8E\x96\xEF\xB8\x8F" => %w[military_medal],
      "\xF0\x9F\x8F\xB5\xEF\xB8\x8F" => %w[rosette],
      "\xF0\x9F\x8E\x97\xEF\xB8\x8F" => %w[reminder_ribbon],
      "\xF0\x9F\x8E\xAB" => %w[ticket],
      "\xF0\x9F\x8E\x9F\xEF\xB8\x8F" => %w[tickets admission_tickets],
      "\xF0\x9F\x8E\xAA" => %w[circus_tent],
      "\xF0\x9F\xA4\xB9" => %w[person_juggling juggling juggler],
      "\xF0\x9F\xA4\xB9\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_juggling],
      "\xF0\x9F\xA4\xB9\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_juggling],
      "\xF0\x9F\x8E\xAD" => %w[performing_arts],
      "\xF0\x9F\xA9\xB0" => %w[ballet_shoes],
      "\xF0\x9F\x8E\xA8" => %w[art],
      "\xF0\x9F\x8E\xAC" => %w[clapper],
      "\xF0\x9F\x8E\xA7" => %w[headphones],
      "\xF0\x9F\x8E\xBC" => %w[musical_score],
      "\xF0\x9F\x8E\xB9" => %w[musical_keyboard],
      "\xF0\x9F\xA5\x81" => %w[drum drum_with_drumsticks],
      "\xF0\x9F\xAA\x98" => %w[long_drum],
      "\xF0\x9F\x8E\xB7" => %w[saxophone],
      "\xF0\x9F\x8E\xBA" => %w[trumpet],
      "\xF0\x9F\x8E\xB8" => %w[guitar],
      "\xF0\x9F\xAA\x95" => %w[banjo],
      "\xF0\x9F\x8E\xBB" => %w[violin],
      "\xF0\x9F\xAA\x97" => %w[accordion],
      "\xF0\x9F\x8E\xB2" => %w[game_die],
      "\xE2\x99\x9F\xEF\xB8\x8F" => %w[chess_pawn],
      "\xF0\x9F\x8E\xAF" => %w[dart],
      "\xF0\x9F\x8E\xB3" => %w[bowling],
      "\xF0\x9F\x8E\xAE" => %w[video_game],
      "\xF0\x9F\x8E\xB0" => %w[slot_machine],
      "\xF0\x9F\xA7\xA9" => %w[jigsaw],
      "\xF0\x9F\x9A\x97" => %w[red_car],
      "\xF0\x9F\x9A\x95" => %w[taxi],
      "\xF0\x9F\x9A\x99" => %w[blue_car],
      "\xF0\x9F\x9B\xBB" => %w[pickup_truck],
      "\xF0\x9F\x9A\x8C" => %w[bus],
      "\xF0\x9F\x9A\x8E" => %w[trolleybus],
      "\xF0\x9F\x8F\x8E\xEF\xB8\x8F" => %w[race_car racing_car],
      "\xF0\x9F\x9A\x93" => %w[police_car],
      "\xF0\x9F\x9A\x91" => %w[ambulance],
      "\xF0\x9F\x9A\x92" => %w[fire_engine],
      "\xF0\x9F\x9A\x90" => %w[minibus],
      "\xF0\x9F\x9A\x9A" => %w[truck],
      "\xF0\x9F\x9A\x9B" => %w[articulated_lorry],
      "\xF0\x9F\x9A\x9C" => %w[tractor],
      "\xF0\x9F\xA6\xAF" => %w[probing_cane],
      "\xF0\x9F\x8D\xB4" => %w[fork_and_knife],
      "\xF0\x9F\x8D\xBD\xEF\xB8\x8F" => %w[fork_knife_plate fork_and_knife_with_plate],
      "\xF0\x9F\xA5\xA3" => %w[bowl_with_spoon],
      "\xF0\x9F\xA5\xA1" => %w[takeout_box],
      "\xF0\x9F\xA5\xA2" => %w[chopsticks],
      "\xF0\x9F\xA7\x82" => %w[salt],
      "\xE2\x9A\xBD" => %w[soccer],
      "\xF0\x9F\x8F\x80" => %w[basketball],
      "\xF0\x9F\x8F\x88" => %w[football],
      "\xE2\x9A\xBE" => %w[baseball],
      "\xF0\x9F\xA5\x8E" => %w[softball],
      "\xF0\x9F\x8E\xBE" => %w[tennis],
      "\xF0\x9F\x8F\x90" => %w[volleyball],
      "\xF0\x9F\x8F\x89" => %w[rugby_football],
      "\xF0\x9F\xA5\x8F" => %w[flying_disc],
      "\xF0\x9F\xAA\x83" => %w[boomerang],
      "\xF0\x9F\x8E\xB1" => %w[ball],
      "\xF0\x9F\xAA\x80" => %w[yo_yo],
      "\xF0\x9F\x8F\x93" => %w[ping_pong table_tennis],
      "\xF0\x9F\x8F\xB8" => %w[badminton],
      "\xF0\x9F\x8F\x92" => %w[hockey],
      "\xF0\x9F\x8F\x91" => %w[field_hockey],
      "\xF0\x9F\xA5\x8D" => %w[lacrosse],
      "\xF0\x9F\x8F\x8F" => %w[cricket_game cricket_bat_ball],
      "\xF0\x9F\xA5\x85" => %w[goal goal_net],
      "\xE2\x9B\xB3" => %w[golf],
      "\xF0\x9F\xAA\x81" => %w[kite],
      "\xF0\x9F\x8F\xB9" => %w[bow_and_arrow archery],
      "\xF0\x9F\x8E\xA3" => %w[fishing_pole_and_fish],
      "\xF0\x9F\xA4\xBF" => %w[diving_mask],
      "\xF0\x9F\xA5\x8A" => %w[boxing_glove boxing_gloves],
      "\xF0\x9F\xA5\x8B" => %w[martial_arts_uniform karate_uniform],
      "\xF0\x9F\x8E\xBD" => %w[running_shirt_with_sash],
      "\xF0\x9F\x9B\xB9" => %w[skateboard],
      "\xF0\x9F\x9B\xBC" => %w[roller_skate],
      "\xF0\x9F\x9B\xB7" => %w[sled],
      "\xE2\x9B\xB8\xEF\xB8\x8F" => %w[ice_skate],
      "\xF0\x9F\xA5\x8C" => %w[curling_stone],
      "\xF0\x9F\x8E\xBF" => %w[ski],
      "\xE2\x9B\xB7\xEF\xB8\x8F" => %w[skier],
      "\xF0\x9F\x8F\x82" => %w[snowboarder],
      "\xF0\x9F\xAA\x82" => %w[parachute],
      "\xF0\x9F\x8F\x8B\xEF\xB8\x8F" => %w[person_lifting_weights lifter weight_lifter],
      "\xF0\x9F\x8F\x8B\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_lifting_weights],
      "\xF0\x9F\x8F\x8B\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_lifting_weights],
      "\xF0\x9F\xA4\xBC" => %w[people_wrestling wrestlers wrestling],
      "\xF0\x9F\xA4\xBC\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[women_wrestling],
      "\xF0\x9F\xA4\xBC\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[men_wrestling],
      "\xF0\x9F\xA4\xB8" => %w[person_doing_cartwheel cartwheel],
      "\xF0\x9F\xA4\xB8\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_cartwheeling],
      "\xF0\x9F\xA4\xB8\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_cartwheeling],
      "\xE2\x9B\xB9\xEF\xB8\x8F" => %w[person_bouncing_ball basketball_player person_with_ball],
      "\xE2\x9B\xB9\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_bouncing_ball],
      "\xE2\x9B\xB9\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_bouncing_ball],
      "\xF0\x9F\xA4\xBA" => %w[person_fencing fencer fencing],
      "\xF0\x9F\xA4\xBE" => %w[person_playing_handball handball],
      "\xF0\x9F\xA4\xBE\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_playing_handball],
      "\xF0\x9F\xA4\xBE\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_playing_handball],
      "\xF0\x9F\x8F\x8C\xEF\xB8\x8F" => %w[person_golfing golfer],
      "\xF0\x9F\x8F\x8C\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_golfing],
      "\xF0\x9F\x8F\x8C\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_golfing],
      "\xF0\x9F\x8F\x87" => %w[horse_racing],
      "\xF0\x9F\xA7\x98" => %w[person_in_lotus_position],
      "\xF0\x9F\xA7\x98\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_in_lotus_position],
      "\xF0\x9F\xA7\x98\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_in_lotus_position],
      "\xF0\x9F\xA5\x91" => %w[avocado],
      "\xF0\x9F\xAB\x92" => %w[olive],
      "\xF0\x9F\xA5\xA6" => %w[broccoli],
      "\xF0\x9F\xA5\xAC" => %w[leafy_green],
      "\xF0\x9F\xAB\x91" => %w[bell_pepper],
      "\xF0\x9F\xA5\x92" => %w[cucumber],
      "\xF0\x9F\x8C\xB6\xEF\xB8\x8F" => %w[hot_pepper],
      "\xF0\x9F\x8C\xBD" => %w[corn],
      "\xF0\x9F\xA5\x95" => %w[carrot],
      "\xF0\x9F\xA7\x84" => %w[garlic],
      "\xF0\x9F\xA7\x85" => %w[onion],
      "\xF0\x9F\xA5\x94" => %w[potato],
      "\xF0\x9F\x8D\xA0" => %w[sweet_potato],
      "\xF0\x9F\xA5\x90" => %w[croissant],
      "\xF0\x9F\xA5\xAF" => %w[bagel],
      "\xF0\x9F\x8D\x9E" => %w[bread],
      "\xF0\x9F\xA5\x96" => %w[french_bread baguette_bread],
      "\xF0\x9F\xAB\x93" => %w[flatbread],
      "\xF0\x9F\xA5\xA8" => %w[pretzel],
      "\xF0\x9F\xA7\x80" => %w[cheese cheese_wedge],
      "\xF0\x9F\xA5\x9A" => %w[egg],
      "\xF0\x9F\x8D\xB3" => %w[cooking],
      "\xF0\x9F\xA7\x88" => %w[butter],
      "\xF0\x9F\xA5\x9E" => %w[pancakes],
      "\xF0\x9F\xA7\x87" => %w[waffle],
      "\xF0\x9F\xA5\x93" => %w[bacon],
      "\xF0\x9F\xA5\xA9" => %w[cut_of_meat],
      "\xF0\x9F\x8D\x97" => %w[poultry_leg],
      "\xF0\x9F\x8D\x96" => %w[meat_on_bone],
      "\xF0\x9F\x8C\xAD" => %w[hotdog hot_dog],
      "\xF0\x9F\x8D\x94" => %w[hamburger],
      "\xF0\x9F\x8D\x9F" => %w[fries],
      "\xF0\x9F\x8D\x95" => %w[pizza],
      "\xF0\x9F\xA5\xAA" => %w[sandwich],
      "\xF0\x9F\xA5\x99" => %w[stuffed_flatbread stuffed_pita],
      "\xF0\x9F\xA7\x86" => %w[falafel],
      "\xF0\x9F\x8C\xAE" => %w[taco],
      "\xF0\x9F\x8C\xAF" => %w[burrito],
      "\xF0\x9F\xAB\x94" => %w[tamale],
      "\xF0\x9F\xA5\x97" => %w[salad green_salad],
      "\xF0\x9F\xA5\x98" => %w[shallow_pan_of_food paella],
      "\xF0\x9F\xAB\x95" => %w[fondue],
      "\xF0\x9F\xA5\xAB" => %w[canned_food],
      "\xF0\x9F\x8D\x9D" => %w[spaghetti],
      "\xF0\x9F\x8D\x9C" => %w[ramen],
      "\xF0\x9F\x8D\xB2" => %w[stew],
      "\xF0\x9F\x8D\x9B" => %w[curry],
      "\xF0\x9F\x8D\xA3" => %w[sushi],
      "\xF0\x9F\x8D\xB1" => %w[bento],
      "\xF0\x9F\xA5\x9F" => %w[dumpling],
      "\xF0\x9F\xA6\xAA" => %w[oyster],
      "\xF0\x9F\x8D\xA4" => %w[fried_shrimp],
      "\xF0\x9F\x8D\x99" => %w[rice_ball],
      "\xF0\x9F\x8D\x9A" => %w[rice],
      "\xF0\x9F\x8D\x98" => %w[rice_cracker],
      "\xF0\x9F\x8D\xA5" => %w[fish_cake],
      "\xF0\x9F\xA5\xA0" => %w[fortune_cookie],
      "\xF0\x9F\xA5\xAE" => %w[moon_cake],
      "\xF0\x9F\x8D\xA2" => %w[oden],
      "\xF0\x9F\x8D\xA1" => %w[dango],
      "\xF0\x9F\x8D\xA7" => %w[shaved_ice],
      "\xF0\x9F\x8D\xA8" => %w[ice_cream],
      "\xF0\x9F\x8D\xA6" => %w[icecream],
      "\xF0\x9F\xA5\xA7" => %w[pie],
      "\xF0\x9F\xA7\x81" => %w[cupcake],
      "\xF0\x9F\x8D\xB0" => %w[cake],
      "\xF0\x9F\x8E\x82" => %w[birthday],
      "\xF0\x9F\x8D\xAE" => %w[custard pudding flan],
      "\xF0\x9F\x8D\xAD" => %w[lollipop],
      "\xF0\x9F\x8D\xAC" => %w[candy],
      "\xF0\x9F\x8D\xAB" => %w[chocolate_bar],
      "\xF0\x9F\x8D\xBF" => %w[popcorn],
      "\xF0\x9F\x8D\xA9" => %w[doughnut],
      "\xF0\x9F\x8D\xAA" => %w[cookie],
      "\xF0\x9F\x8C\xB0" => %w[chestnut],
      "\xF0\x9F\xA5\x9C" => %w[peanuts shelled_peanut],
      "\xF0\x9F\x8D\xAF" => %w[honey_pot],
      "\xF0\x9F\xA5\x9B" => %w[milk glass_of_milk],
      "\xF0\x9F\x8D\xBC" => %w[baby_bottle],
      "\xE2\x98\x95" => %w[coffee],
      "\xF0\x9F\xAB\x96" => %w[teapot],
      "\xF0\x9F\xA7\x89" => %w[mate],
      "\xF0\x9F\xA7\x8B" => %w[bubble_tea],
      "\xF0\x9F\xA7\x83" => %w[beverage_box],
      "\xF0\x9F\xA5\xA4" => %w[cup_with_straw],
      "\xF0\x9F\x8D\xB6" => %w[sake],
      "\xF0\x9F\x8D\xBA" => %w[beer],
      "\xF0\x9F\x8D\xBB" => %w[beers],
      "\xF0\x9F\xA5\x82" => %w[champagne_glass clinking_glass],
      "\xF0\x9F\x8D\xB7" => %w[wine_glass],
      "\xF0\x9F\xA5\x83" => %w[tumbler_glass whisky],
      "\xF0\x9F\x8D\xB8" => %w[cocktail],
      "\xF0\x9F\x8D\xB9" => %w[tropical_drink],
      "\xF0\x9F\x8D\xBE" => %w[champagne bottle_with_popping_cork],
      "\xF0\x9F\xA7\x8A" => %w[ice_cube],
      "\xF0\x9F\xA5\x84" => %w[spoon],
      "\xF0\x9F\x8C\xBE" => %w[ear_of_rice],
      "\xF0\x9F\xAA\xB4" => %w[potted_plant],
      "\xF0\x9F\x92\x90" => %w[bouquet],
      "\xF0\x9F\x8C\xB7" => %w[tulip],
      "\xF0\x9F\x8C\xB9" => %w[rose],
      "\xF0\x9F\xA5\x80" => %w[wilted_rose wilted_flower],
      "\xF0\x9F\x8C\xBA" => %w[hibiscus],
      "\xF0\x9F\x8C\xB8" => %w[cherry_blossom],
      "\xF0\x9F\x8C\xBC" => %w[blossom],
      "\xF0\x9F\x8C\xBB" => %w[sunflower],
      "\xF0\x9F\x8C\x9E" => %w[sun_with_face],
      "\xF0\x9F\x8C\x9D" => %w[full_moon_with_face],
      "\xF0\x9F\x8C\x9B" => %w[first_quarter_moon_with_face],
      "\xF0\x9F\x8C\x9C" => %w[last_quarter_moon_with_face],
      "\xF0\x9F\x8C\x9A" => %w[new_moon_with_face],
      "\xF0\x9F\x8C\x95" => %w[full_moon],
      "\xF0\x9F\x8C\x96" => %w[waning_gibbous_moon],
      "\xF0\x9F\x8C\x97" => %w[last_quarter_moon],
      "\xF0\x9F\x8C\x98" => %w[waning_crescent_moon],
      "\xF0\x9F\x8C\x91" => %w[new_moon],
      "\xF0\x9F\x8C\x92" => %w[waxing_crescent_moon],
      "\xF0\x9F\x8C\x93" => %w[first_quarter_moon],
      "\xF0\x9F\x8C\x94" => %w[waxing_gibbous_moon],
      "\xF0\x9F\x8C\x99" => %w[crescent_moon],
      "\xF0\x9F\x8C\x8E" => %w[earth_americas],
      "\xF0\x9F\x8C\x8D" => %w[earth_africa],
      "\xF0\x9F\x8C\x8F" => %w[earth_asia],
      "\xF0\x9F\xAA\x90" => %w[ringed_planet],
      "\xF0\x9F\x92\xAB" => %w[dizzy],
      "\xF0\x9F\x8C\x9F" => %w[star],
      "\xE2\x9C\xA8" => %w[sparkles],
      "\xE2\x9A\xA1" => %w[zap],
      "\xE2\x98\x84\xEF\xB8\x8F" => %w[comet],
      "\xF0\x9F\x92\xA5" => %w[boom],
      "\xF0\x9F\x94\xA5" => %w[fire flame],
      "\xF0\x9F\x8C\xAA\xEF\xB8\x8F" => %w[cloud_tornado cloud_with_tornado],
      "\xF0\x9F\x8C\x88" => %w[rainbow],
      "\xE2\x98\x80\xEF\xB8\x8F" => %w[sunny],
      "\xF0\x9F\x8C\xA4\xEF\xB8\x8F" => %w[white_sun_small_cloud white_sun_with_small_cloud],
      "\xE2\x9B\x85" => %w[partly_sunny],
      "\xF0\x9F\x8C\xA5\xEF\xB8\x8F" => %w[white_sun_cloud white_sun_behind_cloud],
      "\xE2\x98\x81\xEF\xB8\x8F" => %w[cloud],
      "\xF0\x9F\x8C\xA6\xEF\xB8\x8F" => %w[white_sun_rain_cloud white_sun_behind_cloud_with_rain],
      "\xF0\x9F\x8C\xA7\xEF\xB8\x8F" => %w[cloud_rain cloud_with_rain],
      "\xE2\x9B\x88\xEF\xB8\x8F" => %w[thunder_cloud_rain thunder_cloud_and_rain],
      "\xF0\x9F\x8C\xA9\xEF\xB8\x8F" => %w[cloud_lightning cloud_with_lightning],
      "\xF0\x9F\x8C\xA8\xEF\xB8\x8F" => %w[cloud_snow cloud_with_snow],
      "\xE2\x9D\x84\xEF\xB8\x8F" => %w[snowflake],
      "\xE2\x9B\x84" => %w[snowman],
      "\xF0\x9F\x8C\xAC\xEF\xB8\x8F" => %w[wind_blowing_face],
      "\xF0\x9F\x92\xA8" => %w[dash],
      "\xF0\x9F\x92\xA7" => %w[droplet],
      "\xF0\x9F\x92\xA6" => %w[sweat_drops],
      "\xE2\x98\x82\xEF\xB8\x8F" => %w[umbrella],
      "\xF0\x9F\x8C\x8A" => %w[ocean],
      "\xF0\x9F\x8C\xAB\xEF\xB8\x8F" => %w[fog],
      "\xF0\x9F\x8D\x8F" => %w[green_apple],
      "\xF0\x9F\x8D\x8E" => %w[apple],
      "\xF0\x9F\x8D\x90" => %w[pear],
      "\xF0\x9F\x8D\x8A" => %w[tangerine],
      "\xF0\x9F\x8D\x8B" => %w[lemon],
      "\xF0\x9F\x8D\x8C" => %w[banana],
      "\xF0\x9F\x8D\x89" => %w[watermelon],
      "\xF0\x9F\x8D\x87" => %w[grapes],
      "\xF0\x9F\xAB\x90" => %w[blueberries],
      "\xF0\x9F\x8D\x93" => %w[strawberry],
      "\xF0\x9F\x8D\x88" => %w[melon],
      "\xF0\x9F\x8D\x92" => %w[cherries],
      "\xF0\x9F\x8D\x91" => %w[peach],
      "\xF0\x9F\xA5\xAD" => %w[mango],
      "\xF0\x9F\x8D\x8D" => %w[pineapple],
      "\xF0\x9F\xA5\xA5" => %w[coconut],
      "\xF0\x9F\xA5\x9D" => %w[kiwi kiwifruit],
      "\xF0\x9F\x8D\x85" => %w[tomato],
      "\xF0\x9F\x8D\x86" => %w[eggplant],
      "\xF0\x9F\x90\xB4" => %w[horse],
      "\xF0\x9F\xA6\x84" => %w[unicorn unicorn_face],
      "\xF0\x9F\x90\x9D" => %w[bee],
      "\xF0\x9F\x90\x9B" => %w[bug],
      "\xF0\x9F\xA6\x8B" => %w[butterfly],
      "\xF0\x9F\x90\x8C" => %w[snail],
      "\xF0\x9F\xAA\xB1" => %w[worm],
      "\xF0\x9F\x90\x9E" => %w[lady_beetle],
      "\xF0\x9F\x90\x9C" => %w[ant],
      "\xF0\x9F\xAA\xB0" => %w[fly],
      "\xF0\x9F\xA6\x9F" => %w[mosquito],
      "\xF0\x9F\xAA\xB3" => %w[cockroach],
      "\xF0\x9F\xAA\xB2" => %w[beetle],
      "\xF0\x9F\xA6\x97" => %w[cricket],
      "\xF0\x9F\x95\xB7\xEF\xB8\x8F" => %w[spider],
      "\xF0\x9F\x95\xB8\xEF\xB8\x8F" => %w[spider_web],
      "\xF0\x9F\xA6\x82" => %w[scorpion],
      "\xF0\x9F\x90\xA2" => %w[turtle],
      "\xF0\x9F\x90\x8D" => %w[snake],
      "\xF0\x9F\xA6\x8E" => %w[lizard],
      "\xF0\x9F\xA6\x96" => %w[t_rex],
      "\xF0\x9F\xA6\x95" => %w[sauropod],
      "\xF0\x9F\x90\x99" => %w[octopus],
      "\xF0\x9F\xA6\x91" => %w[squid],
      "\xF0\x9F\xA6\x90" => %w[shrimp],
      "\xF0\x9F\xA6\x9E" => %w[lobster],
      "\xF0\x9F\xA6\x80" => %w[crab],
      "\xF0\x9F\x90\xA1" => %w[blowfish],
      "\xF0\x9F\x90\xA0" => %w[tropical_fish],
      "\xF0\x9F\x90\x9F" => %w[fish],
      "\xF0\x9F\xA6\xAD" => %w[seal],
      "\xF0\x9F\x90\xAC" => %w[dolphin],
      "\xF0\x9F\x90\x8B" => %w[whale],
      "\xF0\x9F\xA6\x88" => %w[shark],
      "\xF0\x9F\x90\x8A" => %w[crocodile],
      "\xF0\x9F\x90\xAF" => %w[tiger],
      "\xF0\x9F\x90\x86" => %w[leopard],
      "\xF0\x9F\xA6\x93" => %w[zebra],
      "\xF0\x9F\xA6\x8D" => %w[gorilla],
      "\xF0\x9F\xA6\xA7" => %w[orangutan],
      "\xF0\x9F\x90\x98" => %w[elephant],
      "\xF0\x9F\xA6\xA3" => %w[mammoth],
      "\xF0\x9F\xA6\xAC" => %w[bison],
      "\xF0\x9F\xA6\x9B" => %w[hippopotamus],
      "\xF0\x9F\xA6\x8F" => %w[rhino rhinoceros],
      "\xF0\x9F\x90\xAA" => %w[dromedary_camel],
      "\xF0\x9F\x90\xAB" => %w[camel],
      "\xF0\x9F\xA6\x92" => %w[giraffe],
      "\xF0\x9F\xA6\x98" => %w[kangaroo],
      "\xF0\x9F\x90\x83" => %w[water_buffalo],
      "\xF0\x9F\x90\x82" => %w[ox],
      "\xF0\x9F\x90\xAE" => %w[cow],
      "\xF0\x9F\x90\x8E" => %w[racehorse],
      "\xF0\x9F\x90\xB7" => %w[pig],
      "\xF0\x9F\x90\x8F" => %w[ram],
      "\xF0\x9F\x90\x91" => %w[sheep],
      "\xF0\x9F\xA6\x99" => %w[llama],
      "\xF0\x9F\x90\x90" => %w[goat],
      "\xF0\x9F\xA6\x8C" => %w[deer],
      "\xF0\x9F\x90\xB6" => %w[dog],
      "\xF0\x9F\x90\xA9" => %w[poodle],
      "\xF0\x9F\xA6\xAE" => %w[guide_dog],
      "\xF0\x9F\x90\x95\xE2\x80\x8D\xF0\x9F\xA6\xBA" => %w[service_dog],
      "\xF0\x9F\x90\xB1" => %w[cat],
      "\xF0\x9F\x90\x88\xE2\x80\x8D\xE2\xAC\x9B" => %w[black_cat],
      "\xF0\x9F\x90\x93" => %w[rooster],
      "\xF0\x9F\xA6\x83" => %w[turkey],
      "\xF0\x9F\xA6\x9A" => %w[peacock],
      "\xF0\x9F\xA6\x9C" => %w[parrot],
      "\xF0\x9F\xA6\xA2" => %w[swan],
      "\xF0\x9F\xA6\xA9" => %w[flamingo],
      "\xF0\x9F\x95\x8A\xEF\xB8\x8F" => %w[dove dove_of_peace],
      "\xF0\x9F\x90\xB0" => %w[rabbit],
      "\xF0\x9F\xA6\x9D" => %w[raccoon],
      "\xF0\x9F\xA6\xA8" => %w[skunk],
      "\xF0\x9F\xA6\xA1" => %w[badger],
      "\xF0\x9F\xA6\xAB" => %w[beaver],
      "\xF0\x9F\xA6\xA6" => %w[otter],
      "\xF0\x9F\xA6\xA5" => %w[sloth],
      "\xF0\x9F\x90\xAD" => %w[mouse],
      "\xF0\x9F\x90\x80" => %w[rat],
      "\xF0\x9F\x90\xBF\xEF\xB8\x8F" => %w[chipmunk],
      "\xF0\x9F\xA6\x94" => %w[hedgehog],
      "\xF0\x9F\x90\xBE" => %w[feet paw_prints],
      "\xF0\x9F\x90\x89" => %w[dragon],
      "\xF0\x9F\x90\xB2" => %w[dragon_face],
      "\xF0\x9F\x8C\xB5" => %w[cactus],
      "\xF0\x9F\x8E\x84" => %w[christmas_tree],
      "\xF0\x9F\x8C\xB2" => %w[evergreen_tree],
      "\xF0\x9F\x8C\xB3" => %w[deciduous_tree],
      "\xF0\x9F\x8C\xB4" => %w[palm_tree],
      "\xF0\x9F\x8C\xB1" => %w[seedling],
      "\xF0\x9F\x8C\xBF" => %w[herb],
      "\xE2\x98\x98\xEF\xB8\x8F" => %w[shamrock],
      "\xF0\x9F\x8D\x80" => %w[four_leaf_clover],
      "\xF0\x9F\x8E\x8D" => %w[bamboo],
      "\xF0\x9F\x8E\x8B" => %w[tanabata_tree],
      "\xF0\x9F\x8D\x83" => %w[leaves],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_woman_girl],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_woman_girl_boy],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_woman_boy_boy],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_woman_girl_girl],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_man_boy],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_man_girl],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_man_girl_boy],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_man_boy_boy],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_man_girl_girl],
      "\xF0\x9F\xA7\xB6" => %w[yarn],
      "\xF0\x9F\xA7\xB5" => %w[thread],
      "\xF0\x9F\xA7\xA5" => %w[coat],
      "\xF0\x9F\xA5\xBC" => %w[lab_coat],
      "\xF0\x9F\xA6\xBA" => %w[safety_vest],
      "\xF0\x9F\x91\x9A" => %w[womans_clothes],
      "\xF0\x9F\x91\x95" => %w[shirt],
      "\xF0\x9F\x91\x96" => %w[jeans],
      "\xF0\x9F\xA9\xB2" => %w[briefs],
      "\xF0\x9F\xA9\xB3" => %w[shorts],
      "\xF0\x9F\x91\x94" => %w[necktie],
      "\xF0\x9F\x91\x97" => %w[dress],
      "\xF0\x9F\x91\x99" => %w[bikini],
      "\xF0\x9F\xA9\xB1" => %w[one_piece_swimsuit],
      "\xF0\x9F\x91\x98" => %w[kimono],
      "\xF0\x9F\xA5\xBB" => %w[sari],
      "\xF0\x9F\xA5\xBF" => %w[womans_flat_shoe],
      "\xF0\x9F\x91\xA0" => %w[high_heel],
      "\xF0\x9F\x91\xA1" => %w[sandal],
      "\xF0\x9F\x91\xA2" => %w[boot],
      "\xF0\x9F\x91\x9E" => %w[mans_shoe],
      "\xF0\x9F\x91\x9F" => %w[athletic_shoe],
      "\xF0\x9F\xA5\xBE" => %w[hiking_boot],
      "\xF0\x9F\xA9\xB4" => %w[thong_sandal],
      "\xF0\x9F\xA7\xA6" => %w[socks],
      "\xF0\x9F\xA7\xA4" => %w[gloves],
      "\xF0\x9F\xA7\xA3" => %w[scarf],
      "\xF0\x9F\x8E\xA9" => %w[tophat],
      "\xF0\x9F\xA7\xA2" => %w[billed_cap],
      "\xF0\x9F\x91\x92" => %w[womans_hat],
      "\xF0\x9F\x8E\x93" => %w[mortar_board],
      "\xE2\x9B\x91\xEF\xB8\x8F" => %w[helmet_with_cross helmet_with_white_cross],
      "\xF0\x9F\xAA\x96" => %w[military_helmet],
      "\xF0\x9F\x91\x91" => %w[crown],
      "\xF0\x9F\x92\x8D" => %w[ring],
      "\xF0\x9F\x91\x9D" => %w[pouch],
      "\xF0\x9F\x91\x9B" => %w[purse],
      "\xF0\x9F\x91\x9C" => %w[handbag],
      "\xF0\x9F\x92\xBC" => %w[briefcase],
      "\xF0\x9F\x8E\x92" => %w[school_satchel],
      "\xF0\x9F\xA7\xB3" => %w[luggage],
      "\xF0\x9F\x91\x93" => %w[eyeglasses],
      "\xF0\x9F\x95\xB6\xEF\xB8\x8F" => %w[dark_sunglasses],
      "\xF0\x9F\xA5\xBD" => %w[goggles],
      "\xF0\x9F\x8C\x82" => %w[closed_umbrella],
      "\xF0\x9F\x90\xB9" => %w[hamster],
      "\xF0\x9F\xA6\x8A" => %w[fox fox_face],
      "\xF0\x9F\x90\xBB" => %w[bear],
      "\xF0\x9F\x90\xBC" => %w[panda_face],
      "\xF0\x9F\x90\xBB\xE2\x80\x8D\xE2\x9D\x84\xEF\xB8\x8F" => %w[polar_bear],
      "\xF0\x9F\x90\xA8" => %w[koala],
      "\xF0\x9F\xA6\x81" => %w[lion_face lion],
      "\xF0\x9F\x90\xBD" => %w[pig_nose],
      "\xF0\x9F\x90\xB8" => %w[frog],
      "\xF0\x9F\x90\xB5" => %w[monkey_face],
      "\xF0\x9F\x99\x88" => %w[see_no_evil],
      "\xF0\x9F\x99\x89" => %w[hear_no_evil],
      "\xF0\x9F\x99\x8A" => %w[speak_no_evil],
      "\xF0\x9F\x90\x92" => %w[monkey],
      "\xF0\x9F\x90\x94" => %w[chicken],
      "\xF0\x9F\x90\xA7" => %w[penguin],
      "\xF0\x9F\x90\xA6" => %w[bird],
      "\xF0\x9F\x90\xA4" => %w[baby_chick],
      "\xF0\x9F\x90\xA3" => %w[hatching_chick],
      "\xF0\x9F\x90\xA5" => %w[hatched_chick],
      "\xF0\x9F\xA6\x86" => %w[duck],
      "\xF0\x9F\xA6\xA4" => %w[dodo],
      "\xF0\x9F\xA6\x85" => %w[eagle],
      "\xF0\x9F\xA6\x89" => %w[owl],
      "\xF0\x9F\xA6\x87" => %w[bat],
      "\xF0\x9F\x90\xBA" => %w[wolf],
      "\xF0\x9F\x90\x97" => %w[boar],
      "\xF0\x9F\x95\xBA" => %w[man_dancing male_dancer],
      "\xF0\x9F\x91\xAF" => %w[people_with_bunny_ears_partying dancers],
      "\xF0\x9F\x91\xAF\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[women_with_bunny_ears_partying],
      "\xF0\x9F\x91\xAF\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[men_with_bunny_ears_partying],
      "\xF0\x9F\x95\xB4\xEF\xB8\x8F" => %w[levitate man_in_business_suit_levitating],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xBD" => %w[person_in_manual_wheelchair],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xBD" => %w[woman_in_manual_wheelchair],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xBD" => %w[man_in_manual_wheelchair],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xBC" => %w[person_in_motorized_wheelchair],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xBC" => %w[woman_in_motorized_wheelchair],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xBC" => %w[man_in_motorized_wheelchair],
      "\xF0\x9F\x9A\xB6" => %w[person_walking walking],
      "\xF0\x9F\x9A\xB6\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_walking],
      "\xF0\x9F\x9A\xB6\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_walking],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xAF" => %w[person_with_probing_cane],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xAF" => %w[woman_with_probing_cane],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xAF" => %w[man_with_probing_cane],
      "\xF0\x9F\xA7\x8E" => %w[person_kneeling],
      "\xF0\x9F\xA7\x8E\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_kneeling],
      "\xF0\x9F\xA7\x8E\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_kneeling],
      "\xF0\x9F\x8F\x83" => %w[person_running runner],
      "\xF0\x9F\x8F\x83\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_running],
      "\xF0\x9F\x8F\x83\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_running],
      "\xF0\x9F\xA7\x8D" => %w[person_standing],
      "\xF0\x9F\xA7\x8D\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_standing],
      "\xF0\x9F\xA7\x8D\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_standing],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA4\x9D\xE2\x80\x8D\xF0\x9F\xA7\x91" => %w[people_holding_hands],
      "\xF0\x9F\x91\xAB" => %w[couple],
      "\xF0\x9F\x91\xAD" => %w[two_women_holding_hands],
      "\xF0\x9F\x91\xAC" => %w[two_men_holding_hands],
      "\xF0\x9F\x92\x91" => %w[couple_with_heart],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA8" => %w[couple_with_heart_woman_man],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA9" => %w[couple_ww couple_with_heart_ww],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x91\xA8" => %w[couple_mm couple_with_heart_mm],
      "\xF0\x9F\x92\x8F" => %w[couplekiss],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA8" => %w[kiss_woman_man],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA9" => %w[kiss_ww
                                                                                                                           couplekiss_ww],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9D\xA4\xEF\xB8\x8F\xE2\x80\x8D\xF0\x9F\x92\x8B\xE2\x80\x8D\xF0\x9F\x91\xA8" => %w[kiss_mm
                                                                                                                           couplekiss_mm],
      "\xF0\x9F\x91\xAA" => %w[family],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_man_woman_boy],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_mwg],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_mwgb],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_mwbb],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_mwgg],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_wwb],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_wwg],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_wwgb],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_wwbb],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_wwgg],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_mmb],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_mmg],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_mmgb],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA6\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_mmbb],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x91\xA7\xE2\x80\x8D\xF0\x9F\x91\xA7" => %w[family_mmgg],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x91\xA6" => %w[family_woman_boy],
      "\xF0\x9F\xA7\x9F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_zombie],
      "\xF0\x9F\xA7\x9F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_zombie],
      "\xF0\x9F\xA7\x9E" => %w[genie],
      "\xF0\x9F\xA7\x9E\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_genie],
      "\xF0\x9F\xA7\x9E\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_genie],
      "\xF0\x9F\xA7\x9C" => %w[merperson],
      "\xF0\x9F\xA7\x9C\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[mermaid],
      "\xF0\x9F\xA7\x9C\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[merman],
      "\xF0\x9F\xA7\x9A" => %w[fairy],
      "\xF0\x9F\xA7\x9A\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_fairy],
      "\xF0\x9F\xA7\x9A\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_fairy],
      "\xF0\x9F\x91\xBC" => %w[angel],
      "\xF0\x9F\xA4\xB0" => %w[pregnant_woman expecting_woman],
      "\xF0\x9F\xA4\xB1" => %w[breast_feeding],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8D\xBC" => %w[person_feeding_baby],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8D\xBC" => %w[woman_feeding_baby],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8D\xBC" => %w[man_feeding_baby],
      "\xF0\x9F\x99\x87" => %w[person_bowing bow],
      "\xF0\x9F\x99\x87\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_bowing],
      "\xF0\x9F\x99\x87\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_bowing],
      "\xF0\x9F\x92\x81" => %w[person_tipping_hand information_desk_person],
      "\xF0\x9F\x92\x81\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_tipping_hand],
      "\xF0\x9F\x92\x81\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_tipping_hand],
      "\xF0\x9F\x99\x85" => %w[person_gesturing_no no_good],
      "\xF0\x9F\x99\x85\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_gesturing_no],
      "\xF0\x9F\x99\x85\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_gesturing_no],
      "\xF0\x9F\x99\x86" => %w[person_gesturing_ok ok_woman],
      "\xF0\x9F\x99\x86\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_gesturing_ok],
      "\xF0\x9F\x99\x86\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_gesturing_ok],
      "\xF0\x9F\x99\x8B" => %w[person_raising_hand raising_hand],
      "\xF0\x9F\x99\x8B\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_raising_hand],
      "\xF0\x9F\x99\x8B\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_raising_hand],
      "\xF0\x9F\xA7\x8F" => %w[deaf_person],
      "\xF0\x9F\xA7\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[deaf_woman],
      "\xF0\x9F\xA7\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[deaf_man],
      "\xF0\x9F\xA4\xA6" => %w[person_facepalming face_palm facepalm],
      "\xF0\x9F\xA4\xA6\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_facepalming],
      "\xF0\x9F\xA4\xA6\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_facepalming],
      "\xF0\x9F\xA4\xB7" => %w[person_shrugging shrug],
      "\xF0\x9F\xA4\xB7\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_shrugging],
      "\xF0\x9F\xA4\xB7\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_shrugging],
      "\xF0\x9F\x99\x8E" => %w[person_pouting person_with_pouting_face],
      "\xF0\x9F\x99\x8E\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_pouting],
      "\xF0\x9F\x99\x8E\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_pouting],
      "\xF0\x9F\x99\x8D" => %w[person_frowning],
      "\xF0\x9F\x99\x8D\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_frowning],
      "\xF0\x9F\x99\x8D\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_frowning],
      "\xF0\x9F\x92\x87" => %w[person_getting_haircut haircut],
      "\xF0\x9F\x92\x87\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_getting_haircut],
      "\xF0\x9F\x92\x87\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_getting_haircut],
      "\xF0\x9F\x92\x86" => %w[person_getting_massage massage],
      "\xF0\x9F\x92\x86\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_getting_face_massage],
      "\xF0\x9F\x92\x86\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_getting_face_massage],
      "\xF0\x9F\xA7\x96" => %w[person_in_steamy_room],
      "\xF0\x9F\xA7\x96\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_in_steamy_room],
      "\xF0\x9F\xA7\x96\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_in_steamy_room],
      "\xF0\x9F\x92\x85" => %w[nail_care],
      "\xF0\x9F\xA4\xB3" => %w[selfie],
      "\xF0\x9F\x92\x83" => %w[dancer],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8C\xBE" => %w[farmer],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8C\xBE" => %w[woman_farmer],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8C\xBE" => %w[man_farmer],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8D\xB3" => %w[cook],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8D\xB3" => %w[woman_cook],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8D\xB3" => %w[man_cook],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\x93" => %w[student],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8E\x93" => %w[woman_student],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8E\x93" => %w[man_student],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\xA4" => %w[singer],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8E\xA4" => %w[woman_singer],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8E\xA4" => %w[man_singer],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8F\xAB" => %w[teacher],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8F\xAB" => %w[woman_teacher],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8F\xAB" => %w[man_teacher],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8F\xAD" => %w[factory_worker],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8F\xAD" => %w[woman_factory_worker],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8F\xAD" => %w[man_factory_worker],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x92\xBB" => %w[technologist],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x92\xBB" => %w[woman_technologist],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x92\xBB" => %w[man_technologist],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x92\xBC" => %w[office_worker],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x92\xBC" => %w[woman_office_worker],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x92\xBC" => %w[man_office_worker],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x94\xA7" => %w[mechanic],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x94\xA7" => %w[woman_mechanic],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x94\xA7" => %w[man_mechanic],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x94\xAC" => %w[scientist],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x94\xAC" => %w[woman_scientist],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x94\xAC" => %w[man_scientist],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\xA8" => %w[artist],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x8E\xA8" => %w[woman_artist],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x8E\xA8" => %w[man_artist],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x9A\x92" => %w[firefighter],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x9A\x92" => %w[woman_firefighter],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x9A\x92" => %w[man_firefighter],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xE2\x9C\x88\xEF\xB8\x8F" => %w[pilot],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9C\x88\xEF\xB8\x8F" => %w[woman_pilot],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9C\x88\xEF\xB8\x8F" => %w[man_pilot],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x9A\x80" => %w[astronaut],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\x9A\x80" => %w[woman_astronaut],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\x9A\x80" => %w[man_astronaut],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xE2\x9A\x96\xEF\xB8\x8F" => %w[judge],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9A\x96\xEF\xB8\x8F" => %w[woman_judge],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9A\x96\xEF\xB8\x8F" => %w[man_judge],
      "\xF0\x9F\x91\xB0" => %w[person_with_veil],
      "\xF0\x9F\x91\xB0\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_with_veil bride_with_veil],
      "\xF0\x9F\x91\xB0\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_with_veil],
      "\xF0\x9F\xA4\xB5" => %w[person_in_tuxedo],
      "\xF0\x9F\xA4\xB5\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_in_tuxedo],
      "\xF0\x9F\xA4\xB5\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_in_tuxedo],
      "\xF0\x9F\x91\xB8" => %w[princess],
      "\xF0\x9F\xA4\xB4" => %w[prince],
      "\xF0\x9F\xA6\xB8" => %w[superhero],
      "\xF0\x9F\xA6\xB8\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_superhero],
      "\xF0\x9F\xA6\xB8\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_superhero],
      "\xF0\x9F\xA6\xB9" => %w[supervillain],
      "\xF0\x9F\xA6\xB9\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_supervillain],
      "\xF0\x9F\xA6\xB9\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_supervillain],
      "\xF0\x9F\xA5\xB7" => %w[ninja],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\x8E\x84" => %w[mx_claus],
      "\xF0\x9F\xA4\xB6" => %w[mrs_claus mother_christmas],
      "\xF0\x9F\x8E\x85" => %w[santa],
      "\xF0\x9F\xA7\x99" => %w[mage],
      "\xF0\x9F\xA7\x99\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_mage],
      "\xF0\x9F\xA7\x99\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_mage],
      "\xF0\x9F\xA7\x9D" => %w[elf],
      "\xF0\x9F\xA7\x9D\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_elf],
      "\xF0\x9F\xA7\x9D\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_elf],
      "\xF0\x9F\xA7\x9B" => %w[vampire],
      "\xF0\x9F\xA7\x9B\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_vampire],
      "\xF0\x9F\xA7\x9B\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_vampire],
      "\xF0\x9F\xA7\x9F" => %w[zombie],
      "\xF0\x9F\xA6\xB5" => %w[leg],
      "\xF0\x9F\xA6\xBF" => %w[mechanical_leg],
      "\xF0\x9F\x92\x84" => %w[lipstick],
      "\xF0\x9F\x92\x8B" => %w[kiss],
      "\xF0\x9F\x91\x84" => %w[lips],
      "\xF0\x9F\xA6\xB7" => %w[tooth],
      "\xF0\x9F\x91\x85" => %w[tongue],
      "\xF0\x9F\x91\x82" => %w[ear],
      "\xF0\x9F\xA6\xBB" => %w[ear_with_hearing_aid],
      "\xF0\x9F\x91\x83" => %w[nose],
      "\xF0\x9F\x91\xA3" => %w[footprints],
      "\xF0\x9F\x91\x81\xEF\xB8\x8F" => %w[eye],
      "\xF0\x9F\xA7\xA0" => %w[brain],
      "\xF0\x9F\xAB\x80" => %w[anatomical_heart],
      "\xF0\x9F\xAB\x81" => %w[lungs],
      "\xF0\x9F\xA6\xB4" => %w[bone],
      "\xF0\x9F\x97\xA3\xEF\xB8\x8F" => %w[speaking_head speaking_head_in_silhouette],
      "\xF0\x9F\x91\xA4" => %w[bust_in_silhouette],
      "\xF0\x9F\x91\xA5" => %w[busts_in_silhouette],
      "\xF0\x9F\xAB\x82" => %w[people_hugging],
      "\xF0\x9F\x91\xB6" => %w[baby],
      "\xF0\x9F\x91\xA7" => %w[girl],
      "\xF0\x9F\xA7\x92" => %w[child],
      "\xF0\x9F\x91\xA6" => %w[boy],
      "\xF0\x9F\x91\xA9" => %w[woman],
      "\xF0\x9F\xA7\x91" => %w[adult],
      "\xF0\x9F\x91\xA8" => %w[man],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB1" => %w[person_curly_hair],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB1" => %w[woman_curly_haired],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB1" => %w[man_curly_haired],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB0" => %w[person_red_hair],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB0" => %w[woman_red_haired],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB0" => %w[man_red_haired],
      "\xF0\x9F\x91\xB1\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[blond_haired_woman],
      "\xF0\x9F\x91\xB1" => %w[blond_haired_person person_with_blond_hair],
      "\xF0\x9F\x91\xB1\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[blond_haired_man],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB3" => %w[person_white_hair],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB3" => %w[woman_white_haired],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB3" => %w[man_white_haired],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xF0\x9F\xA6\xB2" => %w[person_bald],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xF0\x9F\xA6\xB2" => %w[woman_bald],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xF0\x9F\xA6\xB2" => %w[man_bald],
      "\xF0\x9F\xA7\x94" => %w[bearded_person],
      "\xF0\x9F\xA7\x94\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_beard],
      "\xF0\x9F\xA7\x94\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_beard],
      "\xF0\x9F\x91\xB5" => %w[older_woman grandma],
      "\xF0\x9F\xA7\x93" => %w[older_adult],
      "\xF0\x9F\x91\xB4" => %w[older_man],
      "\xF0\x9F\x91\xB2" => %w[man_with_chinese_cap man_with_gua_pi_mao],
      "\xF0\x9F\x91\xB3" => %w[person_wearing_turban man_with_turban],
      "\xF0\x9F\x91\xB3\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_wearing_turban],
      "\xF0\x9F\x91\xB3\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_wearing_turban],
      "\xF0\x9F\xA7\x95" => %w[woman_with_headscarf],
      "\xF0\x9F\x91\xAE" => %w[police_officer cop],
      "\xF0\x9F\x91\xAE\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_police_officer],
      "\xF0\x9F\x91\xAE\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_police_officer],
      "\xF0\x9F\x91\xB7" => %w[construction_worker],
      "\xF0\x9F\x91\xB7\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_construction_worker],
      "\xF0\x9F\x91\xB7\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_construction_worker],
      "\xF0\x9F\x92\x82" => %w[guard guardsman],
      "\xF0\x9F\x92\x82\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_guard],
      "\xF0\x9F\x92\x82\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_guard],
      "\xF0\x9F\x95\xB5\xEF\xB8\x8F" => %w[detective spy sleuth_or_spy],
      "\xF0\x9F\x95\xB5\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x80\xEF\xB8\x8F" => %w[woman_detective],
      "\xF0\x9F\x95\xB5\xEF\xB8\x8F\xE2\x80\x8D\xE2\x99\x82\xEF\xB8\x8F" => %w[man_detective],
      "\xF0\x9F\xA7\x91\xE2\x80\x8D\xE2\x9A\x95\xEF\xB8\x8F" => %w[health_worker],
      "\xF0\x9F\x91\xA9\xE2\x80\x8D\xE2\x9A\x95\xEF\xB8\x8F" => %w[woman_health_worker],
      "\xF0\x9F\x91\xA8\xE2\x80\x8D\xE2\x9A\x95\xEF\xB8\x8F" => %w[man_health_worker],
      "\xF0\x9F\x98\xAC" => %w[grimacing],
      "\xF0\x9F\x99\x84" => %w[rolling_eyes face_with_rolling_eyes],
      "\xF0\x9F\x98\xAF" => %w[hushed],
      "\xE2\x98\xB9\xEF\xB8\x8F" => %w[frowning],
      "\xF0\x9F\x98\xA7" => %w[anguished],
      "\xF0\x9F\x98\xAE" => %w[open_mouth],
      "\xF0\x9F\x98\xB2" => %w[astonished],
      "\xF0\x9F\x98\xB4" => %w[sleeping],
      "\xF0\x9F\xA4\xA4" => %w[drooling_face drool],
      "\xF0\x9F\x98\xAA" => %w[sleepy],
      "\xF0\x9F\x98\xB5" => %w[dizzy_face],
      "\xF0\x9F\x98\xB5\xE2\x80\x8D\xF0\x9F\x92\xAB" => %w[face_with_spiral_eyes],
      "\xF0\x9F\xA4\x90" => %w[zipper_mouth zipper_mouth_face],
      "\xF0\x9F\xA5\xB4" => %w[woozy_face],
      "\xF0\x9F\xA4\xA2" => %w[nauseated_face sick],
      "\xF0\x9F\xA4\xAE" => %w[face_vomiting],
      "\xF0\x9F\xA4\xA7" => %w[sneezing_face sneeze],
      "\xF0\x9F\x98\xB7" => %w[mask],
      "\xF0\x9F\xA4\x92" => %w[thermometer_face face_with_thermometer],
      "\xF0\x9F\xA4\x95" => %w[head_bandage face_with_head_bandage],
      "\xF0\x9F\xA4\x91" => %w[money_mouth money_mouth_face],
      "\xF0\x9F\xA4\xA0" => %w[cowboy face_with_cowboy_hat],
      "\xF0\x9F\xA5\xB8" => %w[disguised_face],
      "\xF0\x9F\x98\x88" => %w[smiling_imp],
      "\xF0\x9F\x91\xBF" => %w[imp],
      "\xF0\x9F\x91\xB9" => %w[japanese_ogre],
      "\xF0\x9F\x91\xBA" => %w[japanese_goblin],
      "\xF0\x9F\xA4\xA1" => %w[clown clown_face],
      "\xF0\x9F\x91\xBB" => %w[ghost],
      "\xF0\x9F\x92\x80" => %w[skull skeleton],
      "\xE2\x98\xA0\xEF\xB8\x8F" => %w[skull_crossbones skull_and_crossbones],
      "\xF0\x9F\x91\xBD" => %w[alien],
      "\xF0\x9F\x91\xBE" => %w[space_invader],
      "\xF0\x9F\xA4\x96" => %w[robot robot_face],
      "\xF0\x9F\x8E\x83" => %w[jack_o_lantern],
      "\xF0\x9F\x98\xBA" => %w[smiley_cat],
      "\xF0\x9F\x98\xB8" => %w[smile_cat],
      "\xF0\x9F\x98\xB9" => %w[joy_cat],
      "\xF0\x9F\x98\xBB" => %w[heart_eyes_cat],
      "\xF0\x9F\x98\xBC" => %w[smirk_cat],
      "\xF0\x9F\x98\xBD" => %w[kissing_cat],
      "\xF0\x9F\x99\x80" => %w[scream_cat],
      "\xF0\x9F\x98\xBF" => %w[crying_cat_face],
      "\xF0\x9F\x98\xBE" => %w[pouting_cat],
      "\xF0\x9F\xA4\xB2" => %w[palms_up_together],
      "\xF0\x9F\x91\x90" => %w[open_hands],
      "\xF0\x9F\x99\x8C" => %w[raised_hands],
      "\xF0\x9F\x91\x8F" => %w[clap],
      "\xF0\x9F\xA4\x9D" => %w[handshake shaking_hands],
      "\xF0\x9F\x91\x8D" => %w[thumbsup +1 thumbup],
      "\xF0\x9F\x91\x8E" => %w[thumbsdown -1 thumbdown],
      "\xF0\x9F\x91\x8A" => %w[punch],
      "\xE2\x9C\x8A" => %w[fist],
      "\xF0\x9F\xA4\x9B" => %w[left_facing_fist left_fist],
      "\xF0\x9F\xA4\x9C" => %w[right_facing_fist right_fist],
      "\xF0\x9F\xA4\x9E" => %w[fingers_crossed hand_with_index_and_middle_finger_crossed],
      "\xE2\x9C\x8C\xEF\xB8\x8F" => %w[v],
      "\xF0\x9F\xA4\x9F" => %w[love_you_gesture],
      "\xF0\x9F\xA4\x98" => %w[metal sign_of_the_horns],
      "\xF0\x9F\x91\x8C" => %w[ok_hand],
      "\xF0\x9F\xA4\x8F" => %w[pinching_hand],
      "\xF0\x9F\xA4\x8C" => %w[pinched_fingers],
      "\xF0\x9F\x91\x88" => %w[point_left],
      "\xF0\x9F\x91\x89" => %w[point_right],
      "\xF0\x9F\x91\x86" => %w[point_up_],
      "\xF0\x9F\x91\x87" => %w[point_down],
      "\xE2\x98\x9D\xEF\xB8\x8F" => %w[point_up],
      "\xE2\x9C\x8B" => %w[raised_hand],
      "\xF0\x9F\xA4\x9A" => %w[raised_back_of_hand back_of_hand],
      "\xF0\x9F\x96\x90\xEF\xB8\x8F" => %w[hand_splayed raised_hand_with_fingers_splayed],
      "\xF0\x9F\x96\x96" => %w[vulcan raised_hand_with_part_between_middle_and_ring_fingers],
      "\xF0\x9F\x91\x8B" => %w[wave],
      "\xF0\x9F\xA4\x99" => %w[call_me call_me_hand],
      "\xF0\x9F\x92\xAA" => %w[muscle],
      "\xF0\x9F\xA6\xBE" => %w[mechanical_arm],
      "\xF0\x9F\x96\x95" => %w[middle_finger reversed_hand_with_middle_finger_extended],
      "\xE2\x9C\x8D\xEF\xB8\x8F" => %w[writing_hand],
      "\xF0\x9F\x99\x8F" => %w[pray],
      "\xF0\x9F\xA6\xB6" => %w[foot],
      "\xF0\x9F\x92\xA9" => %w[poop shit hankey poo],
      "\xF0\x9F\xA4\x94" => %w[thinking thinking_face],
      "\xF0\x9F\x94\xB0" => %w[beginner],
      "\xF0\x9F\x91\x80" => %w[eyes],
      "\xF0\x9F\x98\x86" => %w[laughing satisfied],
      "\xF0\x9F\x8D\xB5" => %w[tea],
      "\xE2\x9A\x99\xEF\xB8\x8F" => %w[gear],
      "\xF0\x9F\x94\x94" => %w[bell],
      "\xF0\x9F\xA4\xAC" => %w[face_with_symbols_over_mouth],
      "\xF0\x9F\x98\x80" => %w[grinning],
      "\xF0\x9F\x98\x83" => %w[smiley],
      "\xF0\x9F\x98\x84" => %w[smile],
      "\xF0\x9F\x98\x81" => %w[grin],
      "\xF0\x9F\x98\x85" => %w[sweat_smile],
      "\xF0\x9F\x98\x82" => %w[joy],
      "\xF0\x9F\xA4\xA3" => %w[rofl rolling_on_the_floor_laughing],
      "\xE2\x98\xBA\xEF\xB8\x8F" => %w[relaxed],
      "\xF0\x9F\x98\x8A" => %w[blush],
      "\xF0\x9F\x98\x87" => %w[innocent],
      "\xF0\x9F\x99\x82" => %w[slight_smile slightly_smiling_face],
      "\xF0\x9F\x99\x83" => %w[upside_down upside_down_face],
      "\xF0\x9F\x98\x89" => %w[wink],
      "\xF0\x9F\x98\x8C" => %w[relieved],
      "\xF0\x9F\xA5\xB2" => %w[smiling_face_with_tear],
      "\xF0\x9F\x98\x8D" => %w[heart_eyes],
      "3_hearts\xF0\x9F\xA5\xB0" => %w[smiling_face_with_],
      "\xF0\x9F\x98\x98" => %w[kissing_heart],
      "\xF0\x9F\x98\x97" => %w[kissing],
      "\xF0\x9F\x98\x99" => %w[kissing_smiling_eyes],
      "\xF0\x9F\x98\x9A" => %w[kissing_closed_eyes],
      "\xF0\x9F\x98\x8B" => %w[yum],
      "\xF0\x9F\x98\x9B" => %w[stuck_out_tongue],
      "\xF0\x9F\x98\x9D" => %w[stuck_out_tongue_closed_eyes],
      "\xF0\x9F\x98\x9C" => %w[stuck_out_tongue_winking_eye],
      "\xF0\x9F\xA4\xAA" => %w[zany_face],
      "\xF0\x9F\xA4\xA8" => %w[face_with_raised_eyebrow],
      "\xF0\x9F\xA7\x90" => %w[face_with_monocle],
      "\xF0\x9F\xA4\x93" => %w[nerd nerd_face],
      "\xF0\x9F\x98\x8E" => %w[sunglasses],
      "\xF0\x9F\xA4\xA9" => %w[star_struck],
      "\xF0\x9F\xA5\xB3" => %w[partying_face],
      "\xF0\x9F\x98\x8F" => %w[smirk],
      "\xF0\x9F\x98\x92" => %w[unamused],
      "\xF0\x9F\x98\x9E" => %w[disappointed],
      "\xF0\x9F\x98\x94" => %w[pensive],
      "\xF0\x9F\x98\x9F" => %w[worried],
      "\xF0\x9F\x98\x95" => %w[confused],
      "\xF0\x9F\x99\x81" => %w[slight_frown slightly_frowning_face],
      "\xF0\x9F\x98\xA3" => %w[persevere],
      "\xF0\x9F\x98\x96" => %w[confounded],
      "\xF0\x9F\x98\xAB" => %w[tired_face],
      "\xF0\x9F\x98\xA9" => %w[weary],
      "\xF0\x9F\xA5\xBA" => %w[pleading_face],
      "\xF0\x9F\x98\xA2" => %w[cry],
      "\xF0\x9F\x98\xAD" => %w[sob],
      "\xF0\x9F\x98\xA4" => %w[triumph],
      "\xF0\x9F\x98\xAE\xE2\x80\x8D\xF0\x9F\x92\xA8" => %w[face_exhaling],
      "\xF0\x9F\x98\xA0" => %w[angry],
      "\xF0\x9F\x98\xA1" => %w[rage],
      "\xF0\x9F\xA4\xAF" => %w[exploding_head],
      "\xF0\x9F\x98\xB3" => %w[flushed],
      "\xF0\x9F\x98\xB6\xE2\x80\x8D\xF0\x9F\x8C\xAB\xEF\xB8\x8F" => %w[face_in_clouds],
      "\xF0\x9F\xA5\xB5" => %w[hot_face],
      "\xF0\x9F\xA5\xB6" => %w[cold_face],
      "\xF0\x9F\x98\xB1" => %w[scream],
      "\xF0\x9F\x98\xA8" => %w[fearful],
      "\xF0\x9F\x98\xB0" => %w[cold_sweat],
      "\xF0\x9F\x98\xA5" => %w[disappointed_relieved],
      "\xF0\x9F\x98\x93" => %w[sweat],
      "\xF0\x9F\xA4\x97" => %w[hugging hugging_face],
      "\xF0\x9F\xA4\xAD" => %w[face_with_hand_over_mouth],
      "\xF0\x9F\xA5\xB1" => %w[yawning_face],
      "\xF0\x9F\xA4\xAB" => %w[shushing_face],
      "\xF0\x9F\xA4\xA5" => %w[lying_face liar],
      "\xF0\x9F\x98\xB6" => %w[no_mouth],
      "\xF0\x9F\x98\x90" => %w[neutral_face],
      "\xF0\x9F\x98\x91" => %w[expressionless],
      "\xF0\x9F\x95\x90" => %w[clock1],
      "\xF0\x9F\x95\x9C" => %w[clock130],
      "\xF0\x9F\x95\x91" => %w[clock2],
      "\xF0\x9F\x95\x9D" => %w[clock230],
      "\xF0\x9F\x95\x92" => %w[clock3],
      "\xF0\x9F\x95\x9E" => %w[clock330],
      "\xF0\x9F\x95\x93" => %w[clock4],
      "\xF0\x9F\x95\x9F" => %w[clock430],
      "\xF0\x9F\x95\x94" => %w[clock5],
      "\xF0\x9F\x95\xA0" => %w[clock530],
      "\xF0\x9F\x95\x95" => %w[clock6],
      "\xF0\x9F\x95\xA1" => %w[clock630],
      "\xF0\x9F\x95\x96" => %w[clock7],
      "\xF0\x9F\x95\xA2" => %w[clock730],
      "\xF0\x9F\x95\x97" => %w[clock8],
      "\xF0\x9F\x95\xA3" => %w[clock830],
      "\xF0\x9F\x95\x98" => %w[clock9],
      "\xF0\x9F\x95\xA4" => %w[clock930],
      "\xF0\x9F\x95\x99" => %w[clock10],
      "\xF0\x9F\x95\xA5" => %w[clock1030],
      "\xF0\x9F\x95\x9A" => %w[clock11],
      "\xF0\x9F\x95\xA6" => %w[clock1130],
      "\xF0\x9F\x95\x9B" => %w[clock12],
      "\xF0\x9F\x95\xA7" => %w[clock1230],
    }.freeze

    SKIN_TONES = [
      :dummy,
      "\xf0\x9f\x8f\xbb",
      "\xf0\x9f\x8f\xbc",
      "\xf0\x9f\x8f\xbd",
      "\xf0\x9f\x8f\xbe",
      "\xf0\x9f\x8f\xbf",
    ].freeze
  end
end
